# -*- coding: utf-8 -*-
#COPYRIGHT 2019 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""The Conversion toolbox contains tools that convert data between
various formats."""
__all__ = ['ASCIIToRaster', 'AddCADFields', 'AddRasterToGeoPackage',
           'BIMFileToGeodatabase', 'CADToGeodatabase',
           'ConnectNetworkDatasetTransitSourcesToStreets', 'ConvertLas',
           'DEMToRaster', 'ExcelToTable', 'ExportCAD',
           'ExtractLocationsDocument', 'ExtractLocationsText',
           'FeatureClassToFeatureClass', 'FeatureClassToGeodatabase',
           'FeatureClassToShapefile', 'FeatureToRaster', 'FeaturesToGTFSStops',
           'FeaturesToJSON', 'FloatToRaster', 'GPXtoFeatures',
           'GTFSShapesToFeatures', 'GTFSStopsToFeatures',
           'GTFSToNetworkDatasetTransitSources', 'JSONToFeatures', 'KMLToLayer',
           'LasDatasetToRaster', 'LayerToKML', 'MobileGdbToFileGdb',
           'MultipatchToCollada', 'MultipatchToRaster', 'PointToRaster',
           'PolygonToRaster', 'PolylineToRaster', 'RasterToASCII',
           'RasterToFloat', 'RasterToGeodatabase', 'RasterToOtherFormat',
           'RasterToPoint', 'RasterToPolygon', 'RasterToPolyline',
           'TableToDBASE', 'TableToExcel', 'TableToGeodatabase', 'TableToTable',
           'WFSToFeatureClass']
__alias__ = 'conversion'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject

# Excel toolset
@gptooldoc('ExcelToTable_conversion', None)
def ExcelToTable(Input_Excel_File=None, Output_Table=None, Sheet=None):
    """ExcelToTable_conversion(Input_Excel_File, Output_Table, {Sheet})

        Converts Microsoft Excel files into a table.

     INPUTS:
      Input_Excel_File (File):
          The Microsoft Excel file to convert.
      Sheet {String}:
          The name of the particular sheet within the Excel file to import. If
          unspecified, the first sheet in the workbook will be used.

     OUTPUTS:
      Output_Table (Table):
          The output table."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExcelToTable_conversion(*gp_fixargs((Input_Excel_File, Output_Table, Sheet), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('TableToExcel_conversion', None)
def TableToExcel(Input_Table=None, Output_Excel_File=None, Use_field_alias_as_column_header=None, Use_domain_and_subtype_description=None):
    """TableToExcel_conversion(Input_Table, Output_Excel_File, {Use_field_alias_as_column_header}, {Use_domain_and_subtype_description})

        Converts a table to a Microsoft Excel file (.xls or .xlsx).

     INPUTS:
      Input_Table (Table View):
          The table to be converted to Microsoft Excel.
      Use_field_alias_as_column_header {Boolean}:
          Specifies how column names in the output are determined.

          * NAME-Column headers will be set using the input's field names. This
          is the default.

          * ALIAS-Column headers will be set using the input geodatabase table's
          field aliases. If the input is a layer in a map, the value set on the
          layer's field alias is ignored.
      Use_domain_and_subtype_description {Boolean}:
          Controls how values from subtype fields or fields with a coded value
          domain are transferred to the output.

          * CODE-All field values will be used as they are stored in the table.
          This is the default.

          * DESCRIPTION-For subtype fields, the subtype description will be
          used. For fields with a coded value domain, the coded value
          descriptions will be used.

     OUTPUTS:
      Output_Excel_File (File):
          The output Excel file. Specify the format of the Excel file using an
          .xls or .xlsx file extension."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.TableToExcel_conversion(*gp_fixargs((Input_Table, Output_Excel_File, Use_field_alias_as_column_header, Use_domain_and_subtype_description), True)))
        return retval
    except Exception as e:
        raise e


# From GPS toolset
@gptooldoc('GPXtoFeatures_conversion', None)
def GPXtoFeatures(Input_GPX_File=None, Output_Feature_class=None):
    """GPXtoFeatures_conversion(Input_GPX_File, Output_Feature_class)

        Converts the point information inside a GPX file to features.

     INPUTS:
      Input_GPX_File (File):
          The GPX file to convert.

     OUTPUTS:
      Output_Feature_class (Feature Class):
          The feature class to create."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GPXtoFeatures_conversion(*gp_fixargs((Input_GPX_File, Output_Feature_class), True)))
        return retval
    except Exception as e:
        raise e


# From Raster toolset
@gptooldoc('RasterToASCII_conversion', None)
def RasterToASCII(in_raster=None, out_ascii_file=None):
    """RasterToASCII_conversion(in_raster, out_ascii_file)

        Converts a raster dataset to an ASCII text file representing raster
        data.

     INPUTS:
      in_raster (Composite Geodataset):
          The input raster dataset.The raster can be integer or floating-point
          type.

     OUTPUTS:
      out_ascii_file (File):
          The output ASCII raster file."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RasterToASCII_conversion(*gp_fixargs((in_raster, out_ascii_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('RasterToFloat_conversion', None)
def RasterToFloat(in_raster=None, out_float_file=None):
    """RasterToFloat_conversion(in_raster, out_float_file)

        Converts a raster dataset to a file of binary floating-point values
        representing raster data.

     INPUTS:
      in_raster (Composite Geodataset):
          The input raster dataset.The raster can be integer or floating-point
          type.

     OUTPUTS:
      out_float_file (File):
          The output floating-point raster file.The file name must have a .flt
          extension."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RasterToFloat_conversion(*gp_fixargs((in_raster, out_float_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('RasterToPoint_conversion', None)
def RasterToPoint(in_raster=None, out_point_features=None, raster_field=None):
    """RasterToPoint_conversion(in_raster, out_point_features, {raster_field})

        Converts a raster dataset to point features.

     INPUTS:
      in_raster (Composite Geodataset):
          The input raster dataset.The raster can be integer or floating-point
          type.
      raster_field {Field}:
          The field to assign values from the cells in the input raster to the
          points in the output dataset.It can be an integer, floating point, or
          string field.

     OUTPUTS:
      out_point_features (Feature Class):
          The output feature class that will contain the converted points."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RasterToPoint_conversion(*gp_fixargs((in_raster, out_point_features, raster_field), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('RasterToPolygon_conversion', None)
def RasterToPolygon(in_raster=None, out_polygon_features=None, simplify=None, raster_field=None, create_multipart_features=None, max_vertices_per_feature=None):
    """RasterToPolygon_conversion(in_raster, out_polygon_features, {simplify}, {raster_field}, {create_multipart_features}, {max_vertices_per_feature})

        Converts a raster dataset to polygon features.

     INPUTS:
      in_raster (Composite Geodataset):
          The input raster dataset.The raster must be integer type.
      simplify {Boolean}:
          Determines if the output polygons will be smoothed into simpler shapes
          or conform to the input raster's cell edges.

          * SIMPLIFY-The polygons will be smoothed into simpler shapes. The
          smoothing is done in such a way that the polygons contain a minimum
          number of segments while remaining as close as possible the original
          raster cell edges. This is the default.

          * NO_SIMPLIFY-The edge of the polygons will conform exactly to the
          input raster's cell edges. With this option, converting the resulting
          polygon feature class back to a raster would produce a raster the same
          as the original.
      raster_field {Field}:
          The field used to assign values from the cells in the input raster to
          the polygons in the output dataset.It can be an integer or a string
          field.
      create_multipart_features {Boolean}:
          Specifies whether the output polygons will consist of single-part or
          multipart features.

          * MULTIPLE_OUTER_PART-Specifies that multipart features will be
          created based on polygons that have the same value.

          * SINGLE_OUTER_PART-Specifies that individual features will be created
          for each polygon. This is the default.
      max_vertices_per_feature {Long}:
          The vertex limit used to subdivide a polygon into smaller polygons.
          This parameter produces similar output as created by the Dice tool.If
          left empty, the output polygons will not be split. The default is
          empty.

     OUTPUTS:
      out_polygon_features (Feature Class):
          The output feature class that will contain the converted polygons."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RasterToPolygon_conversion(*gp_fixargs((in_raster, out_polygon_features, simplify, raster_field, create_multipart_features, max_vertices_per_feature), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('RasterToPolyline_conversion', None)
def RasterToPolyline(in_raster=None, out_polyline_features=None, background_value=None, minimum_dangle_length=None, simplify=None, raster_field=None):
    """RasterToPolyline_conversion(in_raster, out_polyline_features, {background_value}, {minimum_dangle_length}, {simplify}, {raster_field})

        Converts a raster dataset to polyline features.

     INPUTS:
      in_raster (Composite Geodataset):
          The input raster dataset.The raster must be integer type.
      background_value {String}:
          Specifies the value that will identify the background cells. The
          raster dataset is viewed as a set of foreground cells and background
          cells. The linear features are formed from the foreground cells.

          * ZERO-The background is composed of cells of zero or less or NoData.
          All cells with a value greater than zero are considered a foreground
          value.

          * NODATA-The background is composed of NoData cells. All cells with
          valid values belong to the foreground.
      minimum_dangle_length {Double}:
          Minimum length of dangling polylines that will be retained. The
          default is zero.
      simplify {Boolean}:
          Simplifies a line by removing small fluctuations or extraneous bends
          from it while preserving its essential shape.

          * SIMPLIFY-The polylines will be simplified into simpler shapes such
          that each contains a minimum number of segments. This is the default.

          * NO_SIMPLIFY-The polylines will not be simplified.
      raster_field {Field}:
          The field used to assign values from the cells in the input raster to
          the polyline features in the output dataset.It can be an integer or a
          string field.

     OUTPUTS:
      out_polyline_features (Feature Class):
          The output feature class that will contain the converted polylines."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RasterToPolyline_conversion(*gp_fixargs((in_raster, out_polyline_features, background_value, minimum_dangle_length, simplify, raster_field), True)))
        return retval
    except Exception as e:
        raise e


# From WFS toolset
@gptooldoc('WFSToFeatureClass_conversion', None)
def WFSToFeatureClass(input_WFS_server=None, WFS_feature_type=None, out_path=None, out_name=None, is_complex=None, max_features=None, expose_metadata=None, swap_xy=None):
    """WFSToFeatureClass_conversion(input_WFS_server, WFS_feature_type, out_path, out_name, {is_complex}, {max_features}, {expose_metadata}, {swap_xy})

        Imports a feature type from a web feature service (WFS) to a feature
        class in a geodatabase.

     INPUTS:
      input_WFS_server (String):
          The URL of the source WFS service (for example, http://sampleserver6.a
          rcgisonline.com/arcgis/services/SampleWorldCities/MapServer/WFSServer?
          ). If the input is a complex WFS service (is_complex=True), this can
          also be the path to the XML file.
      WFS_feature_type (String):
          The name of the WFS layer to extract from the input WFS service.
      out_path (Workspace / Feature Dataset / Folder):
          If the input is a simple WFS service, the output location can be a
          geodatabase or a feature dataset within a geodatabase. If the output
          location is a feature dataset, the coordinates are converted from the
          source coordinate system to the coordinate system of the feature
          dataset.If the input is a complex WFS service, the output location
          must be a
          folder.
      out_name (String):
          If the input is a simple WFS service, the name is used to create a
          feature class within the output location. If the feature class name
          already exists in the geodatabase, the name will be automatically
          incremented. By default, the feature type name is used.If the input is
          a complex WFS service, the name is used to create a
          geodatabase in the output location.
      is_complex {Boolean}:
          Specify if the input_WFS_server service is a complex WFS service.

          * TRUE-The WFS service is a complex WFS service.

          * FALSE-The WFS service is not a complex service. This is the default.
      max_features {Long}:
          Specify the maximum number of features that can be returned. The
          default is 1000.
      expose_metadata {Boolean}:
          Specifies whether to create tables with metadata from the service.
          This is only applicable for complex WFS services.

          * TRUE-Create metadata tables in the output geodatabase.

          * FALSE-Do not create metadata tables in the output geodatabase. This
          is the default.
      swap_xy {Boolean}:
          Specifies whether to swap the x,y axis order of the output feature
          class. Some WFS services may have the order of the x,y coordinates
          swapped on the server side, causing the feature class to display
          incorrectly.

          * TRUE-Swap the x,y axis order.

          * FALSE-Do not swap the x,y axis order. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.WFSToFeatureClass_conversion(*gp_fixargs((input_WFS_server, WFS_feature_type, out_path, out_name, is_complex, max_features, expose_metadata, swap_xy), True)))
        return retval
    except Exception as e:
        raise e


# JSON toolset
@gptooldoc('FeaturesToJSON_conversion', None)
def FeaturesToJSON(in_features=None, out_json_file=None, format_json=None, include_z_values=None, include_m_values=None, geoJSON=None, outputToWGS84=None, use_field_alias=None):
    """FeaturesToJSON_conversion(in_features, out_json_file, {format_json}, {include_z_values}, {include_m_values}, {geoJSON}, {outputToWGS84}, {use_field_alias})

        Converts features to JSON or GeoJSON format. The fields, geometry,
        and spatial reference of features will be converted to their
        corresponding JSON representation and written to a file with a .json
        or .geojson extension.

     INPUTS:
      in_features (Feature Layer):
          The features to convert to JSON.
      format_json {Boolean}:
          Specifies whether the JSON will be formatted to improve readability
          similar to the ArcGIS REST API specification's PJSON (Pretty JSON)
          format.

          * NOT_FORMATTED-The features will not be formatted. This is the
          default.

          * FORMATTED-The features will be formatted to improve readability.
      include_z_values {Boolean}:
          Specifies whether to include z-values of the features to the JSON.

          * NO_Z_VALUES-The z-values will not be included in geometries, and
          the hasZ property of the JSON will not be included. This is the
          default.

          * Z_VALUES-The z-values will be included in geometries, and the hasZ
          property of the JSON will be set to true.
      include_m_values {Boolean}:
          Specifies whether to include m-values of the features to the JSON.

          * NO_M_VALUES-The m-values will not be included in geometries, and
          the hasM property of the JSON will not be included. This is the
          default.

          * M_VALUES-The m-values will be included in geometries, and the hasM
          property of the JSON will be set to true.
      geoJSON {Boolean}:
          Specifies whether the output will be created as GeoJSON, conforming to
          the GeoJSON specification.

          * GEOJSON-The output will be created in the GeoJSON format
          (.geojson).

          * NO_GEOJSON-The output will be created as Esri JSON (.json). This is
          the default.
      outputToWGS84 {Boolean}:
          Specifies whether the input features will be projected to the
          geographic coordinate system WGS_1984 with a default geographic
          transformation. This parameter only applies when the output is
          GeoJSON.

          * WGS84-Features will be projected to WGS_1984.

          * KEEP_INPUT_SR-Features will not be projected to WGS_1984. The
          GeoJSON will contain a CRS tag that defines the coordinate system.
          This is the default.
      use_field_alias {Boolean}:
          Specifies whether the output file will use field aliases for feature
          attributes.

          * USE_FIELD_NAME-Output feature attributes will use field names. This
          is the default.

          * USE_FIELD_ALIAS-Output feature attributes will use field aliases.

     OUTPUTS:
      out_json_file (File):
          The output JSON or GeoJSON file."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FeaturesToJSON_conversion(*gp_fixargs((in_features, out_json_file, format_json, include_z_values, include_m_values, geoJSON, outputToWGS84, use_field_alias), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('JSONToFeatures_conversion', None)
def JSONToFeatures(in_json_file=None, out_features=None, geometry_type=None):
    """JSONToFeatures_conversion(in_json_file, out_features, {geometry_type})

        Converts feature collections in an Esri JSON (.json) file or GeoJSON
        (.geojson) file to a feature class.

     INPUTS:
      in_json_file (File):
          The JSON file (.json) to convert.
      geometry_type {String}:
          The geometry type to convert from GeoJSON to features. This option is
          only used when the input is a GeoJSON file. If the GeoJSON file does
          not contain any of the selected geometry type, the output feature
          class will be empty.

          * POINT-Convert any points to features.

          * MULTIPOINT-Convert any multipoints to features.

          * POLYLINE-Convert any polylines to features.

          * POLYGON-Convert any polygons to features.

     OUTPUTS:
      out_features (Feature Class):
          The output feature class to create."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.JSONToFeatures_conversion(*gp_fixargs((in_json_file, out_features, geometry_type), True)))
        return retval
    except Exception as e:
        raise e


# KML toolset
@gptooldoc('KMLToLayer_conversion', None)
def KMLToLayer(in_kml_file=None, output_folder=None, output_data=None, include_groundoverlay=None):
    """KMLToLayer_conversion(in_kml_file, output_folder, {output_data}, {include_groundoverlay})

        Converts a KML or KMZ file into feature classes and a layer file. The
        layer file maintains the symbology found within the original KML or
        KMZ file.

     INPUTS:
      in_kml_file (File / KML Layer):
          The KML or KMZ file to translate.
      output_folder (Folder):
          The destination folder for the file geodatabase and layer (.lyrx)
          file.
      output_data {String}:
          The name of the output file geodatabase and layer file. The default
          is the name of the input KML file.
      include_groundoverlay {Boolean}:
          Include ground overlay (raster, air photos, and so on). Use caution if
          the KMZ points to a service that serves raster imagery. The tool will
          attempt to translate the raster imagery at all available scales. This
          process could be lengthy and possibly overwhelm the service.

          * GROUNDOVERLAY-Ground overlays are included in the output.

          * NO_GROUNDOVERLAY-Ground overlays are not included in the output.
          This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.KMLToLayer_conversion(*gp_fixargs((in_kml_file, output_folder, output_data, include_groundoverlay), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('LayerToKML_conversion', None)
def LayerToKML(layer=None, out_kmz_file=None, layer_output_scale=None, is_composite=None, boundary_box_extent=None, image_size=None, dpi_of_client=None, ignore_zvalue=None):
    """LayerToKML_conversion(layer, out_kmz_file, {layer_output_scale}, {is_composite}, {boundary_box_extent}, {image_size}, {dpi_of_client}, {ignore_zvalue})

        This tool converts a feature or raster layer into a KML file
        containing a translation of Esri geometries and symbology. This file
        is compressed using ZIP compression, has a .kmz extension, and can be
        read by any KML client including ArcGIS Earth, ArcGlobe, and Google
        Earth.

     INPUTS:
      layer (Layer):
          The feature or raster layer or layer file (.lyrx) to be converted to
          KML.
      layer_output_scale {Double}:
          The scale at which to export the layer. This parameter is used with
          any scale dependency, such as layer visibility or scale-dependent
          rendering. If the layer is not visible at the export scale, it will
          not be included in the created KML file. Any value, such as 0, can be
          used if there are no scale dependencies.If exporting a layer that is
          to be displayed as 3D vectors and the
          is_composite parameter is set to NO_COMPOSITE, you can set this
          parameter to any value, as long as your features do not have any
          scale-dependent rendering.Only numeric characters should be entered;
          for example, enter 20000 as
          the scale, not 1:20000 or 20,000.
      is_composite {Boolean}:
          * COMPOSITE-The output KML file will be a single composite image
          representing the raster or vector features in the source layer. The
          raster is draped over the terrain as a KML GroundOverlay. Select this
          option to reduce the size of the output KMZ file. When you check this
          box, individual features and layers in the KML are not selectable.

          * NO_COMPOSITE-If your layer has vector features, they are preserved
          as KML vectors. If your layer is a raster, you can choose either
          option for this parameter without any visual difference.
      boundary_box_extent {Extent}:
          The geographic extent of the area to be exported. The extent
          rectangle bounds should be specified as a space-delimited string of
          WGS84 geographic coordinates in the form lower left and upper right
          (xmin, ymin, xmax, ymax).
      image_size {Long}:
          Defines the vertical and horizontal resolution when the Return single
          composite image parameter is used. Use this parameter with the DPI
          parameter to control output image resolution.This parameter does not
          provide the ability to resample source
          rasters. Any input rasters will have a snapshot taken and included in
          the KML output as a simple .png image.
      dpi_of_client {Long}:
          Defines the device resolution for KML output when the Return single
          composite image parameter is used. Use this parameter with the
          image_size parameter to control output image resolution.This parameter
          does not provide the ability to resample source
          rasters. Any input rasters will have a snapshot taken and included in
          the KML output as a simple .png image.
      ignore_zvalue {Boolean}:
          * ABSOLUTE-Use the Z-values of features when creating KML. The
          features will be drawn inside KML clients relative to sea level.

          * CLAMPED_TO_GROUND-Override Z-values in your features and create KML
          with the features clamped to the ground. The features will be draped
          over the terrain. This setting is used for features that do not have
          Z-values. This is the default.

     OUTPUTS:
      out_kmz_file (File):
          The KML file to write. This file is compressed and has a .kmz
          extension. It can be read by any KML client including ArcGIS Earth,
          ArcGlobe, and Google Earth."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.LayerToKML_conversion(*gp_fixargs((layer, out_kmz_file, layer_output_scale, is_composite, boundary_box_extent, image_size, dpi_of_client, ignore_zvalue), True)))
        return retval
    except Exception as e:
        raise e


# LAS toolset
@gptooldoc('ConvertLas_conversion', None)
def ConvertLas(in_las=None, target_folder=None, file_version=None, point_format=None, compression=None, las_options=None, out_las_dataset=None):
    """ConvertLas_conversion(in_las, target_folder, {file_version}, {point_format}, {compression}, {las_options;las_options...}, {out_las_dataset})

        Converts LAS files between different compression methods, file
        versions, and point record formats.

     INPUTS:
      in_las (Layer File / LAS Dataset Layer / Folder / File):
          The LAS data that will be converted. A folder can be specified to
          process all of the LAS files contained therein.
      target_folder (Folder):
          The existing folder that the output LAS files will be written to.
      file_version {String}:
          The LAS file version of the output files.

          * SAME_AS_INPUT-The output file version will be the same as the input.
          This is the default.

          * 1.0-The base version for the LAS format which supported 256 class
          codes.

          * 1.1-The output file version will be 1.1. Class codes were reduced to
          32, but support for classification flags was added.

          * 1.2-The output file version will be 1.2. Support for red-green-blue
          (RGB) color channels and GPS time was added.

          * 1.3-The output file version will be 1.3. Storage of lidar waveform
          data for point record formats that are not supported in the ArcGIS
          platform was added.

          * 1.4-The output file version will be 1.4. Support for coordinate
          system definition using Well Known Text (WKT) convention, 256 class
          codes, up to 15 discrete returns per pulse, higher precision scan
          angle, and overlap classification flag was added.
      point_format {String}:
          Specifies the point record format of the output LAS files. The
          available options will vary based on the output LAS file version.

          * 0-The base type for storing discrete LAS points that supports
          attributes such as lidar intensity, return values, scan angle, scan
          direction, and edge of flight line.

          * 1-Adds GPS time to the attributes supported in point format 0.

          * 2-Adds RGB values to the attributes supported in point format 0.

          * 3-Adds RGB values and GPS time to the attributes supported in point
          format 0.

          * 6-The preferred base type for storing discrete LAS points in LAS
          file version 1.4.

          * 7-Adds RGB values to the attributes supported in point format 6.

          * 8-Adds RGB and near-infrared values to the attributes supported in
          point format 6.
      compression {String}:
          Specifies whether the output LAS file will in a compressed format or
          the standard LAS format.

          * NO_COMPRESSION-The output will be in the standard LAS format
          (*.las). This is the default.

          * ZLAS-Output LAS files will be compressed in the zLAS format.

          * LAZ-Output LAS files will be compressed in the LAZ format.
      las_options {String}:
          Specifies modifications that can be made to reduce the size of the
          output LAS files and improve their usability and performance in
          display and analysis operations.

          * REARRANGE_POINTS-Points will be rearranged to improve display and
          analysis performance. Statistics will be automatically computed during
          this process. This option is selected by default.

          * REMOVE_VLR-Variable-length records that are added after the header
          as well as the points records of each file will be removed.

          * REMOVE_EXTRA_BYTES-Extra bytes that may be present with each point
          from the input file will be removed.

     OUTPUTS:
      out_las_dataset {LAS Dataset}:
          The output LAS dataset referencing the newly created LAS files."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ConvertLas_conversion(*gp_fixargs((in_las, target_folder, file_version, point_format, compression, las_options, out_las_dataset), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('LasDatasetToRaster_conversion', None)
def LasDatasetToRaster(in_las_dataset=None, out_raster=None, value_field=None, interpolation_type=None, data_type=None, sampling_type=None, sampling_value=None, z_factor=None):
    """LasDatasetToRaster_conversion(in_las_dataset, out_raster, {value_field}, {interpolation_type}, {data_type}, {sampling_type}, {sampling_value}, {z_factor})

        Creates a raster using elevation, intensity, or RGB values stored in
        the lidar points referenced by the LAS dataset.

     INPUTS:
      in_las_dataset (LAS Dataset Layer):
          The LAS dataset to process.
      value_field {String}:
          The lidar data that will be used to generate the raster output.

          * ELEVATION-Elevation from the lidar files will be used to create the
          raster. This is the default.

          * INTENSITY-Intensity information from the lidar files will be used to
          create the raster.

          * RGB-RGB values from the lidar points will be used to create 3-band
          imagery.
      interpolation_type {Interpolate}:
          The interpolation technique that will be used to determine the cell
          values of the output raster.The binning approach provides a Cell
          Assignment Method for determining
          each output cell using the points that fall within its extent, along
          with a Void Fill Method to determine the value of cells that do not
          contain any LAS points.Cell Assignment Methods

          * AVERAGE-Assigns the average value of all points in the cell. This is
          the default.

          * MINIMUM-Assigns the minimum value found in the points within the
          cell.

          * MAXIMUM-Assigns the maximum value found in the points within the
          cell.

          * IDW-Uses Inverse Distance Weighted interpolation to determine the
          cell value.

          * NEAREST-Uses Nearest Neighbor assignment to determine the cell
          value.
          Void Fill Methods

          * NONE-NoData is assigned to the cell.

          * SIMPLE-Averages the values from data cells immediately surrounding a
          NoData cell to eliminate small voids.

          * LINEAR-Triangulates across void areas and uses linear interpolation
          on the triangulated value to determine the cell value. This is the
          default.

          * NATURAL_NEIGHBOR-Uses natural neighbor interpolation to determine
          the cell value.
          The Triangulation interpolation methods derive cell values using a TIN
          based approach while also offering the opportunity to speed up
          processing time by thinning the sampling of LAS data using the Window
          Size technique.Triangulation Methods

          * Linear-Uses linear interpolation to determine cell values.

          * Natural Neighbors-Uses natural neighbor interpolation to determine
          cell value.
          Window Size Selection Methods

          * Maximum-The point with the highest value in each window size is
          maintained. This is the default.

          * Minimum-The point with the lowest value in each window size is
          maintained.

          * Closest To Mean-The point whose value is closest to the average of
          all point values in the window size is maintained.
      data_type {String}:
          Specifies the type of numeric values stored in the output raster.

          * FLOAT-Output raster will use 32-bit floating point, which supports
          values ranging from -3.402823466e+38 to 3.402823466e+38. This is the
          default.

          * INT-Output raster will use an appropriate integer bit depth. This
          option will round z-values to the nearest whole number and write an
          integer to each raster cell value.
      sampling_type {String}:
          Specifies the method used for interpreting the Sampling Value to
          define the resolution of the output raster.

          * OBSERVATIONS-Defines the number of cells that divide the lengthiest
          side of the LAS dataset extent.

          * CELLSIZE-Defines the cell size of the output raster. This is the
          default.
      sampling_value {Double}:
          Specifies the value used in conjunction with the Sampling Type to
          define the resolution of the output raster.
      z_factor {Double}:
          The factor by which z-values will be multiplied. This is typically
          used to convert Z linear units to match XY linear units. The default
          is 1, which leaves elevation values unchanged. This parameter is
          disabled if the spatial reference of the input surface has a Z datum
          with a specified linear unit.

     OUTPUTS:
      out_raster (Raster Dataset):
          The location and name of the output raster. When storing a raster
          dataset in a geodatabase or in a folder such as an Esri Grid, no file
          extension should be added to the name of the raster dataset. A file
          extension can be provided to define the raster's format when storing
          it in a folder, such as .tif to generate a GeoTIFF or .img to generate
          an ERDAS IMAGINE format file.If the raster is stored as a TIFF file or
          in a geodatabase, its raster
          compression type and quality can be specified using geoprocessing
          environment settings."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.LasDatasetToRaster_conversion(*gp_fixargs((in_las_dataset, out_raster, value_field, interpolation_type, data_type, sampling_type, sampling_value, z_factor), True)))
        return retval
    except Exception as e:
        raise e


# To CAD toolset
@gptooldoc('AddCADFields_conversion', None)
def AddCADFields(input_table=None, Entities=None, LayerProps=None, TextProps=None, DocProps=None, XDataProps=None):
    """AddCADFields_conversion(input_table, Entities, {LayerProps}, {TextProps}, {DocProps}, {XDataProps})

        Adds several reserved CAD fields in one step. Fields created by this
        tool are used by the Export To CAD tool to generate CAD entities with
        specific properties.  After executing this tool, you must calculate or
        type the appropriate field values.

     INPUTS:
      input_table (Table View):
          Input table, feature class, or shapefile that will have the CAD-
          specific fields added to it
      Entities (Boolean):
          Adds the list of CAD-specific Entity property fields to the input
          table

          * ADD_ENTITY_PROPERTIES-Adds the list of CAD-specific Entity property
          fields to the input table

          * NO_ENTITY_PROPERTIES-Does not add the list of CAD-specific Entity
          property fields to the input table
      LayerProps {Boolean}:
          Adds the list of CAD-specific Layer property fields to the input table

          * ADD_LAYER_PROPERTIES-Adds the list of CAD-specific Layer property
          fields to the input table

          * NO_LAYER_PROPERTIES-Does not add the list of CAD-specific Layer
          property fields to the input table
      TextProps {Boolean}:
          Adds the list of CAD-specific Text property fields to the input table

          * ADD_TEXT_PROPERTIES-Adds the list of CAD-specific Text property
          fields to the input table

          * NO_TEXT_PROPERTIES-Does not add the list of CAD-specific Text
          property fields to the input table
      DocProps {Boolean}:
          Adds the list of CAD-specific Document property fields to the input
          table

          * ADD_DOCUMENT_PROPERTIES-Adds the list of CAD-specific Document
          property fields to the input table

          * NO_DOCUMENT_PROPERTIES-Does not add the list of CAD-specific
          Document property fields to the input table
      XDataProps {Boolean}:
          Adds the list of CAD-specific XData property fields to the input table

          * ADD_XDATA_PROPERTIES-Adds the list of CAD-specific XData property
          fields to the input table

          * NO_XDATA_PROPERTIES-Does not add the list of CAD-specific XData
          property fields to the input table"""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddCADFields_conversion(*gp_fixargs((input_table, Entities, LayerProps, TextProps, DocProps, XDataProps), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ExportCAD_conversion', None)
def ExportCAD(in_features=None, Output_Type=None, Output_File=None, Ignore_FileNames=None, Append_To_Existing=None, Seed_File=None):
    """ExportCAD_conversion(in_features;in_features..., Output_Type, Output_File, {Ignore_FileNames}, {Append_To_Existing}, {Seed_File})

        Creates one or more CAD drawings based on the values contained in one
        or more input feature classes or feature layers and supporting tables.

     INPUTS:
      in_features (Feature Layer):
          A collection of feature classes and/or feature layers whose geometry
          will be exported to one or more CAD files.
      Output_Type (String):
          The CAD platform and file version of the output files. This value
          overrides any Output_Type values contained in the keyname column or
          alias column CADFile_type.

          * DGN_V8-Microstation DGN file

          * DWG_R2018-DWG version 2018

          * DWG_R2013-DWG version 2013

          * DWG_R2010-DWG version 2010

          * DWG_R2007-DWG version 2007

          * DWG_R2005-DWG version 2005

          * DWG_R2004-DWG version 2004

          * DWG_R2000-DWG version 2000

          * DWG_R14-DWG version 14

          * DXF_R2018-DXF version 2018

          * DXF_R2013-DXF version 2013

          * DXF_R2010-DXF version 2010

          * DXF_R2007-DXF version 2007

          * DXF_R2005-DXF version 2005

          * DXF_R2004-DXF version 2004

          * DXF_R2000-DXF version 2000

          * DXF_R14-DXF version 14
      Ignore_FileNames {Boolean}:
          Specifies whether the function will ignore or use the paths in the
          DrawingPathName. This allows the function to output CAD entities to
          specific drawings or ignore this and add to one CAD file.

          * Ignore_Filenames_in_Tables-The paths in the document entity fields
          will be ignored and the output of all entities will be added to a
          single CAD file.

          * Use_Filenames_in_Tables-The paths in the document entity fields and
          each entity's path will be used so that each CAD part will be written
          to a separate file. This is the default.
      Append_To_Existing {Boolean}:
          Specifies whether the output will be appended to an existing CAD file.
          This allows you to add information to a CAD file on disk.

          * Append_To_Existing_Files-The output file content will be added to an
          existing output CAD file. The existing CAD file content will not be
          lost.

          * Overwrite_Existing_Files-The output file content will overwrite the
          existing CAD file content. This is the default.
      Seed_File {CAD Drawing Dataset}:
          An existing CAD drawing whose contents and document and layer
          properties will be used for all new output CAD files. The CAD platform
          and format version of the seed file overrides the value specified by
          the Output_Type parameter. If appending to existing CAD files, the
          seed drawing is ignored.

     OUTPUTS:
      Output_File (CAD Drawing Dataset):
          The path of the desired output CAD drawing file. This name overrides
          any drawing name information included in the input features columns or
          alias columns named DrawingPathName."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportCAD_conversion(*gp_fixargs((in_features, Output_Type, Output_File, Ignore_FileNames, Append_To_Existing, Seed_File), True)))
        return retval
    except Exception as e:
        raise e


# To Collada toolset
@gptooldoc('MultipatchToCollada_conversion', None)
def MultipatchToCollada(in_features=None, output_folder=None, prepend_source=None, field_name=None):
    """MultipatchToCollada_conversion(in_features, output_folder, {prepend_source}, {field_name})

        Converts one or more multipatch features into a collection of COLLADA
        (.dae) files and referenced texture image files in an output folder.
        The inputs can be a layer or a feature class.

     INPUTS:
      in_features (Feature Layer):
          The multipatch features to be exported.
      prepend_source {Boolean}:
          Prepend the file names of the output COLLADA files with the name of
          the source feature layer.

          * PREPEND_SOURCE_NAME-Prepend the file names.

          * PREPEND_NONE-Do not prepend the file names. This is the default.
      field_name {Field}:
          The feature attribute to use as the output COLLADA file name for each
          exported feature. If no field is specified, the feature's Object ID is
          used.

     OUTPUTS:
      output_folder (Folder):
          The destination folder where the output COLLADA files and texture
          image files will be placed."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MultipatchToCollada_conversion(*gp_fixargs((in_features, output_folder, prepend_source, field_name), True)))
        return retval
    except Exception as e:
        raise e


# To GeoPackage toolset
@gptooldoc('AddRasterToGeoPackage_conversion', None)
def AddRasterToGeoPackage(in_dataset=None, target_geopackage=None, raster_name=None, tiling_scheme=None, tiling_scheme_file=None, area_of_interest=None):
    """AddRasterToGeoPackage_conversion(in_dataset, target_geopackage, raster_name, {tiling_scheme}, {tiling_scheme_file}, {area_of_interest})

        Load raster datasets into an OGC GeoPackage raster pyramid.

     INPUTS:
      in_dataset (Raster Layer / Mosaic Layer):
          The raster dataset to load into the OGC GeoPackage raster pyramid.
      target_geopackage (Workspace):
          The target GeoPackage.
      raster_name (String):
          The name of the output GeoPackage raster pyramid.
      tiling_scheme {String}:
          The tiling scheme used.

          * TILED-The spatial reference of the input raster will be maintained
          and tiles will be generated consistent with the GeoPackage standard.
          This is the default.

          * ARCGISONLINE_SCHEME-Generate raster tiles in a Web Mercator
          coordinate reference (the same scheme developed for the Army
          Geospatial Center).

          * NSGPROFILE_SCALED_TRANSVERSE_MERCATOR-A scaled transverse Mercator
          is used.

          * NSGPROFILE_WGS84_GEOGRAPHIC-WGS84 Geographic is used.

          * GOOGLE_EARTH_WEB_MERCATOR-Create raster tiles using the parameters
          in the Web Mercator coordinate reference.

          * FROM_FILE-Uses a custom tiling scheme from a file using an XML
          schema definition created using the Generate Tile Cache Tiling Scheme
          tool.
      tiling_scheme_file {File}:
          A custom tiling scheme file that is required when tiling_scheme is
          set to FROM_FILE.
      area_of_interest {Feature Set}:
          Specify an area to limit the area of where you the raster loaded,
          rather than the entire dataset."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddRasterToGeoPackage_conversion(*gp_fixargs((in_dataset, target_geopackage, raster_name, tiling_scheme, tiling_scheme_file, area_of_interest), True)))
        return retval
    except Exception as e:
        raise e


# To Geodatabase toolset
@gptooldoc('BIMFileToGeodatabase_conversion', None)
def BIMFileToGeodatabase(in_bim_file_workspace=None, out_gdb_path=None, out_dataset_name=None, spatial_reference=None, identifier=None):
    """BIMFileToGeodatabase_conversion(in_bim_file_workspace;in_bim_file_workspace..., out_gdb_path, out_dataset_name, {spatial_reference}, {identifier})

        Imports the contents of one or more BIM file workspaces into a
        geodatabase feature dataset.

     INPUTS:
      in_bim_file_workspace (BIM File Workspace):
          The BIM file or files to convert to geodatabase feature classes.
      out_gdb_path (Workspace):
          The geodatabase where the output feature dataset will be created.
          This geodatabase must already exist.
      out_dataset_name (String):
          The building dataset name.
      spatial_reference {Spatial Reference}:
          The spatial reference of the output feature dataset.To control other
          aspects of the spatial reference, such as the x,y-,
          z-, and m- domains, resolutions, and tolerances, set the appropriate
          geoprocessing environments.
      identifier {String}:
          Adds a unique building identifier to all output feature classes, which
          allows you to add unique names for each building to be used at a later
          time."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.BIMFileToGeodatabase_conversion(*gp_fixargs((in_bim_file_workspace, out_gdb_path, out_dataset_name, spatial_reference, identifier), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CADToGeodatabase_conversion', None)
def CADToGeodatabase(input_cad_datasets=None, out_gdb_path=None, out_dataset_name=None, reference_scale=None, spatial_reference=None):
    """CADToGeodatabase_conversion(input_cad_datasets;input_cad_datasets..., out_gdb_path, out_dataset_name, reference_scale, {spatial_reference})

        Reads a CAD dataset and creates feature classes of the drawing. The
        feature classes are written to a geodatabase feature dataset.

     INPUTS:
      input_cad_datasets (CAD Drawing Dataset):
          The collection of CAD files to convert to geodatabase features.
      out_gdb_path (Workspace):
          The geodatabase where the output feature dataset will be created.
          This geodatabase must already exist.
      out_dataset_name (String):
          The name of the feature dataset to be created.
      reference_scale (Double):
          This parameter is not needed for this tool as CAD annotation is
          treated as points in ArcGIS Pro.
      spatial_reference {Spatial Reference}:
          The spatial reference of the output feature dataset. If you wish to
          control other aspects of the spatial reference, such as the xy, z, m
          domains, resolutions, and tolerances, set the appropriate
          geoprocessing environments."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CADToGeodatabase_conversion(*gp_fixargs((input_cad_datasets, out_gdb_path, out_dataset_name, reference_scale, spatial_reference), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ExtractLocationsDocument_conversion', None)
def ExtractLocationsDocument(in_file=None, out_feature_class=None, in_template=None, coord_dd_latlon=None, coord_dd_xydeg=None, coord_dd_xyplain=None, coord_dm_latlon=None, coord_dm_xymin=None, coord_dms_latlon=None, coord_dms_xysec=None, coord_dms_xysep=None, coord_utm=None, coord_ups_north=None, coord_ups_south=None, coord_mgrs=None, coord_mgrs_northpolar=None, coord_mgrs_southpolar=None, comma_decimal=None, coord_use_lonlat=None, in_coor_system=None, in_custom_locations=None, fuzzy_match=None, max_features_extracted=None, ignore_first_features=None, date_monthname=None, date_m_d_y=None, date_yyyymmdd=None, date_yymmdd=None, date_yyjjj=None, max_dates_extracted=None, ignore_first_dates=None, date_range_begin=None, date_range_end=None, in_custom_attributes=None, file_link=None, file_mod_datetime=None, pre_text_length=None, post_text_length=None, std_coord_fmt=None, req_word_breaks=None):
    """ExtractLocationsDocument_conversion(in_file, out_feature_class, {in_template}, {coord_dd_latlon}, {coord_dd_xydeg}, {coord_dd_xyplain}, {coord_dm_latlon}, {coord_dm_xymin}, {coord_dms_latlon}, {coord_dms_xysec}, {coord_dms_xysep}, {coord_utm}, {coord_ups_north}, {coord_ups_south}, {coord_mgrs}, {coord_mgrs_northpolar}, {coord_mgrs_southpolar}, {comma_decimal}, {coord_use_lonlat}, {in_coor_system}, {in_custom_locations}, {fuzzy_match}, {max_features_extracted}, {ignore_first_features}, {date_monthname}, {date_m_d_y}, {date_yyyymmdd}, {date_yymmdd}, {date_yyjjj}, {max_dates_extracted}, {ignore_first_dates}, {date_range_begin}, {date_range_end}, {in_custom_attributes}, {file_link}, {file_mod_datetime}, {pre_text_length}, {post_text_length}, {std_coord_fmt}, {req_word_breaks})

        Analyzes documents containing unstructured or semistructured text,
        such as email messages, travel forms, and so on, and extracts
        locations to a point feature class.The tool analyzes and processes the
        input documents as follows:

        * Recognizes spatial coordinates specified in the content of the
        documents and creates points representing these locations. The
        following coordinate formats are recognized: decimal degrees, degrees
        decimal minutes, degrees minutes seconds, Universal Transverse
        Mercator, and Military Grid Reference System.

        * Recognizes place names specified in the content of the documents
        that are defined in a custom location file and creates points
        representing these locations. A custom location file associates a
        place name with a spatial coordinate representing that location.

        *  Recognizes text that is of interest, extracts this information from
        a document, and records it in fields in the output feature class's
        attribute table.
        This tool supports all Microsoft Office documents (Word, PowerPoint,
        and Excel); Adobe PDF documents; marked-up text such as XML and HTML
        documents; and any files containing plain text such as text files
        (.txt).

     INPUTS:
      in_file (File):
          The input file that will be scanned for locations (coordinates or
          custom locations), dates, and custom attributes; or a folder in which
          all files in the folder will be scanned for locations.
      in_template {File}:
          The template file (*.lxttmpl) that determines the setting to use for
          each tool parameter. When a template file is provided, all values
          specified for other parameters will be ignored except those that
          determine the input content that will be processed and the output
          feature class.Some settings that are available in the Extract
          Locations pane are
          only available to this tool when the settings are saved to a template
          file, and the template file is referenced in this parameter. These
          settings are as follows:

          * Spatial coordinates in x,y format-Allows two sequential numbers such
          as 630084 4833438 or 981075.652ftUS 607151.272ftUS to be recognized as
          coordinates when they are valid for a planar coordinate system
          associated with the input documents. You can specify whether numbers
          with and without units are recognized or only numbers with units of
          measure are recognized as coordinates.

          * Custom coordinate and date formats-Allows you to customize how text
          is recognized as a spatial coordinate or a date, particularly when
          written in a language other than English or using a format that is not
          common in the United States. For example, a spatial coordinate written
          as 30 20 10 N x 060 50 40 W can be recognized with a customization to
          recognize the character x as valid text between the latitude and
          longitude. Coordinates and dates such as 60.91°N, 147.34°O and 17
          juillet, 2018 can be recognized when customizations are specified to
          accommodate the language of the documents, in this case French. Also,
          when two-digit years are used, you can control the range of years to
          which they are matched.

          * Preferences for some ambiguous dates-Dates such as 10/12/2019 are
          ambiguous because they can be interpreted as either October 12, 2019,
          or December 10, 2019. Some countries use the m/d/yy date format as a
          standard, and other countries use the d/m/yy format. A preference can
          be set for how these ambiguous dates are interpreted, either as m/d/yy
          or d/m/yy, to suit the country of origin of the documents.

          * Length of fields in the output feature class-You can specify the
          length of the fields containing text surrounding spatial coordinates
          that are extracted from a document using the Pre-Text Field Length
          (pre_text_length in Python) and Post-Text Field Length
          (post_text_length in Python) parameters. The Extract Locations pane
          allows you to control the length of several additional fields in the
          attribute table, including fields containing dates extracted from the
          document, the original text that was converted to dates, the file name
          from which the information was extracted, and so on.
      coord_dd_latlon {Boolean}:
          Specifies whether to search for coordinates stored as decimal degrees
          formatted as latitude and longitude (infrequent false positives).
          Examples are: 33.8N 77.035W and W77N38.88909.

          * FIND_DD_LATLON-The tool will search for decimal degrees coordinates
          formatted as latitude and longitude. This is the default.

          * DONT_FIND_DD_LATLON-The tool will not search for decimal degrees
          coordinates formatted as latitude and longitude.
      coord_dd_xydeg {Boolean}:
          Specifies whether to search for coordinates stored as decimal degrees
          formatted as X Y with degree symbols (infrequent false positives).
          Examples are: 38.8° -77.035° and -077d+38.88909d.

          * FIND_DD_XYDEG-The tool will search for decimal degrees coordinates
          formatted as X Y with degree symbols. This is the default.

          * DONT_FIND_DD_XYDEG-The tool will not search for decimal degrees
          coordinates formatted as X Y with degree symbols.
      coord_dd_xyplain {Boolean}:
          Specifies whether to search for coordinates stored as decimal degrees
          formatted as X Y with no symbols (frequent false positives). Examples
          are: 38.8 -77.035 and -077.0, +38.88909.

          * FIND_DD_XYPLAIN-The tool will search for decimal degrees coordinates
          formatted as X Y with no symbols (frequent false positives). This is
          the default.

          * DONT_FIND_DD_XYPLAIN-The tool will not search for decimal degrees
          coordinates formatted as X Y with no symbols.
      coord_dm_latlon {Boolean}:
          Specifies whether to search for coordinates stored as degrees decimal
          minutes formatted as latitude and longitude (infrequent false
          positives). Examples are: 3853.3N 7702.100W and W7702N3853.3458.

          * FIND_DM_LATLON-The tool will search for degrees decimal minutes
          coordinates formatted as latitude and longitude. This is the default.

          * DONT_FIND_DM_LATLON-The tool will not search for degrees decimal
          minutes coordinates formatted as latitude and longitude.
      coord_dm_xymin {Boolean}:
          Specifies whether to search for coordinates stored as degrees decimal
          minutes formatted as X Y with minutes symbols (infrequent false
          positives). Examples are: 3853' -7702.1' and -07702m+3853.3458m.

          * FIND_DM_XYMIN-The tool will search for degrees decimal minutes
          coordinates formatted as X Y with minutes symbols. This is the
          default.

          * DONT_FIND_DM_XYMIN-The tool will not search for degrees decimal
          minutes coordinates formatted as X Y with minutes symbols.
      coord_dms_latlon {Boolean}:
          Specifies whether to search for coordinates stored as degrees minutes
          seconds formatted as latitude and longitude (infrequent false
          positives). Examples are: 385320.7N 770206.000W and W770206N385320.76.

          * FIND_DMS_LATLON-The tool will search for degrees minutes seconds
          coordinates formatted as latitude and longitude. This is the default.

          * DONT_FIND_DMS_LATLON-The tool will not search for degrees minutes
          seconds coordinates formatted as latitude and longitude.
      coord_dms_xysec {Boolean}:
          Specifies whether to search for coordinates stored as degrees minutes
          seconds formatted as X Y with seconds symbols (infrequent false
          positives). Examples are: 385320" -770206.0" and
          -0770206.0s+385320.76s.

          * FIND_DMS_XYSEC-The tool will search for degrees minutes seconds
          coordinates formatted as X Y with seconds symbols. This is the
          default.

          * DONT_FIND_DMS_XYSEC-The tool will not search for degrees minutes
          seconds coordinates formatted as X Y with seconds symbols.
      coord_dms_xysep {Boolean}:
          Specifies whether to search for coordinates stored as degrees minutes
          seconds formatted as X Y with separators (moderate false positives).
          Examples are: 8:53:20 -77:2:6.0 and -077/02/06/+38/53/20.76.

          * FIND_DMS_XYSEP-The tool will search for degrees minutes seconds
          coordinates formatted as X Y with separators. This is the default.

          * DONT_FIND_DMS_XYSEP-The tool will not search for degrees minutes
          seconds coordinates formatted as X Y with separators.
      coord_utm {Boolean}:
          Specifies whether to search for Universal Transverse Mercator (UTM)
          coordinates (infrequent false positives). Examples are: 18S 323503
          4306438 and 18 north 323503.25 4306438.39.

          * FIND_UTM_MAINWORLD-The tool will search for UTM coordinates. This is
          the default.

          * DONT_FIND_UTM_MAINWORLD-The tool will not search for UTM
          coordinates.
      coord_ups_north {Boolean}:
          Specifies whether to search for Universal Polar Stereographic (UPS)
          coordinates in the north polar area (infrequent false positives).
          Examples are: Y 2722399 2000000 and north 2722399 2000000.

          * FIND_UTM_NORTHPOLAR-The tool will search for UPS coordinates in the
          north polar area. This is the default.

          * DONT_FIND_UTM_NORTHPOLAR-The tool will not search for UPS
          coordinates in the north polar area.
      coord_ups_south {Boolean}:
          Specifies whether to search for Universal Polar Stereographic (UPS)
          coordinates in the south polar area (infrequent false positives).
          Examples are: A 2000000 3168892 and south 2000000 3168892.

          * FIND_UTM_SOUTHPOLAR-The tool will search for UPS coordinates in the
          south polar area. This is the default.

          * DONT_FIND_UTM_SOUTHPOLAR-The tool will not search for UPS
          coordinates in the south polar area.
      coord_mgrs {Boolean}:
          Specifies whether to search for Military Grid Reference System (MGRS)
          coordinates (infrequent false positives). Examples are: 18S UJ 13503
          06438 and 18SUJ0306.

          * FIND_MGRS_MAINWORLD-The tool will search for MGRS coordinates. This
          is the default.

          * DONT_FIND_MGRS_MAINWORLD-The tool will not search for MGRS
          coordinates.
      coord_mgrs_northpolar {Boolean}:
          Specifies whether to search for Military Grid Reference System (MGRS)
          coordinates in the north polar area (infrequent false positives).
          Examples are: Y TG 56814 69009 and YTG5669.

          * FIND_MGRS_NORTHPOLAR-The tool will search for MGRS coordinates in
          the north polar area. This is the default.

          * DONT_FIND_MGRS_NORTHPOLAR-The tool will not search for MGRS
          coordinates in the north polar area.
      coord_mgrs_southpolar {Boolean}:
          Specifies whether to search for Military Grid Reference System (MGRS)
          coordinates in the south polar area (moderate false positives).
          Examples are: A TN 56814 30991 and ATN5630.

          * FIND_MGRS_SOUTHPOLAR-The tool will search for MGRS coordinates in
          the south polar area. This is the default.

          * DONT_FIND_MGRS_SOUTHPOLAR-The tool will not search for MGRS
          coordinates in the south polar area.
      comma_decimal {Boolean}:
          Specifies whether a comma (,) will be recognized as a decimal
          separator. By default, content is scanned for spatial coordinates
          defined by numbers that use a period (.) or a middle dot (·) as the
          decimal separator, for example: Lat 01° 10·80' N Long 103° 28·60' E.
          If you are working with content in which spatial coordinates are
          defined by numbers that use a comma (,) as the decimal separator, for
          example: 52° 8′ 32,14″ N; 5° 24′ 56,09″ E, set this parameter to
          recognize a comma as the decimal separator instead. This parameter is
          not set automatically based on the regional setting for your
          computer's operating system.

          * USE_COMMA_DECIMAL_MARK-A comma will be recognized as the decimal
          separator.

          * USE_DOT_DECIMAL_MARK-A period or a middle dot will be recognized as
          the decimal separator. This is the default.
      coord_use_lonlat {Boolean}:
          When numbers resemble x,y coordinates, both numbers are less than 90,
          and there are no symbols or notations to indicate which number
          represents the latitude or longitude, results can be ambiguous.
          Interpret the numbers as a longitude-latitude coordinate (x,y) instead
          of a latitude-longitude coordinate (y,x).

          * PREFER_LONLAT-x,y coordinates will be interpreted as longitude-
          latitude.

          * PREFER_LATLON-x,y coordinates will be interpreted as latitude-
          longitude. This is the default.
      in_coor_system {Spatial Reference}:
          The coordinate system that will be used to interpret the spatial
          coordinates defined in the input. GCS-WGS-84 is the default.
      in_custom_locations {File}:
          The custom location file (.lxtgaz) that will be used when scanning the
          input content. A point is created to represent each occurrence of each
          place name in the custom location file up to the limits established by
          other tool parameters.
      fuzzy_match {Boolean}:
          Specifies whether fuzzy matching will be used for searching the custom
          location file.

          * USE_FUZZY-Fuzzy matching will be used when searching the custom
          location file.

          * DONT_USE_FUZZY-Exact matching will be used when searching the custom
          location file. This is the default.
      max_features_extracted {Long}:
          The maximum number of features that can be extracted. The tool will
          stop scanning the input content for locations when the maximum number
          is reached. When running as a geoprocessing service, the service and
          the server may have separate limits on the number of features allowed.
      ignore_first_features {Long}:
          The number of features detected and ignored before extracting all
          other features. This parameter can be used to focus the search on a
          specific portion of the data.
      date_monthname {Boolean}:
          Specifies whether to search for dates in which the month name appears
          (infrequent false positives). 12 May 2003 and January 15, 1997 are
          examples.

          * FIND_DATE_MONTHNAME-The tool will search for dates in which the
          month name appears. This is the default.

          * DONT_FIND_DATE_MONTHNAME-The tool will not search for dates in which
          the month name appears.
      date_m_d_y {Boolean}:
          Specifies whether to search for dates in which numbers are in the
          M/D/Y or D/M/Y format (moderate false positives). 5/12/03 and
          1-15-1997 are examples.

          * FIND_DATE_M_D_Y-The tool will search for dates in which numbers are
          in the M/D/Y or D/M/Y format (moderate false positives). This is the
          default.

          * DONT_FIND_DATE_M_D_Y-The tool will not search for dates in which
          numbers are in the M/D/Y or D/M/Y format.
      date_yyyymmdd {Boolean}:
          Specifies whether to search for dates in which numbers are in the
          YYYYMMDD format (moderate false positives). 20030512 and 19970115 are
          examples.

          * FIND_DATE_YYYYMMDD-The tool will search for dates in which numbers
          are in the YYYYMMDD format (moderate false positives). This is the
          default.

          * DONT_FIND_DATE_YYYYMMDD-The tool will not search for dates in which
          numbers are in the YYYYMMDD format.
      date_yymmdd {Boolean}:
          Specifies whether to search for dates in which numbers are in the
          YYMMDD format (frequent false positives). 030512 and 970115 are
          examples.

          * FIND_DATE_YYMMDD-The tool will search for dates in which numbers are
          in the YYMMDD format (frequent false positives). This is the default.

          * DONT_FIND_DATE_YYMMDD-The tool will not search for dates in which
          numbers are in the YYMMDD format.
      date_yyjjj {Boolean}:
          Specifies whether to search for dates in which numbers are in the
          YYJJJ or YYYYJJJ format (frequent false positives). 03132 and 97015
          are examples.

          * FIND_DATE_YYJJJ-The tool will search for dates in which numbers are
          in the YYJJJ or YYYYJJJ format (frequent false positives). This is the
          default.

          * DONT_FIND_DATE_YYJJJ-The tool will not search for dates in which
          numbers are in the YYJJJ or YYYYJJJ format.
      max_dates_extracted {Long}:
          The maximum number of dates that will be extracted.
      ignore_first_dates {Long}:
          The number of dates that will be detected and ignored before
          extracting all other dates.
      date_range_begin {Date}:
          The earliest acceptable date to extract. Detected dates matching this
          value or later will be extracted.
      date_range_end {Date}:
          The latest acceptable date to extract. Detected dates matching this
          value or earlier will be extracted.
      in_custom_attributes {File}:
          The custom attribute file (.lxtca) that will be used to scan the input
          content. Fields will be created in the output feature class's
          attribute table for all custom attributes defined in the file. When
          the input content is scanned, it will be examined to see if it
          contains text associated with all custom attributes specified in the
          file. When a match is found, the appropriate text is extracted from
          the input content and stored in the appropriate field.
      file_link {String}:
          The file path that will be used as the file name in the output data
          when the Input File parameter (in_file in Python) is transferred to
          the server. If this parameter is not specified, the path of the Input
          File will be used, which may be an unreachable folder on a server.
          This parameter has no effect when the Input File is not specified.
      file_mod_datetime {Date}:
          The UTC date and time that the file was modified will be used as the
          modified attribute in the output data when the Input File parameter
          (in_file in Python) is transferred to the server. If this parameter is
          not specified, the current modified time of the input file will be
          used. This parameter has no effect when the Input File is not
          specified.
      pre_text_length {Long}:
          Content is extracted from the input document to provide context for
          the location that was found. This parameter defines the maximum number
          of characters that will be extracted preceding the text that defines
          the location. The extracted text is stored in the Pre-Text field in
          the output feature class's attribute table. The default is 254. The
          Pre-Text field's data type will also have this length. The length of a
          text field in a shapefile is limited to 254 characters; when the
          output is a shapefile, a larger number of characters will be truncated
          to 254.
      post_text_length {Long}:
          Content is extracted from the input document to provide context for
          the location that was found. This parameter defines the maximum number
          of characters that will be extracted following the text that defines
          the location. The extracted text is stored in the Post-Text field in
          the output feature class's attribute table. The default is 254. The
          Post-Text field's data type will also have this length. The length of
          a text field in a shapefile is limited to 254 characters; when the
          output is a shapefile, a larger number of characters will be truncated
          to 254.
      std_coord_fmt {String}:
          Specifies the coordinate format that will be used to store the
          coordinate location. A standard representation of the spatial
          coordinate that defines the point feature is recorded in a field in
          the attribute table.

          * STD_COORD_FMT_DD-The coordinate location is recorded in decimal
          degrees format. This is the default.

          * STD_COORD_FMT_DM-The coordinate location is recorded in degrees
          decimal minutes format.

          * STD_COORD_FMT_DMS-The coordinate location is recorded in degrees
          minutes seconds format.

          * STD_COORD_FMT_UTM-The coordinate location is recorded in Universal
          Transverse Mercator format.

          * STD_COORD_FMT_MGRS-The coordinate location is recorded in Military
          Grid Reference System format.
      req_word_breaks {Boolean}:
          Specifies whether to search for text using word breaks. A word break
          occurs when words (text) are bounded by whitespace or punctuation
          characters as in European languages.This setting can produce frequent
          false positives or infrequent false
          positives depending on the language of the text. For example, when
          word breaks are not required, the English text Bernard will produce a
          match against the text San Bernardino, which would likely be
          considered a false positive. However, when text is written using a
          language that does not use word breaks, you cannot find words if word
          breaks are required. For example, with the text I flew to Tokyo in
          Japanese, 私は東京に飛んで, you would only be able to find the word Tokyo, 東京,
          when word breaks are not required.

          * REQ_WORD_BREAKS-The tool will search for words that are bounded by
          whitespace or punctuation characters. This is the default.

          * DONT_REQ_WORD_BREAKS-The tool will not search for words that are
          bounded by whitespace or punctuation characters.

     OUTPUTS:
      out_feature_class (Feature Class):
          The feature class containing point features that represent the
          locations that were found."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExtractLocationsDocument_conversion(*gp_fixargs((in_file, out_feature_class, in_template, coord_dd_latlon, coord_dd_xydeg, coord_dd_xyplain, coord_dm_latlon, coord_dm_xymin, coord_dms_latlon, coord_dms_xysec, coord_dms_xysep, coord_utm, coord_ups_north, coord_ups_south, coord_mgrs, coord_mgrs_northpolar, coord_mgrs_southpolar, comma_decimal, coord_use_lonlat, in_coor_system, in_custom_locations, fuzzy_match, max_features_extracted, ignore_first_features, date_monthname, date_m_d_y, date_yyyymmdd, date_yymmdd, date_yyjjj, max_dates_extracted, ignore_first_dates, date_range_begin, date_range_end, in_custom_attributes, file_link, file_mod_datetime, pre_text_length, post_text_length, std_coord_fmt, req_word_breaks), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ExtractLocationsText_conversion', None)
def ExtractLocationsText(in_text=None, out_feature_class=None, in_template=None, coord_dd_latlon=None, coord_dd_xydeg=None, coord_dd_xyplain=None, coord_dm_latlon=None, coord_dm_xymin=None, coord_dms_latlon=None, coord_dms_xysec=None, coord_dms_xysep=None, coord_utm=None, coord_ups_north=None, coord_ups_south=None, coord_mgrs=None, coord_mgrs_northpolar=None, coord_mgrs_southpolar=None, comma_decimal=None, coord_use_lonlat=None, in_coor_system=None, in_custom_locations=None, fuzzy_match=None, max_features_extracted=None, ignore_first_features=None, date_monthname=None, date_m_d_y=None, date_yyyymmdd=None, date_yymmdd=None, date_yyjjj=None, max_dates_extracted=None, ignore_first_dates=None, date_range_begin=None, date_range_end=None, in_custom_attributes=None, file_link=None, file_mod_datetime=None, pre_text_length=None, post_text_length=None, std_coord_fmt=None, req_word_breaks=None):
    """ExtractLocationsText_conversion(in_text, out_feature_class, {in_template}, {coord_dd_latlon}, {coord_dd_xydeg}, {coord_dd_xyplain}, {coord_dm_latlon}, {coord_dm_xymin}, {coord_dms_latlon}, {coord_dms_xysec}, {coord_dms_xysep}, {coord_utm}, {coord_ups_north}, {coord_ups_south}, {coord_mgrs}, {coord_mgrs_northpolar}, {coord_mgrs_southpolar}, {comma_decimal}, {coord_use_lonlat}, {in_coor_system}, {in_custom_locations}, {fuzzy_match}, {max_features_extracted}, {ignore_first_features}, {date_monthname}, {date_m_d_y}, {date_yyyymmdd}, {date_yymmdd}, {date_yyjjj}, {max_dates_extracted}, {ignore_first_dates}, {date_range_begin}, {date_range_end}, {in_custom_attributes}, {file_link}, {file_mod_datetime}, {pre_text_length}, {post_text_length}, {std_coord_fmt}, {req_word_breaks})

        Analyzes input text or a text file and extracts locations to a point
        feature class If the input text is a file path, the identified file
        will be opened
        and its content will be analyzed. If the input text is unstructured
        information such as an email message, or semistructured text such as a
        travel forms, the input text itself will be analyzed. The tool
        extracts locations found in the text or in the content of the file and
        adds the resulting points to a feature class.The tool analyzes and
        processes the text as follows:

        * Recognizes spatial coordinates specified in the content of the text
        and creates points representing these locations. The following
        coordinate formats are recognized: decimal degrees, degrees decimal
        minutes, degrees minutes seconds, Universal Transverse Mercator, and
        Military Grid Reference System.

        * Recognizes place names specified in the text that are defined in a
        custom location file and creates points representing these locations.
        A custom location file associates a place name with a spatial
        coordinate representing that location.

        *  Recognizes text that is of interest, extracts this information from
        the text provided, and records it in fields in the output feature
        class's attribute table.

     INPUTS:
      in_text (String):
          The text that will be scanned for locations (coordinates or custom
          locations), dates, and custom attributes; or text defining a file
          path, whose contents will be scanned for locations. For geoprocessing
          services, when a file path is provided, the file must be accessible
          from the service, as the file is not transferred to the server.
      in_template {File}:
          The template file (*.lxttmpl) that determines the setting to use for
          each tool parameter. When a template file is provided, all values
          specified for other parameters will be ignored except those that
          determine the input content that will be processed and the output
          feature class.Some settings that are available in the Extract
          Locations pane are
          only available to this tool when the settings are saved to a template
          file, and the template file is referenced in this parameter. These
          settings are as follows:

          * Spatial coordinates in x,y format-Allows two sequential numbers such
          as 630084 4833438 or 981075.652ftUS 607151.272ftUS to be recognized as
          coordinates when they are valid for a planar coordinate system
          associated with the input documents. You can specify whether numbers
          with and without units are recognized or only numbers with units of
          measure are recognized as coordinates.

          * Custom coordinate and date formats-Allows you to customize how text
          is recognized as a spatial coordinate or a date, particularly when
          written in a language other than English or using a format that is not
          common in the United States. For example, a spatial coordinate written
          as 30 20 10 N x 060 50 40 W can be recognized with a customization to
          recognize the character x as valid text between the latitude and
          longitude. Coordinates and dates such as 60.91°N, 147.34°O and 17
          juillet, 2018 can be recognized when customizations are specified to
          accommodate the language of the documents, in this case French. Also,
          when two-digit years are used, you can control the range of years to
          which they are matched.

          * Preferences for some ambiguous dates-Dates such as 10/12/2019 are
          ambiguous because they can be interpreted as either October 12, 2019,
          or December 10, 2019. Some countries use the m/d/yy date format as a
          standard, and other countries use the d/m/yy format. A preference can
          be set for how these ambiguous dates are interpreted, either as m/d/yy
          or d/m/yy, to suit the country of origin of the documents.

          * Length of fields in the output feature class-You can specify the
          length of the fields containing text surrounding spatial coordinates
          that are extracted from a document using the Pre-Text Field Length
          (pre_text_length in Python) and Post-Text Field Length
          (post_text_length in Python) parameters. The Extract Locations pane
          allows you to control the length of several additional fields in the
          attribute table, including fields containing dates extracted from the
          document, the original text that was converted to dates, the file name
          from which the information was extracted, and so on.
      coord_dd_latlon {Boolean}:
          Specifies whether to search for coordinates stored as decimal degrees
          formatted as latitude and longitude (infrequent false positives).
          Examples are: 33.8N 77.035W and W77N38.88909.

          * FIND_DD_LATLON-The tool will search for decimal degrees coordinates
          formatted as latitude and longitude. This is the default.

          * DONT_FIND_DD_LATLON-The tool will not search for decimal degrees
          coordinates formatted as latitude and longitude.
      coord_dd_xydeg {Boolean}:
          Specifies whether to search for coordinates stored as decimal degrees
          formatted as X Y with degree symbols (infrequent false positives).
          Examples are: 38.8° -77.035° and -077d+38.88909d.

          * FIND_DD_XYDEG-The tool will search for decimal degrees coordinates
          formatted as X Y with degree symbols. This is the default.

          * DONT_FIND_DD_XYDEG-The tool will not search for decimal degrees
          coordinates formatted as X Y with degree symbols.
      coord_dd_xyplain {Boolean}:
          Specifies whether to search for coordinates stored as decimal degrees
          formatted as X Y with no symbols (frequent false positives). Examples
          are: 38.8 -77.035 and -077.0, +38.88909.

          * FIND_DD_XYPLAIN-The tool will search for decimal degrees coordinates
          formatted as X Y with no symbols (frequent false positives). This is
          the default.

          * DONT_FIND_DD_XYPLAIN-The tool will not search for decimal degrees
          coordinates formatted as X Y with no symbols.
      coord_dm_latlon {Boolean}:
          Specifies whether to search for coordinates stored as degrees decimal
          minutes formatted as latitude and longitude (infrequent false
          positives). Examples are: 3853.3N 7702.100W and W7702N3853.3458.

          * FIND_DM_LATLON-The tool will search for degrees decimal minutes
          coordinates formatted as latitude and longitude. This is the default.

          * DONT_FIND_DM_LATLON-The tool will not search for degrees decimal
          minutes coordinates formatted as latitude and longitude.
      coord_dm_xymin {Boolean}:
          Specifies whether to search for coordinates stored as degrees decimal
          minutes formatted as X Y with minutes symbols (infrequent false
          positives). Examples are: 3853' -7702.1' and -07702m+3853.3458m.

          * FIND_DM_XYMIN-The tool will search for degrees decimal minutes
          coordinates formatted as X Y with minutes symbols. This is the
          default.

          * DONT_FIND_DM_XYMIN-The tool will not search for degrees decimal
          minutes coordinates formatted as X Y with minutes symbols.
      coord_dms_latlon {Boolean}:
          Specifies whether to search for coordinates stored as degrees minutes
          seconds formatted as latitude and longitude (infrequent false
          positives). Examples are: 385320.7N 770206.000W and W770206N385320.76.

          * FIND_DMS_LATLON-The tool will search for degrees minutes seconds
          coordinates formatted as latitude and longitude. This is the default.

          * DONT_FIND_DMS_LATLON-The tool will not search for degrees minutes
          seconds coordinates formatted as latitude and longitude.
      coord_dms_xysec {Boolean}:
          Specifies whether to search for coordinates stored as degrees minutes
          seconds formatted as X Y with seconds symbols (infrequent false
          positives). Examples are: 385320" -770206.0" and
          -0770206.0s+385320.76s.

          * FIND_DMS_XYSEC-The tool will search for degrees minutes seconds
          coordinates formatted as X Y with seconds symbols. This is the
          default.

          * DONT_FIND_DMS_XYSEC-The tool will not search for degrees minutes
          seconds coordinates formatted as X Y with seconds symbols.
      coord_dms_xysep {Boolean}:
          Specifies whether to search for coordinates stored as degrees minutes
          seconds formatted as X Y with separators (moderate false positives).
          Examples are: 8:53:20 -77:2:6.0 and -077/02/06/+38/53/20.76.

          * FIND_DMS_XYSEP-The tool will search for degrees minutes seconds
          coordinates formatted as X Y with separators. This is the default.

          * DONT_FIND_DMS_XYSEP-The tool will not search for degrees minutes
          seconds coordinates formatted as X Y with separators.
      coord_utm {Boolean}:
          Specifies whether to search for Universal Transverse Mercator (UTM)
          coordinates (infrequent false positives). Examples are: 18S 323503
          4306438 and 18 north 323503.25 4306438.39.

          * FIND_UTM_MAINWORLD-The tool will search for UTM coordinates. This is
          the default.

          * DONT_FIND_UTM_MAINWORLD-The tool will not search for UTM
          coordinates.
      coord_ups_north {Boolean}:
          Specifies whether to search for Universal Polar Stereographic (UPS)
          coordinates in the north polar area (infrequent false positives).
          Examples are: Y 2722399 2000000 and north 2722399 2000000.

          * FIND_UTM_NORTHPOLAR-The tool will search for UPS coordinates in the
          north polar area. This is the default.

          * DONT_FIND_UTM_NORTHPOLAR-The tool will not search for UPS
          coordinates in the north polar area.
      coord_ups_south {Boolean}:
          Specifies whether to search for Universal Polar Stereographic (UPS)
          coordinates in the south polar area (infrequent false positives).
          Examples are: A 2000000 3168892 and south 2000000 3168892.

          * FIND_UTM_SOUTHPOLAR-The tool will search for UPS coordinates in the
          south polar area. This is the default.

          * DONT_FIND_UTM_SOUTHPOLAR-The tool will not search for UPS
          coordinates in the south polar area.
      coord_mgrs {Boolean}:
          Specifies whether to search for Military Grid Reference System (MGRS)
          coordinates (infrequent false positives). Examples are: 18S UJ 13503
          06438 and 18SUJ0306.

          * FIND_MGRS_MAINWORLD-The tool will search for MGRS coordinates. This
          is the default.

          * DONT_FIND_MGRS_MAINWORLD-The tool will not search for MGRS
          coordinates.
      coord_mgrs_northpolar {Boolean}:
          Specifies whether to search for Military Grid Reference System (MGRS)
          coordinates in the north polar area (infrequent false positives).
          Examples are: Y TG 56814 69009 and YTG5669.

          * FIND_MGRS_NORTHPOLAR-The tool will search for MGRS coordinates in
          the north polar area. This is the default.

          * DONT_FIND_MGRS_NORTHPOLAR-The tool will not search for MGRS
          coordinates in the north polar area.
      coord_mgrs_southpolar {Boolean}:
          Specifies whether to search for Military Grid Reference System (MGRS)
          coordinates in the south polar area (moderate false positives).
          Examples are: A TN 56814 30991 and ATN5630.

          * FIND_MGRS_SOUTHPOLAR-The tool will search for MGRS coordinates in
          the south polar area. This is the default.

          * DONT_FIND_MGRS_SOUTHPOLAR-The tool will not search for MGRS
          coordinates in the south polar area.
      comma_decimal {Boolean}:
          Specifies whether a comma (,) will be recognized as a decimal
          separator. By default, content is scanned for spatial coordinates
          defined by numbers that use a period (.) or a middle dot (·) as the
          decimal separator, for example: Lat 01° 10·80' N Long 103° 28·60' E.
          If you are working with content in which spatial coordinates are
          defined by numbers that use a comma (,) as the decimal separator, for
          example: 52° 8′ 32,14″ N; 5° 24′ 56,09″ E, set this parameter to
          recognize a comma as the decimal separator instead. This parameter is
          not set automatically based on the regional setting for your
          computer's operating system.

          * USE_COMMA_DECIMAL_MARK-A comma will be recognized as the decimal
          separator.

          * USE_DOT_DECIMAL_MARK-A period or a middle dot will be recognized as
          the decimal separator. This is the default.
      coord_use_lonlat {Boolean}:
          When numbers resemble x,y coordinates, both numbers are less than 90,
          and there are no symbols or notations to indicate which number
          represents the latitude or longitude, results can be ambiguous.
          Interpret the numbers as a longitude-latitude coordinate (x,y) instead
          of a latitude-longitude coordinate (y,x).

          * PREFER_LONLAT-x,y coordinates will be interpreted as longitude-
          latitude.

          * PREFER_LATLON-x,y coordinates will be interpreted as latitude-
          longitude. This is the default.
      in_coor_system {Spatial Reference}:
          The coordinate system that will be used to interpret the spatial
          coordinates defined in the input. GCS-WGS-84 is the default.
      in_custom_locations {File}:
          The custom location file (.lxtgaz) that will be used when scanning the
          input content. A point is created to represent each occurrence of each
          place name in the custom location file up to the limits established by
          other tool parameters.
      fuzzy_match {Boolean}:
          Specifies whether fuzzy matching will be used for searching the custom
          location file.

          * USE_FUZZY-Fuzzy matching will be used when searching the custom
          location file.

          * DONT_USE_FUZZY-Exact matching will be used when searching the custom
          location file. This is the default.
      max_features_extracted {Long}:
          The maximum number of features that can be extracted. The tool will
          stop scanning the input content for locations when the maximum number
          is reached. When running as a geoprocessing service, the service and
          the server may have separate limits on the number of features allowed.
      ignore_first_features {Long}:
          The number of features detected and ignored before extracting all
          other features. This parameter can be used to focus the search on a
          specific portion of the data.
      date_monthname {Boolean}:
          Specifies whether to search for dates in which the month name appears
          (infrequent false positives). 12 May 2003 and January 15, 1997 are
          examples.

          * FIND_DATE_MONTHNAME-The tool will search for dates in which the
          month name appears. This is the default.

          * DONT_FIND_DATE_MONTHNAME-The tool will not search for dates in which
          the month name appears.
      date_m_d_y {Boolean}:
          Specifies whether to search for dates in which numbers are in the
          M/D/Y or D/M/Y format (moderate false positives). 5/12/03 and
          1-15-1997 are examples.

          * FIND_DATE_M_D_Y-The tool will search for dates in which numbers are
          in the M/D/Y or D/M/Y format (moderate false positives). This is the
          default.

          * DONT_FIND_DATE_M_D_Y-The tool will not search for dates in which
          numbers are in the M/D/Y or D/M/Y format.
      date_yyyymmdd {Boolean}:
          Specifies whether to search for dates in which numbers are in the
          YYYYMMDD format (moderate false positives). 20030512 and 19970115 are
          examples.

          * FIND_DATE_YYYYMMDD-The tool will search for dates in which numbers
          are in the YYYYMMDD format (moderate false positives). This is the
          default.

          * DONT_FIND_DATE_YYYYMMDD-The tool will not search for dates in which
          numbers are in the YYYYMMDD format.
      date_yymmdd {Boolean}:
          Specifies whether to search for dates in which numbers are in the
          YYMMDD format (frequent false positives). 030512 and 970115 are
          examples.

          * FIND_DATE_YYMMDD-The tool will search for dates in which numbers are
          in the YYMMDD format (frequent false positives). This is the default.

          * DONT_FIND_DATE_YYMMDD-The tool will not search for dates in which
          numbers are in the YYMMDD format.
      date_yyjjj {Boolean}:
          Specifies whether to search for dates in which numbers are in the
          YYJJJ or YYYYJJJ format (frequent false positives). 03132 and 97015
          are examples.

          * FIND_DATE_YYJJJ-The tool will search for dates in which numbers are
          in the YYJJJ or YYYYJJJ format (frequent false positives). This is the
          default.

          * DONT_FIND_DATE_YYJJJ-The tool will not search for dates in which
          numbers are in the YYJJJ or YYYYJJJ format.
      max_dates_extracted {Long}:
          The maximum number of dates that will be extracted.
      ignore_first_dates {Long}:
          The number of dates that will be detected and ignored before
          extracting all other dates.
      date_range_begin {Date}:
          The earliest acceptable date to extract. Detected dates matching this
          value or later will be extracted.
      date_range_end {Date}:
          The latest acceptable date to extract. Detected dates matching this
          value or earlier will be extracted.
      in_custom_attributes {File}:
          The custom attribute file (.lxtca) that will be used to scan the input
          content. Fields will be created in the output feature class's
          attribute table for all custom attributes defined in the file. When
          the input content is scanned, it will be examined to see if it
          contains text associated with all custom attributes specified in the
          file. When a match is found, the appropriate text is extracted from
          the input content and stored in the appropriate field.
      file_link {String}:
          The file path that will be used as the file name in the output data
          when the Input File parameter (in_file in Python) is transferred to
          the server. If this parameter is not specified, the path of the Input
          File will be used, which may be an unreachable folder on a server.
          This parameter has no effect when the Input File is not specified.
      file_mod_datetime {Date}:
          The UTC date and time that the file was modified will be used as the
          modified attribute in the output data when the Input File parameter
          (in_file in Python) is transferred to the server. If this parameter is
          not specified, the current modified time of the input file will be
          used. This parameter has no effect when the Input File is not
          specified.
      pre_text_length {Long}:
          Content is extracted from the input document to provide context for
          the location that was found. This parameter defines the maximum number
          of characters that will be extracted preceding the text that defines
          the location. The extracted text is stored in the Pre-Text field in
          the output feature class's attribute table. The default is 254. The
          Pre-Text field's data type will also have this length. The length of a
          text field in a shapefile is limited to 254 characters; when the
          output is a shapefile, a larger number of characters will be truncated
          to 254.
      post_text_length {Long}:
          Content is extracted from the input document to provide context for
          the location that was found. This parameter defines the maximum number
          of characters that will be extracted following the text that defines
          the location. The extracted text is stored in the Post-Text field in
          the output feature class's attribute table. The default is 254. The
          Post-Text field's data type will also have this length. The length of
          a text field in a shapefile is limited to 254 characters; when the
          output is a shapefile, a larger number of characters will be truncated
          to 254.
      std_coord_fmt {String}:
          Specifies the coordinate format that will be used to store the
          coordinate location. A standard representation of the spatial
          coordinate that defines the point feature is recorded in a field in
          the attribute table.

          * STD_COORD_FMT_DD-The coordinate location is recorded in decimal
          degrees format. This is the default.

          * STD_COORD_FMT_DM-The coordinate location is recorded in degrees
          decimal minutes format.

          * STD_COORD_FMT_DMS-The coordinate location is recorded in degrees
          minutes seconds format.

          * STD_COORD_FMT_UTM-The coordinate location is recorded in Universal
          Transverse Mercator format.

          * STD_COORD_FMT_MGRS-The coordinate location is recorded in Military
          Grid Reference System format.
      req_word_breaks {Boolean}:
          Specifies whether to search for text using word breaks. A word break
          occurs when words (text) are bounded by whitespace or punctuation
          characters as in European languages.This setting can produce frequent
          false positives or infrequent false
          positives depending on the language of the text. For example, when
          word breaks are not required, the English text Bernard will produce a
          match against the text San Bernardino, which would likely be
          considered a false positive. However, when text is written using a
          language that does not use word breaks, you cannot find words if word
          breaks are required. For example, with the text I flew to Tokyo in
          Japanese, 私は東京に飛んで, you would only be able to find the word Tokyo, 東京,
          when word breaks are not required.

          * REQ_WORD_BREAKS-The tool will search for words that are bounded by
          whitespace or punctuation characters. This is the default.

          * DONT_REQ_WORD_BREAKS-The tool will not search for words that are
          bounded by whitespace or punctuation characters.

     OUTPUTS:
      out_feature_class (Feature Class):
          The feature class containing point features that represent the
          locations that were found."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExtractLocationsText_conversion(*gp_fixargs((in_text, out_feature_class, in_template, coord_dd_latlon, coord_dd_xydeg, coord_dd_xyplain, coord_dm_latlon, coord_dm_xymin, coord_dms_latlon, coord_dms_xysec, coord_dms_xysep, coord_utm, coord_ups_north, coord_ups_south, coord_mgrs, coord_mgrs_northpolar, coord_mgrs_southpolar, comma_decimal, coord_use_lonlat, in_coor_system, in_custom_locations, fuzzy_match, max_features_extracted, ignore_first_features, date_monthname, date_m_d_y, date_yyyymmdd, date_yymmdd, date_yyjjj, max_dates_extracted, ignore_first_dates, date_range_begin, date_range_end, in_custom_attributes, file_link, file_mod_datetime, pre_text_length, post_text_length, std_coord_fmt, req_word_breaks), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FeatureClassToFeatureClass_conversion', None)
def FeatureClassToFeatureClass(in_features=None, out_path=None, out_name=None, where_clause=None, field_mapping=None, config_keyword=None):
    """FeatureClassToFeatureClass_conversion(in_features, out_path, out_name, {where_clause}, {field_mapping}, {config_keyword})

        Converts a shapefile, coverage feature class, or geodatabase feature
        class to a shapefile or geodatabase feature class.

     INPUTS:
      in_features (Feature Layer):
          The feature class or feature layer that will be converted.
      out_path (Workspace / Feature Dataset):
          The location in which the output feature class will be created. This
          can be either a geodatabase or a folder. If the output location is a
          folder, the output will be a shapefile.
      out_name (String):
          The name of the output feature class.
      where_clause {SQL Expression}:
          An SQL expression used to select a subset of features. For more
          information on SQL syntax see the help topic SQL reference for
          elements used in query expressions.
      field_mapping {Field Mappings}:
          The fields and field contents chosen from the input feature class. You
          can add, rename, or delete output fields as well as set properties
          such as data type and merge rule.You can use the ArcPy FieldMappings
          class to define this parameter.
      config_keyword {String}"""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FeatureClassToFeatureClass_conversion(*gp_fixargs((in_features, out_path, out_name, where_clause, field_mapping, config_keyword), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FeatureClassToGeodatabase_conversion', None)
def FeatureClassToGeodatabase(Input_Features=None, Output_Geodatabase=None):
    """FeatureClassToGeodatabase_conversion(Input_Features;Input_Features..., Output_Geodatabase)

        Converts one or more feature classes or feature layers to geodatabase
        feature classes.

     INPUTS:
      Input_Features (Feature Layer):
          One or more feature classes or feature layers to be imported into a
          file or enterprise geodatabase.
      Output_Geodatabase (Workspace / Feature Dataset):
          The output or destination geodatabase. This can be a file or
          enterprise geodatabase."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FeatureClassToGeodatabase_conversion(*gp_fixargs((Input_Features, Output_Geodatabase), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('MobileGdbToFileGdb_conversion', None)
def MobileGdbToFileGdb(in_mobile_gdb=None, out_file_gdb=None):
    """MobileGdbToFileGdb_conversion(in_mobile_gdb, out_file_gdb)

        Copies the contents of a mobile geodatabase to a new file geodatabase.

     INPUTS:
      in_mobile_gdb (File):
          The mobile geodatabase that will have its contents copied to a new
          file geodatabase.

     OUTPUTS:
      out_file_gdb (File):
          The name and location of the output file geodatabase, for example,
          c:\\temp\\outputGeodatabases\\copiedFGDB.gdb."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MobileGdbToFileGdb_conversion(*gp_fixargs((in_mobile_gdb, out_file_gdb), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('RasterToGeodatabase_conversion', None)
def RasterToGeodatabase(Input_Rasters=None, Output_Geodatabase=None, Configuration_Keyword=None):
    """RasterToGeodatabase_conversion(Input_Rasters;Input_Rasters..., Output_Geodatabase, {Configuration_Keyword})

        Loads multiple raster datasets into a geodatabase.

     INPUTS:
      Input_Rasters (Raster Dataset):
          Input raster dataset(s).
      Output_Geodatabase (Workspace):
          The path and name of a geodatabase.
      Configuration_Keyword {String}:
          Specifies the storage parameters (configuration) for a geodatabase.
          Configuration keywords are set up by your database administrator."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RasterToGeodatabase_conversion(*gp_fixargs((Input_Rasters, Output_Geodatabase, Configuration_Keyword), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('TableToGeodatabase_conversion', None)
def TableToGeodatabase(Input_Table=None, Output_Geodatabase=None):
    """TableToGeodatabase_conversion(Input_Table;Input_Table..., Output_Geodatabase)

        Converts one or more tables to geodatabase tables in an output
        geodatabase. The inputs can be dBASE, INFO, VPF, OLE DB tables,
        geodatabase tables, or table views.

     INPUTS:
      Input_Table (Table View):
          The list of tables to be converted to geodatabase tables. Input tables
          can be INFO, dBASE, OLE DB, geodatabase tables, or table views.
      Output_Geodatabase (Workspace):
          The destination geodatabase where the tables will be placed."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.TableToGeodatabase_conversion(*gp_fixargs((Input_Table, Output_Geodatabase), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('TableToTable_conversion', None)
def TableToTable(in_rows=None, out_path=None, out_name=None, where_clause=None, field_mapping=None, config_keyword=None):
    """TableToTable_conversion(in_rows, out_path, out_name, {where_clause}, {field_mapping}, {config_keyword})

        Exports the rows of a table, table view, feature layer, feature class,
        or raster with attribute table to a new geodatabase, .csv, .txt, or
        .dbf table.

     INPUTS:
      in_rows (Table View / Raster Layer):
          The input table to be exported to a new table.
      out_path (Workspace):
          The destination where the output table will be written.
      out_name (String):
          The name of the output table. If the output location is a folder,
          include an extension such as
          .csv, .txt, or .dbf to export the table to that format. If the output
          location is a geodatabase, do not specify an extension.
      where_clause {SQL Expression}:
          An SQL expression used to select a subset of records. Learn more about
          SQL query expressions
      field_mapping {Field Mappings}:
          The fields and field contents chosen from the input table. You can
          add, rename, or delete output fields as well as set properties such as
          data type and merge rule.You can use the ArcPy FieldMappings object
          for this parameter.
      config_keyword {String}:
          Specifies the default storage parameters (configurations) for
          geodatabases in a relational database management system (RDBMS). This
          setting is applicable only when using enterprise geodatabase
          tables.Configuration keywords are set by the database administrator."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.TableToTable_conversion(*gp_fixargs((in_rows, out_path, out_name, where_clause, field_mapping, config_keyword), True)))
        return retval
    except Exception as e:
        raise e


# To Raster toolset
@gptooldoc('ASCIIToRaster_conversion', None)
def ASCIIToRaster(in_ascii_file=None, out_raster=None, data_type=None):
    """ASCIIToRaster_conversion(in_ascii_file, out_raster, {data_type})

        Converts an ASCII file representing raster data to a raster
        dataset.This is a deprecated tool. The Copy Raster tool can now be
        used to
        convert an ASCII file representing raster data to a raster dataset.

     INPUTS:
      in_ascii_file (File):
          The input ASCII file to be converted.
      data_type {String}:
          The data type of the output raster dataset.

          * INTEGER-An integer raster dataset will be created.

          * FLOAT-A floating-point raster dataset will be created.

     OUTPUTS:
      out_raster (Raster Dataset):
          The output raster dataset to be created.When not saving to a
          geodatabase, specify .tif for a TIFF file format,
          .CRF for CRF file format, .img for an ERDAS IMAGINE file format, or no
          extension for an Esri Grid raster format."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ASCIIToRaster_conversion(*gp_fixargs((in_ascii_file, out_raster, data_type), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DEMToRaster_conversion', None)
def DEMToRaster(in_dem_file=None, out_raster=None, data_type=None, z_factor=None):
    """DEMToRaster_conversion(in_dem_file, out_raster, {data_type}, {z_factor})

        Converts a digital elevation model (DEM) in a United States Geological
        Survey (USGS) format to a raster dataset.This is a deprecated tool.
        The Copy Raster tool can now be used to
        convert a DEM file representing raster data to a raster dataset.

     INPUTS:
      in_dem_file (File):
          The input USGS DEM file. The DEM must be standard USGS 7.5 minute, 1
          degree, or any other file in the USGS DEM format. The DEM may be in
          either fixed or variable record-length format.
      data_type {String}:
          Data type of the output raster dataset.

          * INTEGER-An integer raster dataset will be created.

          * FLOAT-A floating-point raster dataset will be created. This is the
          default.
      z_factor {Double}:
          The number of ground x,y units in one surface z unit.The z-factor
          adjusts the units of measure for the z units when they
          are different from the x,y units of the input surface. The z-values of
          the input surface are multiplied by the z-factor when calculating the
          final output surface.If the x,y units and z units are in the same
          units of measure, the
          z-factor is 1. This is the default.If the x,y units and z units are in
          different units of measure, the
          z-factor must be set to the appropriate factor, or the results will be
          incorrect. For example, if your z units are feet and your x,y units
          are meters, you would use a z-factor of 0.3048 to convert your z units
          from feet to meters (1 foot = 0.3048 meter).

     OUTPUTS:
      out_raster (Raster Dataset):
          The output raster dataset to be created.When not saving to a
          geodatabase, specify .tif for a TIFF file format,
          .CRF for CRF file format, .img for an ERDAS IMAGINE file format, or no
          extension for an Esri Grid raster format."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DEMToRaster_conversion(*gp_fixargs((in_dem_file, out_raster, data_type, z_factor), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FeatureToRaster_conversion', None)
def FeatureToRaster(in_features=None, field=None, out_raster=None, cell_size=None):
    """FeatureToRaster_conversion(in_features, field, out_raster, {cell_size})

        Converts features to a raster dataset.

     INPUTS:
      in_features (Composite Geodataset):
          The input feature dataset to be converted to a raster dataset.
      field (Field):
          The field used to assign values to the output raster.It can be any
          field of the input feature dataset's attribute table.If the Shape
          field of a point or multipoint dataset contains z or m
          values, then either of these can be used.
      cell_size {Analysis Cell Size}:
          The cell size for the output raster being created.This parameter can
          be defined by a numeric value or obtained from an
          existing raster dataset. If the cell size hasn't been explicitly
          specified as the parameter value, then the environment cell size value
          is used if specified; otherwise some additional rules are used to
          calculate it from the other inputs. See the usage for more detail.

     OUTPUTS:
      out_raster (Raster Dataset):
          The output raster dataset to be created.When not saving to a
          geodatabase, specify .tif for a TIFF file format,
          .CRF for CRF file format, .img for an ERDAS IMAGINE file format, or no
          extension for an Esri Grid raster format."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FeatureToRaster_conversion(*gp_fixargs((in_features, field, out_raster, cell_size), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FloatToRaster_conversion', None)
def FloatToRaster(in_float_file=None, out_raster=None):
    """FloatToRaster_conversion(in_float_file, out_raster)

        Converts a file of binary floating-point values representing raster
        data to a raster dataset.This is a deprecated tool. The Copy Raster
        tool can now be used to
        convert a float file representing raster data to a raster dataset.

     INPUTS:
      in_float_file (File):
          The input floating-point binary file. The file must have a .flt
          extension. There must be a header file in
          association with the floating-point binary file, with a .hdr
          extension.

     OUTPUTS:
      out_raster (Raster Dataset):
          The output raster dataset to be created.When not saving to a
          geodatabase, specify .tif for a TIFF file format,
          .CRF for CRF file format, .img for an ERDAS IMAGINE file format, or no
          extension for an Esri Grid raster format."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FloatToRaster_conversion(*gp_fixargs((in_float_file, out_raster), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('MultipatchToRaster_conversion', None)
def MultipatchToRaster(in_multipatch_features=None, out_raster=None, cell_size=None):
    """MultipatchToRaster_conversion(in_multipatch_features, out_raster, {cell_size})

        Converts multipatch features to a raster dataset.

     INPUTS:
      in_multipatch_features (Composite Geodataset):
          The input multipatch features to be converted to a raster.
      cell_size {Analysis Cell Size}:
          The cell size for the output raster being created.This parameter can
          be defined by a numeric value or obtained from an
          existing raster dataset. If the cell size hasn't been explicitly
          specified as the parameter value, then the environment cell size value
          is used if specified; otherwise some additional rules are used to
          calculate it from the other inputs. See the usage for more detail.

     OUTPUTS:
      out_raster (Raster Dataset):
          The output raster dataset to be created.It will be of floating point
          type.When not saving to a geodatabase, specify .tif for a TIFF file
          format,
          .CRF for CRF file format, .img for an ERDAS IMAGINE file format, or no
          extension for an Esri Grid raster format."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MultipatchToRaster_conversion(*gp_fixargs((in_multipatch_features, out_raster, cell_size), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('PointToRaster_conversion', None)
def PointToRaster(in_features=None, value_field=None, out_rasterdataset=None, cell_assignment=None, priority_field=None, cellsize=None):
    """PointToRaster_conversion(in_features, value_field, out_rasterdataset, {cell_assignment}, {priority_field}, {cellsize})

        Converts point features to a raster dataset.

     INPUTS:
      in_features (Feature Layer):
          The point or multipoint input feature dataset to be converted to a
          raster.
      value_field (Field):
          The field used to assign values to the output raster.It can be any
          field of the input feature dataset's attribute table.If the Shape
          field of a point or multipoint dataset contains z or m
          values, then either of these can be used.
      cell_assignment {String}:
          The method to determine how the cell will be assigned a value when
          more than one feature falls within a cell.

          * MOST_FREQUENT-If there is more than one feature within the cell, the
          one with the most common attribute, in the Value field, is assigned to
          the cell. If they have the same number of common attributes, the one
          with the lowest FID is used.

          * SUM-The sum of the attributes of all the points within the cell (not
          valid for string data).

          * MEAN-The mean of the attributes of all the points within the cell
          (not valid for string data).

          * STANDARD_DEVIATION-The standard deviation of attributes of all the
          points within the cell. If there are less than two points in the cell,
          the cell is assigned NoData (not valid for string data).

          * MAXIMUM-The maximum value of the attributes of the points within the
          cell (not valid for string data).

          * MINIMUM-The minimum value of the attributes of the points within the
          cell (not valid for string data).

          * RANGE-The range of the attributes of the points within the cell (not
          valid for string data).

          * COUNT-The number of points within the cell.
      priority_field {Field}:
          This field is used when a feature should take preference over another
          feature with the same attribute.Priority field is only used with the
          Most frequent cell assignment
          type option.
      cellsize {Analysis Cell Size}:
          The cell size for the output raster being created.This parameter can
          be defined by a numeric value or obtained from an
          existing raster dataset. If the cell size hasn't been explicitly
          specified as the parameter value, then the environment cell size value
          is used if specified; otherwise some additional rules are used to
          calculate it from the other inputs. See the usage for more detail.

     OUTPUTS:
      out_rasterdataset (Raster Dataset):
          The output raster dataset to be created.When not saving to a
          geodatabase, specify .tif for a TIFF file format,
          .CRF for CRF file format, .img for an ERDAS IMAGINE file format, or no
          extension for an Esri Grid raster format."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.PointToRaster_conversion(*gp_fixargs((in_features, value_field, out_rasterdataset, cell_assignment, priority_field, cellsize), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('PolygonToRaster_conversion', None)
def PolygonToRaster(in_features=None, value_field=None, out_rasterdataset=None, cell_assignment=None, priority_field=None, cellsize=None):
    """PolygonToRaster_conversion(in_features, value_field, out_rasterdataset, {cell_assignment}, {priority_field}, {cellsize})

        Converts polygon features to a raster dataset.

     INPUTS:
      in_features (Feature Layer):
          The polygon input feature dataset to be converted to a raster.
      value_field (Field):
          The field used to assign values to the output raster.It can be any
          field of the input feature dataset's attribute table.
      cell_assignment {String}:
          The method to determine how the cell will be assigned a value when
          more than one feature falls within a cell.

          * CELL_CENTER-The polygon that overlaps the center of the cell yields
          the attribute to assign to the cell.

          * MAXIMUM_AREA-The single feature with the largest area within the
          cell yields the attribute to assign to the cell.

          * MAXIMUM_COMBINED_AREA-If there is more than one feature in a cell
          with the same value, the areas of these features will be combined. The
          combined feature with the largest area within the cell will determine
          the value to assign to the cell.
      priority_field {Field}:
          This field is used to determine which feature should take preference
          over another feature that falls over a cell. When it is used, the
          feature with the largest positive priority is always selected for
          conversion irrespective of the Cell assignment type chosen.
      cellsize {Analysis Cell Size}:
          The cell size for the output raster being created.This parameter can
          be defined by a numeric value or obtained from an
          existing raster dataset. If the cell size hasn't been explicitly
          specified as the parameter value, then the environment cell size value
          is used if specified; otherwise some additional rules are used to
          calculate it from the other inputs. See the usage for more detail.

     OUTPUTS:
      out_rasterdataset (Raster Dataset):
          The output raster dataset to be created.When not saving to a
          geodatabase, specify .tif for a TIFF file format,
          .CRF for CRF file format, .img for an ERDAS IMAGINE file format, or no
          extension for an Esri Grid raster format."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.PolygonToRaster_conversion(*gp_fixargs((in_features, value_field, out_rasterdataset, cell_assignment, priority_field, cellsize), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('PolylineToRaster_conversion', None)
def PolylineToRaster(in_features=None, value_field=None, out_rasterdataset=None, cell_assignment=None, priority_field=None, cellsize=None):
    """PolylineToRaster_conversion(in_features, value_field, out_rasterdataset, {cell_assignment}, {priority_field}, {cellsize})

        Converts polyline features to a raster dataset.

     INPUTS:
      in_features (Feature Layer):
          The polyline input feature dataset to be converted to a raster.
      value_field (Field):
          The field used to assign values to the output raster.It can be any
          field of the input feature dataset's attribute table.
      cell_assignment {String}:
          The method to determine how the cell will be assigned a value when
          more than one feature falls within a cell.

          * MAXIMUM_LENGTH-The feature with the longest length that covers the
          cell will determine the value to assign to the cell.

          * MAXIMUM_COMBINED_LENGTH-If there is more than one feature in a cell
          with the same value, the lengths of these features will be combined.
          The combined feature with the longest length within the cell will
          determine the value to assign to the cell.
      priority_field {Field}:
          This field is used to determine which feature should take preference
          over another feature that falls over a cell. When it is used, the
          feature with the largest positive priority is always selected for
          conversion irrespective of the Cell assignment type chosen.
      cellsize {Analysis Cell Size}:
          The cell size for the output raster being created.This parameter can
          be defined by a numeric value or obtained from an
          existing raster dataset. If the cell size hasn't been explicitly
          specified as the parameter value, then the environment cell size value
          is used if specified; otherwise some additional rules are used to
          calculate it from the other inputs. See the usage for more detail.

     OUTPUTS:
      out_rasterdataset (Raster Dataset):
          The output raster dataset to be created.When not saving to a
          geodatabase, specify .tif for a TIFF file format,
          .CRF for CRF file format, .img for an ERDAS IMAGINE file format, or no
          extension for an Esri Grid raster format."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.PolylineToRaster_conversion(*gp_fixargs((in_features, value_field, out_rasterdataset, cell_assignment, priority_field, cellsize), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('RasterToOtherFormat_conversion', None)
def RasterToOtherFormat(Input_Rasters=None, Output_Workspace=None, Raster_Format=None):
    """RasterToOtherFormat_conversion(Input_Rasters;Input_Rasters..., Output_Workspace, {Raster_Format})

        Converts one or more raster datasets to a different format.

     INPUTS:
      Input_Rasters (Raster Dataset):
          The raster datasets to convert.
      Output_Workspace (Workspace):
          The folder where the raster dataset will be written.
      Raster_Format {String}:
          The format of the new raster dataset.

          * BIL-Esri Band Interleaved by Line file

          * BIP-Esri Band Interleaved by Pixel file

          * BMP-Microsoft bitmap graphic raster dataset format

          * BSQ-Esri Band Sequential file

          * CRF-Cloud Raster Format

          * ENVI DAT-ENVI DAT file

          * GIF-Graphic Interchange Format for raster datasets

          * GRID-Esri Grid raster dataset format

          * IMAGINE Image-ERDAS IMAGINE raster data format

          * JP2000-JPEG 2000 raster dataset format

          * JPEG-Joint Photographic Experts Group raster dataset format

          * MRF-Meta Raster Format

          * PNG-Portable Network Graphic raster dataset format

          * TIFF-Tagged Image File Format for raster datasets"""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RasterToOtherFormat_conversion(*gp_fixargs((Input_Rasters, Output_Workspace, Raster_Format), True)))
        return retval
    except Exception as e:
        raise e


# To Shapefile toolset
@gptooldoc('FeatureClassToShapefile_conversion', None)
def FeatureClassToShapefile(Input_Features=None, Output_Folder=None):
    """FeatureClassToShapefile_conversion(Input_Features;Input_Features..., Output_Folder)

        Copies the features from one or more feature classes or layers to a
        folder of shapefiles.

     INPUTS:
      Input_Features (Feature Layer):
          The list of input feature classes or feature layers that will be
          converted and added to the output folder.
      Output_Folder (Folder):
          The folder where the shapefiles will be written."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FeatureClassToShapefile_conversion(*gp_fixargs((Input_Features, Output_Folder), True)))
        return retval
    except Exception as e:
        raise e


# To dBASE toolset
@gptooldoc('TableToDBASE_conversion', None)
def TableToDBASE(Input_Table=None, Output_Folder=None):
    """TableToDBASE_conversion(Input_Table;Input_Table..., Output_Folder)

        Converts one or more tables to dBASE tables.

     INPUTS:
      Input_Table (Table View):
          The list of tables to be converted to dBASE.
      Output_Folder (Folder):
          The destination folder where the output dBASE tables will be placed."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.TableToDBASE_conversion(*gp_fixargs((Input_Table, Output_Folder), True)))
        return retval
    except Exception as e:
        raise e


# Transit Feed (GTFS) toolset
@gptooldoc('ConnectNetworkDatasetTransitSourcesToStreets_conversion', None)
def ConnectNetworkDatasetTransitSourcesToStreets(target_feature_dataset=None, in_streets_features=None, search_distance=None, expression=None):
    """ConnectNetworkDatasetTransitSourcesToStreets_conversion(target_feature_dataset, in_streets_features, search_distance, {expression})

        Connects transit stops to street features for use in a transit-
        enabled network dataset. This tool creates the StopsOnStreets and
        StopConnectors feature classes defined by the Network Analyst public
        transit data model and is intended to be run as part of a larger
        workflow for creating a transit-network dataset described in Create
        and use a network dataset with public transit data.To realistically
        model travel by public transit in a network dataset,
        the network should allow pedestrians to walk to the transit stops,
        ride the transit, and then walk to their destinations. The network
        should include both public transit data and street data, and the
        transit stops and lines should be connected to the streets in a
        controlled manner. Pedestrians should only be able to enter or exit
        the transit lines at stops, and the stops must be connected to the
        streets. This tool ensures such a connection.The tool will create a
        copy of the Stops feature class, which must be
        present in the target feature dataset, and snap the copied Stops
        features to the input streets features, subject to the specified
        search distance and expression. The tool will then create
        StopConnectors features by generating a straight line between each
        stop and its snapped copy, creating a connection between the stop's
        location and the location where it snapped to a street feature.
        Vertices will be added to the input streets features at the locations
        of the snapped stops to ensure good network dataset connectivity.

     INPUTS:
      target_feature_dataset (Feature Dataset):
          The feature dataset where the transit-enabled network dataset will be
          created. This feature dataset must already exist and contain a point
          feature class called Stops with the schema described by the Network
          Analyst public transit data model. A valid Stops feature class can be
          created with the GTFS To Network Dataset Transit Sources tool.The
          Stops feature class may be altered after running the tool. Stop
          features with a GStopType value of 2, representing station entrances,
          may be deleted. These stop features will instead be included in the
          output StopsOnStreets feature class to model correct connections from
          the streets, through the station entrances, and to the stops. Parent
          stations that are spatially coincident with stops may also be deleted.
      in_streets_features (Feature Layer):
          A polyline feature class of streets to which transit stops and lines
          will connect. This streets feature class should be the same feature
          class you intend to use in your transit-enabled network dataset for
          modeling pedestrians walking along streets. The feature class does not
          need to be in the target feature dataset to run this tool; however,
          the feature class must be in the target feature dataset at the time
          you create the network dataset.The input streets features will be
          altered after running the tool.
          Vertices will be added at the locations where StopsOnStreets features
          intersect the streets. If you do not want your street data altered,
          make a copy of it before running this tool.
      search_distance (Linear Unit):
          The search distance for snapping transit stops to the input street
          features. Stops that are outside the search distance will not be
          snapped and will not be connected to the streets. A small search
          distance will ensure that stops do not snap to streets that are far
          away, but it increases the likelihood of stops failing to snap when
          they should. A large search distance increases the number of stops
          likely to snap but may lead to errors that should instead be corrected
          by editing the street data. If no street features are found within the
          search distance of a particular stop, the output StopsOnStreets
          feature will not be snapped to a street and will be coincident with
          its corresponding feature in Stops, which could lead to poor
          connectivity in the network dataset at that location.The default is
          100 meters.
      expression {SQL Expression}:
          An SQL expression used to select a subset of input street feature
          records. Transit stops will be snapped only to street features
          matching this expression. For example, the expression could be used to
          prevent stops from snapping to streets where pedestrian travel is
          prohibited."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ConnectNetworkDatasetTransitSourcesToStreets_conversion(*gp_fixargs((target_feature_dataset, in_streets_features, search_distance, expression), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FeaturesToGTFSStops_conversion', None)
def FeaturesToGTFSStops(in_features=None, out_gtfs_stops_file=None):
    """FeaturesToGTFSStops_conversion(in_features, out_gtfs_stops_file)

        Converts a feature class to a GTFS stops.txt file for a GTFS public
        transit dataset.

     INPUTS:
      in_features (Feature Layer):
          A point feature class containing transit stop geometries and at least
          the minimum required GTFS stops.txt file fields except stop_lat and
          stop_lon.

     OUTPUTS:
      out_gtfs_stops_file (File):
          The output stops.txt file."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FeaturesToGTFSStops_conversion(*gp_fixargs((in_features, out_gtfs_stops_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GTFSShapesToFeatures_conversion', None)
def GTFSShapesToFeatures(in_gtfs_shapes_file=None, out_feature_class=None):
    """GTFSShapesToFeatures_conversion(in_gtfs_shapes_file, out_feature_class)

        Converts a GTFS shapes.txt file from a GTFS public transit dataset to
        a polyline feature class showing the physical paths taken by vehicles
        in the public transit system.If possible, attributes from the
        routes.txt file are included for each
        shape in the output, and output lines are symbolized according to the
        color specified in the route_color field.The shapes.txt file contains
        sequences of latitude and longitude
        points. This tool generates shape polylines by connecting these
        sequences of points with straight lines.

     INPUTS:
      in_gtfs_shapes_file (File):
          A valid shapes.txt file from a GTFS dataset.

     OUTPUTS:
      out_feature_class (Feature Class):
          The output feature class."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GTFSShapesToFeatures_conversion(*gp_fixargs((in_gtfs_shapes_file, out_feature_class), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GTFSStopsToFeatures_conversion', None)
def GTFSStopsToFeatures(in_gtfs_stops_file=None, out_feature_class=None):
    """GTFSStopsToFeatures_conversion(in_gtfs_stops_file, out_feature_class)

        Converts a GTFS stops.txt file from a GTFS public transit dataset to
        a feature class of public transit stops.

     INPUTS:
      in_gtfs_stops_file (File):
          A valid stops.txt file from a GTFS dataset.

     OUTPUTS:
      out_feature_class (Feature Class):
          The output feature class."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GTFSStopsToFeatures_conversion(*gp_fixargs((in_gtfs_stops_file, out_feature_class), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GTFSToNetworkDatasetTransitSources_conversion', None)
def GTFSToNetworkDatasetTransitSources(in_gtfs_folders=None, target_feature_dataset=None, interpolate=None, append=None):
    """GTFSToNetworkDatasetTransitSources_conversion(in_gtfs_folders;in_gtfs_folders..., target_feature_dataset, {interpolate}, {append})

        Converts one or more General Transit Feed Specification (GTFS) public
        transit datasets to a set of feature classes and tables that can be
        used when creating a network dataset. The output feature classes and
        tables represent the transit stops, lines, and schedules in the format
        defined by the Network Analyst public transit data model, which can be
        interpreted by the Public Transit evaluator in a network dataset.The
        transit data model feature classes and tables produced by this
        tool are as follows:

        * Stops

        * LineVariantElements

        * Calendars

        * CalendarExceptions

        * Lines

        * LineVariants

        * Runs

        * ScheduleElements

        * Schedules
        The output from this tool can be used as input to the Connect Network
        Dataset Transit Sources To Streets tool to prepare all necessary
        inputs for a transit-enabled network dataset. The complete workflow
        for creating such a network dataset is described in Create and use a
        network dataset with public transit data.

     INPUTS:
      in_gtfs_folders (Folder):
          One or more folders containing valid GTFS data. Each folder must
          contain the GTFS stops.txt, routes.txt, trips.txt, and stop_times.txt
          files and either the calendar.txt or calendar_dates.txt file, or both.
      target_feature_dataset (Feature Dataset):
          The feature dataset where the transit-enabled network dataset will be
          created. The Stops and LineVariantElements feature classes created by
          this tool will be placed in this feature dataset, and the output
          tables created by this tool will be placed in this feature dataset's
          parent geodatabase.The feature dataset can be in a file geodatabase or
          an enterprise
          geodatabase and can have any spatial reference. If the target feature
          dataset is in an enterprise geodatabase, it must not be versioned. The
          target feature dataset should not be contained in a geodatabase that
          already has another feature dataset containing public transit data
          model feature classes.
      interpolate {Boolean}:
          Specifies whether to interpolate blank values from the arrival_time
          and departure_time fields in the GTFS stop_times.txt file when
          creating the public transit data model tables.

          * INTERPOLATE-Blank values will be interpolated using simple linear
          interpolation. The original GTFS data will not be altered. If there
          were no blank values in the original data, no interpolation will
          occur.

          * NO_INTERPOLATE-Blank values will not be interpolated. If blank
          values are found in the input GTFS data, the tool will issue a warning
          and will not process the GTFS dataset. This is the default.
      append {Boolean}:
          Specifies whether to append the input GTFS datasets to existing public
          transit data model feature classes and tables in the target feature
          dataset and its parent geodatabase.

          * APPEND-Data will be appended into the existing feature classes and
          tables.

          * NO_APPEND-Existing feature classes and tables will be overwritten.
          This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GTFSToNetworkDatasetTransitSources_conversion(*gp_fixargs((in_gtfs_folders, target_feature_dataset, interpolate, append), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject