# -*- coding: utf-8 -*-
#COPYRIGHT 2019 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""The Network Diagram toolbox provides various tools to manage diagrams
and configure diagram templates."""
__all__ = ['AddAngleDirectedLayout', 'AddCollapseContainerByAttributeRule',
           'AddCollapseContainerRule', 'AddCompressionLayout',
           'AddConnectivityAssociationsRule',
           'AddDiagramFeatureCapabilityByAttributeRule', 'AddDiagramTemplate',
           'AddExpandContainerByAttributeRule', 'AddExpandContainerRule',
           'AddForceDirectedLayout', 'AddGridLayout', 'AddLinearDispatchLayout',
           'AddMainRingLayout', 'AddMainlineTreeLayout',
           'AddPartialOverlappingEdgesLayout', 'AddRadialTreeLayout',
           'AddReduceEdgeByAttributeRule', 'AddReduceJunctionByAttributeRule',
           'AddReduceJunctionRule', 'AddRelativeMainlineLayout',
           'AddRemoveFeatureByAttributeRule', 'AddRemoveFeatureRule',
           'AddReshapeDiagramEdgesLayout', 'AddSetRootJunctionByAttributeRule',
           'AddSetStartingPointByAttributeRule', 'AddSmartTreeLayout',
           'AddSpatialDispatchLayout', 'AddSpatialQueryRule',
           'AddStartIterationRule', 'AddStopIterationRule',
           'AddStructuralAttachmentsRule', 'AddTraceRule',
           'AlterDiagramProperties', 'AlterDiagramTemplate', 'AppendToDiagram',
           'ApplyAngleDirectedLayout', 'ApplyCompressionLayout',
           'ApplyForceDirectedLayout', 'ApplyGeoPositionsLayout',
           'ApplyGridLayout', 'ApplyLinearDispatchLayout',
           'ApplyMainRingLayout', 'ApplyMainlineTreeLayout',
           'ApplyPartialOverlappingEdgesLayout', 'ApplyRadialTreeLayout',
           'ApplyRelativeMainlineLayout', 'ApplyRotateTreeLayout',
           'ApplySmartTreeLayout', 'ApplySpatialDispatchLayout',
           'ApplyTemplateLayouts', 'ChangeDiagramsOwner', 'CreateDiagram',
           'CreateDiagramLayerDefinition', 'DeleteDiagram',
           'DeleteDiagramTemplate', 'ExportDiagramContent',
           'ExportDiagramLayerDefinition', 'ExportDiagramTemplateDefinitions',
           'ExtendDiagram', 'GetDiagramTemplateNames',
           'ImportDiagramTemplateDefinitions', 'MakeDiagramLayer',
           'OverwriteDiagram', 'PurgeTemporaryDiagrams',
           'ReshapeDiagramEdgesLayout', 'StoreDiagram', 'UpdateDiagram']
__alias__ = 'nd'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject

# Tools
@gptooldoc('AlterDiagramProperties_nd', None)
def AlterDiagramProperties(in_network_diagram_layer=None, out_name=None, access_right_type=None, tags=None):
    """AlterDiagramProperties_nd(in_network_diagram_layer, {out_name}, {access_right_type}, {tags})

        Alters properties for any stored network diagram.When working with a
        utility network in an enterprise geodatabase, the
        diagram owner and the portal utility network owner are the only users
        who can run the Alter Diagram Properties tool.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The stored network diagram to alter.
      out_name {String}:
          The new name for the input network diagram.
      access_right_type {String}:
          Specifies the access right level of the input diagram.

          * PUBLIC-Other users will have full access to the diagram; everyone
          can see, edit, update, and overwrite the diagram. However, no one
          except the diagram owner and the portal utility network owner-in the
          case of diagrams related to a utility network in an enterprise
          geodatabase-can change its properties using the Alter Diagram
          Properties tool. This is the default.

          * PROTECTED-Other users will have read-only access to the diagram.
          They cannot edit, update, or overwrite the diagram.

          * PRIVATE-Other users will not have access to the diagram. The
          corresponding diagram item will be hidden from other users in the Find
          Diagrams pane.
      tags {String}:
          One or several tags that will help find the stored diagram. These tags
          can be used used in the Find Diagrams pane.To add several tags, use
          the number sign (#) to separate each tag.
          This also allows a more thorough and efficient diagram search."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AlterDiagramProperties_nd(*gp_fixargs((in_network_diagram_layer, out_name, access_right_type, tags), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AppendToDiagram_nd', None)
def AppendToDiagram(in_network_diagram_layer=None, map=None):
    """AppendToDiagram_nd(in_network_diagram_layer, map)

        Appends network features to a network diagram.If you have an open edit
        session, you must save your edits prior to
        running this tool. This ensures that the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram layer to which network features will be appended.
      map (Map):
          The map with selected network features to append to the network
          diagram."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AppendToDiagram_nd(*gp_fixargs((in_network_diagram_layer, map), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ChangeDiagramsOwner_nd', None)
def ChangeDiagramsOwner(in_diagrams=None, target_owner=None, source_owner=None, diagram_names=None):
    """ChangeDiagramsOwner_nd(in_diagrams, target_owner, {source_owner}, {diagram_names;diagram_names...})

        Changes ownership of stored network diagrams.This tool is an
        administration tool. When working with a utility
        network in an enterprise geodatabase, it must be run by the database
        utility network owner through a database connection to the default
        version. The default version must be public, that is, not protected.In
        addition to that requirement, the connected ArcGIS Enterprise
        portal account must be the portal utility network owner to perform
        this operation.Change Diagrams Owner cannot process utility network
        datasets created
        prior to ArcGIS Pro 2.4, even if they have been upgraded.

     INPUTS:
      in_diagrams (Utility Network / Trace Network / Utility Network Layer / Trace Network Layer / Diagram Layer):
          The input network layer or network diagram layer related to the
          utility network of interest with the stored network diagrams whose
          ownership will be transferred.
      target_owner (String):
          The name of the user that will become the new owner of the specified
          diagrams.
      source_owner {String}:
          The name of the user whose ownership of the network diagrams will be
          changed.This parameter is only used when there are no specified
          diagram names.
          When diagram names are specified, it will be ignored.
      diagram_names {String}:
          The names of the diagrams to be processed."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ChangeDiagramsOwner_nd(*gp_fixargs((in_diagrams, target_owner, source_owner, diagram_names), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CreateDiagram_nd', None)
def CreateDiagram(in_utility_network=None, template_name=None, features=None):
    """CreateDiagram_nd(in_utility_network, template_name, {features;features...})

        Creates a temporary network diagram from network features currently
        selected in the active map or from feature layers created from a
        Python script.When feature layers are specified and there are features
        selected in
        the active map, the selected features set is ignored and all the
        features in the specified layers are used as input for the diagram
        creation.When no feature layers or classes are specified, the tool
        searches for
        the network features selected in the active map and creates the
        diagram from those features.Edits must be saved so that the output
        diagram is in sync with the
        last save of the network topology in the database. Otherwise, the
        unsaved edits will not be reflected in the new diagram.

     INPUTS:
      in_utility_network (Utility Network / Trace Network / Utility Network Layer / Trace Network Layer):
          The utility network from which the diagram will be created.
      template_name (String):
          The name of the template that will be used to create the diagram.
      features {Feature Layer}:
          One or more feature layers or feature classes to be used as input for
          diagram generation."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateDiagram_nd(*gp_fixargs((in_utility_network, template_name, features), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DeleteDiagram_nd', None)
def DeleteDiagram(in_diagrams=None, template_names=None, diagram_names=None):
    """DeleteDiagram_nd(in_diagrams, {template_names;template_names...}, {diagram_names;diagram_names...})

        Deletes one or more stored network diagrams, which are optionally
        filtered by their diagram template names, related to a given
        network.You can specify a single diagram, a set of diagrams, or a
        diagram
        template name. When specifying a diagram template, all associated
        diagrams are deleted.You must save any edits prior to deleting a
        diagram.

     INPUTS:
      in_diagrams (Utility Network / Trace Network / Utility Network Layer / Trace Network Layer / Diagram Layer):
          The input network diagram layer to delete, or the utility network
          layer on which the set of specified input diagram names to delete are
          based.
      template_names {String}:
          The names of the templates for which the related diagrams are to be
          processed.
      diagram_names {String}:
          The names of the diagrams to be processed."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DeleteDiagram_nd(*gp_fixargs((in_diagrams, template_names, diagram_names), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ExportDiagramContent_nd', None)
def ExportDiagramContent(in_utility_network=None, network_diagram_name=None, out_file=None, include_diagram_properties=None, include_geometries=None, include_attributes=None, include_aggregations=None):
    """ExportDiagramContent_nd(in_utility_network, network_diagram_name, out_file, {include_diagram_properties}, {include_geometries}, {include_attributes}, {include_aggregations})

        Exports diagram content in a simple format (JSON) that reflects basic
        connectivity. Additional optional information such as diagram
        properties, diagram feature geometry, network elements attributes, and
        aggregated elements can also be exported.The input network or diagram
        layer can be from either a utility
        network in a file geodatabase, a utility network service, or a
        database connection to a utility network in an enterprise geodatabase.

     INPUTS:
      in_utility_network (Utility Network / Trace Network / Utility Network Layer / Trace Network Layer / Diagram Layer):
          The utility network layer, utility network data element, or network
          diagram layer related to the network diagram to export.
      network_diagram_name (String):
          The name of the network diagram to export.
      include_diagram_properties {Boolean}:
          Specifies whether the diagram properties will be exported.

          *  INCLUDE_DIAGRAM_PROPERTIES-The diagram properties (statistics,
          creation and update dates, and so on) will be exported.

          *  EXCLUDE_DIAGRAM_PROPERTIES-The diagram properties will not be
          exported. This is the default.
      include_geometries {Boolean}:
          Specifies whether the geometry of the diagram features will be
          exported.

          *  INCLUDE_GEOMETRIES-Each diagram feature will be exported with its
          geometry.

          *  EXCLUDE_GEOMETRIES-Each diagram feature will be exported without
          its geometry. This is the default.
      include_attributes {Boolean}:
          Specifies whether the attributes of the associated network features
          will be exported.

          *  INCLUDE_ATTRIBUTES-The associated network feature attributes will
          be exported.

          *  EXCLUDE_ATTRIBUTES-The associated network feature attributes will
          not be exported. This is the default.
      include_aggregations {Boolean}:
          Specifies whether each diagram feature will be exported with the list
          of the network elements it aggregates.

          *  INCLUDE_AGGREGATIONS-Each diagram feature will be exported with the
          list of the network elements it aggregates with their asset group and
          asset type values.

          *  EXCLUDE_AGGREGATIONS-The diagram feature aggregations will not be
          exported. This is the default.

     OUTPUTS:
      out_file (File):
          The output JSON file that will be created with the exported diagram
          content."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportDiagramContent_nd(*gp_fixargs((in_utility_network, network_diagram_name, out_file, include_diagram_properties, include_geometries, include_attributes, include_aggregations), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ExtendDiagram_nd', None)
def ExtendDiagram(in_network_diagram_layer=None, ignore_traversability=None, extension_type=None):
    """ExtendDiagram_nd(in_network_diagram_layer, {ignore_traversability}, {extension_type})

        Extends a network diagram one feature level based on network
        connectivity or traversability or on containment or structural
        attachment associations.For example, a diagram with a portion of a
        pipe network in it may have
        many open-ended pipes with connected features. When running the Extend
        Diagram tool on this diagram with the By connectivity extension type,
        any connected features are appended to the diagram.Features can also
        be obtained based on traversability using the By
        traversability extension type. In this case, features are appended to
        the diagram if they allow the network commodity to continue through to
        the next feature. For example, a diagram with a portion of a pipe
        network in it may have a closed valve at the end of a pipe end. Since
        a resource travelling this network cannot travel beyond the closed
        valve, the valve is not returned in the diagram. If this example was
        based on connectivity instead of traversability, the valve would be
        returned, as it is connected to the pipe.Extending diagrams can be
        locked on the related diagram template.If you have an open edit
        session, you must save your edits prior to
        running this tool. This ensures that the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to extend.
      ignore_traversability {Boolean}:
          Specifies whether traversability or connectivity is used to extend the
          diagram.This parameter was deprecated at ArcGIS Pro 2.2. It is
          systematically
          ignored regardless of its value when the extension_type parameter is
          specified. To maintain compatibility with models and Python scripts
          written at ArcGIS Pro 2.1, it remains enabled when the extension_type
          parameter is not specified.

          *  IGNORE_TRAVERSABILITY-The traversability of the network is ignored.
          This is the default.

          * HONOR_TRAVERSABILITY-The traversability of the network is honored.
      extension_type {String}:
          Specifies how the diagram will be extended.

          * BY_CONNECTIVITY-Extends the network diagram one feature level based
          on network connectivity. This is the default.

          * BY_TRAVERSABILITY-Extends the network diagram one feature level
          based on network traversability.

          * BY_ATTACHMENT-Extends the network diagram one feature level based on
          structural attachment associations.

          * BY_CONTAINMENT-Extends the network diagram one feature level based
          on containment associations."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExtendDiagram_nd(*gp_fixargs((in_network_diagram_layer, ignore_traversability, extension_type), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('MakeDiagramLayer_nd', None)
def MakeDiagramLayer(in_utility_network=None, network_diagram_name=None, out_layer=None):
    """MakeDiagramLayer_nd(in_utility_network, network_diagram_name, out_layer)

        Creates a network diagram layer from a network diagram.

     INPUTS:
      in_utility_network (Utility Network / Trace Network / Utility Network Layer / Trace Network Layer):
          The utility network the diagram is related to.
      network_diagram_name (String):
          The network diagram name.

     OUTPUTS:
      out_layer (Diagram Layer):
          The name of the diagram layer to be created.The output diagram layer
          can be used as input to any geoprocessing
          tool that accepts a diagram layer as input, including the Store
          Diagram, Update Diagram, and Apply Smart Tree Layout tools."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MakeDiagramLayer_nd(*gp_fixargs((in_utility_network, network_diagram_name, out_layer), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('OverwriteDiagram_nd', None)
def OverwriteDiagram(in_network_diagram_layer=None, map=None):
    """OverwriteDiagram_nd(in_network_diagram_layer, map)

        Overwrites the contents of a network diagram with the network features
        currently selected in the specified map. These network features become
        the new initial content of the diagram.If you have an open edit
        session, you must save your edits prior to
        running this tool. This ensures that the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to overwrite.
      map (Map):
          The map referencing the set of selected network features to use to
          overwrite the input network diagram."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.OverwriteDiagram_nd(*gp_fixargs((in_network_diagram_layer, map), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('PurgeTemporaryDiagrams_nd', None)
def PurgeTemporaryDiagrams(in_utility_network=None, created_before=None):
    """PurgeTemporaryDiagrams_nd(in_utility_network, {created_before})

        Purges temporary network diagrams related to a given utility
        network.This tool is an administration tool. When working with a
        utility
        network in an enterprise geodatabase, it must be run by the database
        utility network owner through a database connection to the default
        version. The default version must be public, that is, not protected.In
        addition to that requirement, the connected ArcGIS Enterprise
        portal account must be the portal utility network owner to perform
        this operation.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network data element with the temporary diagrams to be
          purged.
      created_before {Date}:
          The cutoff date for temporary network diagrams to be purged. All
          temporary network diagrams created before this date will be purged.If
          no date is specified, all temporary diagrams in the database will
          be purged."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.PurgeTemporaryDiagrams_nd(*gp_fixargs((in_utility_network, created_before), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('StoreDiagram_nd', None)
def StoreDiagram(in_network_diagram_layer=None, out_name=None, access_right_type=None, tags=None):
    """StoreDiagram_nd(in_network_diagram_layer, out_name, {access_right_type}, {tags})

        Stores a temporary network diagram in the database. Access rights and
        tags can be assigned to control security and searchability of the
        diagram.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The temporary network diagram layer to be stored.
      access_right_type {String}:
          Specifies the access right level of the input diagram.

          * PUBLIC-Other users will have full access to the diagram; everyone
          can see, edit, update, and overwrite the diagram. However, no one
          except the diagram owner and the portal utility network owner-in the
          case of diagrams related to a utility network in an enterprise
          geodatabase-can change its properties using the Alter Diagram
          Properties tool. This is the default.

          * PROTECTED-Other users will have read-only access to the diagram.
          They cannot edit, update, or overwrite the diagram.

          * PRIVATE-Other users will not have access to the diagram. The
          corresponding diagram item will be hidden from other users in the Find
          Diagrams pane.
      tags {String}:
          Tags that can help with querying the stored diagram using the Find
          Diagrams pane.Use the # character to separate each tag and aid in
          efficient diagram
          searches.

     OUTPUTS:
      out_name (Diagram Layer):
          The name of the output network diagram."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.StoreDiagram_nd(*gp_fixargs((in_network_diagram_layer, out_name, access_right_type, tags), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('UpdateDiagram_nd', None)
def UpdateDiagram(in_diagrams=None, template_names=None, diagram_names=None, update_option=None, autolayout_option=None):
    """UpdateDiagram_nd(in_diagrams, {template_names;template_names...}, {diagram_names;diagram_names...}, {update_option}, {autolayout_option})

        Updates one or more network diagrams that are related to a given
        utility network.Diagrams may need to be updated when they are either
        inconsistent or
        consistent. When a diagram is inconsistent, it means the corresponding
        features in the map have been altered, and the diagram is out of date.
        A consistent diagram may need to be updated if the diagram template
        associated with it has been modified.If you have an open edit session,
        you must save your edits prior to
        running this tool. This ensures that the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Learn
        more about updating network diagrams

     INPUTS:
      in_diagrams (Utility Network / Trace Network / Utility Network Layer / Trace Network Layer / Diagram Layer):
          The input network diagram layer to update, or the utility network on
          which the set of specified input diagram names are based to update.
      template_names {String}:
          The names of the templates for which the related diagrams are to be
          processed.
      diagram_names {String}:
          The names of the diagrams to be processed.
      update_option {Boolean}:
          Specifies whether to update only diagrams that are inconsistent (the
          default) or all diagrams regardless of their consistency state.

          * INCONSISTENT_DIAGRAMS_ONLY-Only diagrams that are inconsistent will
          be updated. This is the default.

          * ALL_SELECTED_DIAGRAMS-Both consistent and inconsistent diagrams will
          be updated.
      autolayout_option {Boolean}:
          Specifies whether automatic layouts that may be configured on the
          template on which the diagrams are based will be reapplied during the
          update process. By default, when automatic layouts are specified on a
          template, they are not reapplied during the update process.

          * REAPPLY_AUTOLAYOUT-The automatic layouts that are configured on the
          template will be reapplied to diagrams at the end of the update
          process.

          * DO_NOT_REAPPLY_AUTOLAYOUT-None of the automatic layouts configured
          on the template will be reapplied to diagrams during the update
          process. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.UpdateDiagram_nd(*gp_fixargs((in_diagrams, template_names, diagram_names, update_option, autolayout_option), True)))
        return retval
    except Exception as e:
        raise e


# Configuration toolset
@gptooldoc('AddAngleDirectedLayout_nd', None)
def AddAngleDirectedLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, iterations_number=None, number_of_directions=None):
    """AddAngleDirectedLayout_nd(in_utility_network, template_name, is_active, {are_containers_preserved}, {iterations_number}, {number_of_directions})

        Adds the Angle Directed Layout algorithm to the list of the layouts to
        be automatically chained at the end of the generation of diagrams
        based on a given template. This tool also presets the Angle Directed
        Layout algorithm parameters for any diagram based on that
        template.This layout algorithm progressively moves the diagram's edges
        in
        specified alignment directions. For each diagram edge, this layout
        notes its current direction, searches for the nearest desired
        direction among those specified, and moves the edge in that
        direction.This tool is a configuration and administration tool.When
        working with a utility network in an enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the layout algorithm will automatically execute
          when generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagram that is based on the template_name
          parameter. This is the default.The parameter values specified for the
          layout algorithm are used to run the layout during diagram generation.
          They are also loaded by default when the algorithm is to be run on any
          diagram based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be loaded by default when the algorithm is to be
          run on any diagram based on the input template.
      are_containers_preserved {Boolean}:
          Specifies how the algorithm will process containers.

          * PRESERVE_CONTAINERS-The layout algorithm will execute on the top
          graph of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm will execute on both content
          and noncontent features in the diagram. This is the default.
      iterations_number {Long}:
          The number of iterations to process. The default is 1.
      number_of_directions {String}:
          The number of directions that will be used to align the diagram edges
          and their connected junctions.

          * TWELVE_DIRECTIONS-The edges will move so they progressively approach
          one of the 12 axes, starting with the edge's origin junction and
          inclined at 30, 60, 90, 120, 150, 180, 210, 240, 270, 300, 330, or 360
          degrees.

          * EIGHT_DIRECTIONS-The edges will move so they progressively approach
          one of the 8 axes, starting with the edge's origin junction and
          inclined at 45, 90, 135, 180, 225, 270, 315, or 360 degrees. This is
          the default.

          * FOUR_DIRECTIONS-The edges will move so they progressively approach
          one of the 4 axes, starting with the edge's origin junction and
          inclined at 90, 180, 270, or 360 degrees."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddAngleDirectedLayout_nd(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, iterations_number, number_of_directions), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddCollapseContainerByAttributeRule_nd', None)
def AddCollapseContainerByAttributeRule(in_utility_network=None, template_name=None, is_active=None, container_source=None, where_clause=None, description=None, reconnected_edges_option=None):
    """AddCollapseContainerByAttributeRule_nd(in_utility_network, template_name, is_active, container_source, {where_clause}, {description}, {reconnected_edges_option})

        Adds a diagram rule to the rule list specified on a diagram template
        to automatically collapse all contents related to containers during
        diagram building. The containers with the contents to be collapsed are
        identified using an SQL query based on their attributes.This tool is a
        configuration and administration tool.When working with a utility
        network in an enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule will be enabled when generating and
          updating diagrams based on the specified template.

          * ACTIVE-The added rule will become enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule will not become enabled during the
          generation or update of any diagrams based on the input template.
      container_source (Table / Feature Class):
          The network container source class that references the containers
          with the contents to be collapsed during the Collapse Container rule
          process.
      where_clause {SQL Expression}:
          An SQL expression used to select the subset of containers in this
          source class with the contents to be collapsed in the generated
          diagrams. For more information about SQL syntax, see SQL reference for
          query expressions used in ArcGIS.
      description {String}:
          The description of the rule.
      reconnected_edges_option {Boolean}:
          Specifies whether the rule will aggregate the edges that are
          reconnected to the collapsed junctions.

          * DONT_AGGREGATE_RECONNECTED_EDGES-Any edge connecting a content
          junction will be kept and reconnected to the collapsed container
          junction.

          * AGGREGATE_RECONNECTED_EDGES-Any edge connecting a content junction
          will be replaced by a reduction edge that is reconnected to the
          collapsed container junction. Multiple edges between two collapsed
          junctions will be systematically aggregated under the same reduction
          edge. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddCollapseContainerByAttributeRule_nd(*gp_fixargs((in_utility_network, template_name, is_active, container_source, where_clause, description, reconnected_edges_option), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddCollapseContainerRule_nd', None)
def AddCollapseContainerRule(in_utility_network=None, template_name=None, is_active=None, container_type=None, inverse_source_selection=None, container_sources=None, description=None, reconnected_edges_option=None):
    """AddCollapseContainerRule_nd(in_utility_network, template_name, is_active, container_type, inverse_source_selection, {container_sources;container_sources...}, {description}, {reconnected_edges_option})

        Adds a diagram rule that automatically collapses container contents
        during the building of diagrams based on an existing template. This
        rule collapses the entire contents of containers in the diagrams.This
        tool is a configuration and administration tool.When working with a
        utility network in an enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule will be enabled when generating and
          updating diagrams based on the specified template.

          * ACTIVE-The added rule will become enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule will not become enabled during the
          generation or update of any diagrams based on the input template.
      container_type (String):
          The geometry type of the source class container the rule will process.

          * JUNCTIONS-The Collapse Container rule will process the junction
          container source classes only, that is, the network polygon or point
          container source classes.

          * EDGES-The Collapse Container rule will process the edge container
          source classes only, that is, the network linear container source
          classes.

          * BOTH-The Collapse Container rule will process any container source
          classes regardless of their type; that is, both junction and edge
          types will be processed. This is the default.
      inverse_source_selection (String):
          Specifies how the rule will process the specified container source
          classes.

          * EXCLUDE_SOURCE_CLASSES-Any containers that are based on the
          specified source classes will not be collapsed, while other containers
          will be collapsed. This is the default.

          * INCLUDE_SOURCE_CLASSES-Any containers that are based on the
          specified source classes will be collapsed.
      container_sources {Table / Feature Class}:
          The network container source class (or classes) that will be excluded
          or included during the Collapse Container rule execution depending on
          the chosen rule process.With the Exclude Source Classes rule process,
          the rule can be
          configured without specifying a particular network source class, in
          which case it will collapse contents of any container source classes
          in the generated diagrams. However, with the Include Source Classes
          rule process, the particular container source class (or classes) to be
          collapsed must be specified.When running the Exclude Source Classes
          rule process, the contents
          related to any network container features belonging to those classes
          will never be collapsed in the generated diagrams, while contents
          related to network container features that don't belong to those
          classes will be collapsed. Conversely, when running the Include Source
          Classes rule process, the contents related to any network container
          features belonging to those classes will always be collapsed in the
          generated diagrams, while contents related to network container
          features that don't belong to those classes will not be collapsed.
      description {String}:
          The description of the rule.
      reconnected_edges_option {Boolean}:
          Specifies whether the rule will aggregate the edges that are
          reconnected to the collapsed junctions.

          * DONT_AGGREGATE_RECONNECTED_EDGES-Any edge connecting a content
          junction will be kept and reconnected to the collapsed container
          junction.

          * AGGREGATE_RECONNECTED_EDGES-Any edge connecting a content junction
          will be replaced by a reduction edge that is reconnected to the
          collapsed container junction. Multiple edges between two collapsed
          junctions will be systematically aggregated under the same reduction
          edge. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddCollapseContainerRule_nd(*gp_fixargs((in_utility_network, template_name, is_active, container_type, inverse_source_selection, container_sources, description, reconnected_edges_option), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddCompressionLayout_nd', None)
def AddCompressionLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, grouping_distance_absolute=None, vertices_removal_rule=None):
    """AddCompressionLayout_nd(in_utility_network, template_name, is_active, {are_containers_preserved}, {grouping_distance_absolute}, {vertices_removal_rule})

        Adds the Compression Layout algorithm to the layout list of the input
        diagram template so it automatically executes at the end of diagram
        buildings. This tool also presets the Compression Layout algorithm
        parameters for any diagram based on that template.This layout
        algorithm compresses the diagram features toward the
        middle of the diagram while trying to maintain relative positioning.
        It works from a distance that allows it to build junction groups that
        are moved as super nodes during the algorithm execution.This tool is a
        configuration and administration tool.When working with a utility
        network in an enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the layout algorithm will automatically execute
          when generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagram that is based on the template_name
          parameter. This is the default.The parameter values specified for the
          layout algorithm are used to run the layout during diagram generation.
          They are also loaded by default when the algorithm is to be run on any
          diagram based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be loaded by default when the algorithm is to be
          run on any diagram based on the input template.
      are_containers_preserved {Boolean}:
          Specifies how containers will be processed by the Compression layout
          algorithm.

          * PRESERVE_CONTAINERS-The Compression layout algorithm will execute
          on the top graph of the diagram so containers are preserved. This is
          the default.

          * IGNORE_CONTAINERS-The Compression layout algorithm will execute on
          both content and noncontent features in the diagram.
      grouping_distance_absolute {Linear Unit}:
          The grouping distance is used to determine whether two connected
          junctions are close enough to be considered part of the same junctions
          group. A junctions group represents many junctions that are moved as a
          group during execution. The group may contain both junctions and
          containers. To group two junctions together, they must also be
          connected in the diagram by an edge. The default is 20 units in the
          diagram's coordinate system.
      vertices_removal_rule {String}:
          Specifies which vertices along edges in the diagram will be removed.

          * ALL-All vertices on all edges will be removed from the diagram.

          * OUTER-Any edge vertices that are within the detected junctions'
          groups will be maintained, while edge vertices that are outside will
          be removed.When there are containers in the diagram that have edges
          that intersect the container polygons, a vertex is added at the
          intersection of the edge and container polygon. This is the default.

          * OUTER_EXCEPT_FIRST-Any edge vertices that are within the detected
          junctions' groups will be maintained, while edge vertices that are
          outside will be removed.When there are containers in the diagram that
          have edges that intersect the container polygons, the first (or last)
          outside vertex is preserved on edges that intersect a container
          polygon. A vertex is automatically inserted at the intersection of the
          edges and container polygons."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddCompressionLayout_nd(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, grouping_distance_absolute, vertices_removal_rule), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddConnectivityAssociationsRule_nd', None)
def AddConnectivityAssociationsRule(in_utility_network=None, template_name=None, is_active=None, description=None):
    """AddConnectivityAssociationsRule_nd(in_utility_network, template_name, is_active, {description})

        Adds a diagram rule to automatically represent connectivity
        associations during the building of diagrams based on an existing
        template. This rule processes connectivity associations for which both
        the from and to junctions are currently represented in the
        diagrams.This tool is a configuration and administration tool.When
        working with a utility network in an enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule will be enabled when generating and
          updating diagrams based on the specified template.

          * ACTIVE-The added rule will become enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule will not become enabled during the
          generation or update of any diagrams based on the input template.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddConnectivityAssociationsRule_nd(*gp_fixargs((in_utility_network, template_name, is_active, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddDiagramFeatureCapabilityByAttributeRule_nd', None)
def AddDiagramFeatureCapabilityByAttributeRule(in_utility_network=None, template_name=None, is_active=None, network_source=None, where_clause=None, capability=None, description=None):
    """AddDiagramFeatureCapabilityByAttributeRule_nd(in_utility_network, template_name, is_active, network_source, where_clause, capability, {description})

        Adds a diagram rule to a diagram template to assign a particular
        capability on diagram features currently represented in the diagram.
        This capability is used by some other rules executed later in the rule
        sequence. The diagram features to process are queried from a network
        source class by attributes.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule will be enabled when generating and
          updating diagrams based on the specified template.

          * ACTIVE-The added rule will become enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule will not become enabled during the
          generation or update of any diagrams based on the input template.
      network_source (Table / Feature Class):
          The network source class that references the features associated with
          the diagram features to which the particular capability will be
          assigned.
      where_clause (SQL Expression):
          An SQL expression used to filter out the features of interest among
          all the source class features. For more information on SQL syntax, see
          SQL reference for query expressions used in ArcGIS.
      capability (String):
          Specifies the capability that will be assigned to the queried diagram
          features at the end of the rule execution. This capability will be
          used by other rules executed later in the rule sequence.

          * PREVENT_TO_COLLAPSE_CONTAINER-All queried features will be flagged
          to prevent their containers from being collapsed by Collapse Container
          rules executed later in the rule sequence. This is the default.

          * ALLOW_TO_COLLAPSE_CONTAINER-All queried features will be flagged to
          allow their related container to be collapsed by Collapse Container
          rules executed later in the rule sequence.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddDiagramFeatureCapabilityByAttributeRule_nd(*gp_fixargs((in_utility_network, template_name, is_active, network_source, where_clause, capability, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddDiagramTemplate_nd', None)
def AddDiagramTemplate(in_utility_network=None, template_name=None, ndbd_file=None, ndld_file=None):
    """AddDiagramTemplate_nd(in_utility_network, template_name, {ndbd_file}, {ndld_file})

        Adds a new diagram template to a network. Both a network diagram rule
        and layout definitions file (.ndbd) and a network diagram layer
        definitions file (.ndld) can be imported.This tool is a configuration
        and administration tool.When working with a utility network in an
        enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network to which the template will be added.
      template_name (String):
          The name of the output diagram template.
      ndbd_file {File}:
          The network diagram rule and layout definitions file (.ndbd) to
          import. This file can be created using the Export Diagram Template
          Definitions tool on an existing template.
      ndld_file {File}:
          The diagram layer definitions file (.ndld) to import. This file can
          be created using the Export Diagram Template Definitions or Export
          Diagram Layer Definition tool on an existing template."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddDiagramTemplate_nd(*gp_fixargs((in_utility_network, template_name, ndbd_file, ndld_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddExpandContainerByAttributeRule_nd', None)
def AddExpandContainerByAttributeRule(in_utility_network=None, template_name=None, is_active=None, containers_visibility=None, container_source=None, where_clause=None, description=None):
    """AddExpandContainerByAttributeRule_nd(in_utility_network, template_name, is_active, containers_visibility, container_source, {where_clause}, {description})

        Adds a diagram rule to automatically expand contents related to
        containers during the building of diagrams based on an existing
        template. The containers to expand are filtered out from a given
        network source class by attributes.This tool is a configuration and
        administration tool.When working with a utility network in an
        enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule will be enabled when generating and
          updating diagrams based on the specified template.

          * ACTIVE-The added rule will become enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule will not become enabled during the
          generation or update of any diagrams based on the input template.
      containers_visibility (Boolean):
          Specifies whether the containers stay visible after they are
          expanded.

          *  KEEP_VISIBLE-The containers will stay visible after they are
          expanded. This is the default.

          * HIDE-The containers will be hidden after they are expanded.
      container_source (Table / Feature Class):
          The network container source class that references the containers you
          want to be expanded during the Expand Container rule process.
      where_clause {SQL Expression}:
          An SQL expression used to select the subset of containers in this
          class that will be expanded in the generated diagrams. For more
          information on SQL syntax, see the SQL reference for query expressions
          used in ArcGIS help topic.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddExpandContainerByAttributeRule_nd(*gp_fixargs((in_utility_network, template_name, is_active, containers_visibility, container_source, where_clause, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddExpandContainerRule_nd', None)
def AddExpandContainerRule(in_utility_network=None, template_name=None, is_active=None, containers_visibility=None, container_type=None, inverse_source_selection=None, container_sources=None, description=None):
    """AddExpandContainerRule_nd(in_utility_network, template_name, is_active, containers_visibility, container_type, inverse_source_selection, {container_sources;container_sources...}, {description})

        Adds a diagram rule that automatically expands container contents
        during the building of diagrams based on an existing template. This
        rule expands the entire contents of containers in the diagrams.This
        tool is a configuration and administration tool.When working with a
        utility network in an enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule will be enabled when generating and
          updating diagrams based on the specified template.

          * ACTIVE-The added rule will become enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule will not become enabled during the
          generation or update of any diagrams based on the input template.
      containers_visibility (Boolean):
          Specifies whether the containers stay visible after they are
          expanded.

          *  KEEP_VISIBLE-The containers will stay visible after they are
          expanded. This is the default.

          * HIDE-The containers will be hidden after they are expanded.
      container_type (String):
          The geometry type of the source class container the rule must process.

          * JUNCTIONS-The Expand Container rule process will operate on the
          junction container source classes only; that is, only the network
          polygon or point container source classes will be processed.

          * EDGES-The Expand Container rule process will operate on the edge
          container source classes only; that is, only the network linear
          container source classes will be processed.

          * BOTH-The Expand Container rule process will operate on any container
          source classes regardless of their type; that is, both junction and
          edge types will be processed. This is the default.
      inverse_source_selection (String):
          Determines how the rule processes the specified container source
          classes.

          * EXCLUDE_SOURCE_CLASSES-Containers based on the specified source
          classes will not be expanded, while other containers will be expanded.
          This is the default.

          * INCLUDE_SOURCE_CLASSES-Containers based on the specified source
          classes will be expanded.
      container_sources {Table / Feature Class}:
          The network container source class or classes that must be excluded
          or included during the Expand Container rule execution depending on
          the chosen rule process.With the Exclude Source Classes rule process,
          the rule can be
          configured without specifying any particular network source class; in
          which case, it will expand all containers in the generated diagrams
          regardless of their source class. However, with the Include Source
          Classes rule process, the particular container source class or classes
          to be expanded must be specified.When running the Exclude Source
          Classes option
          (inverse_source_selection=EXCLUDE_SOURCE_CLASSES in Python), the
          containers belonging to those classes will never be expanded in the
          generated diagrams, while network container features that don't belong
          to those classes will be expanded. Conversely, when running the
          Include Source Classes option
          (inverse_source_selection=INCLUDE_SOURCE_CLASSES in Python), the
          containers belonging to those classes will always be expanded in the
          generated diagrams, while network container features that don't belong
          to those classes will not be expanded.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddExpandContainerRule_nd(*gp_fixargs((in_utility_network, template_name, is_active, containers_visibility, container_type, inverse_source_selection, container_sources, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddForceDirectedLayout_nd', None)
def AddForceDirectedLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, iterations_number=None, repel_factor=None, degree_freedom=None, breakpoint_position=None, edge_display_type=None):
    """AddForceDirectedLayout_nd(in_utility_network, template_name, is_active, {are_containers_preserved}, {iterations_number}, {repel_factor}, {degree_freedom}, {breakpoint_position}, {edge_display_type})

        Adds the Force Directed Layout algorithm to the list of the layouts to
        be automatically chained at the end of the building of diagrams based
        on a given template. This tool also presets the Force Directed Layout
        algorithm parameters for any diagram based on that template.This
        layout algorithm uses a physical analogy to draw graphs by
        identifying a force system in which it tries to locally minimize the
        energy. It searches for an equilibrium state of the force system-a
        position for each diagram junction where the total force on each
        junction is zero.This tool is a configuration and administration
        tool.When working with a utility network in an enterprise geodatabase,
        it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the layout algorithm will automatically execute
          when generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagram that is based on the template_name
          parameter. This is the default.The parameter values specified for the
          layout algorithm are used to run the layout during diagram generation.
          They are also loaded by default when the algorithm is to be run on any
          diagram based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be loaded by default when the algorithm is to be
          run on any diagram based on the input template.
      are_containers_preserved {Boolean}:
          Specifies how the algorithm will process containers.

          * PRESERVE_CONTAINERS-The layout algorithm will execute on the top
          graph of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm will execute on both content
          and noncontent features in the diagram. This is the default.
      iterations_number {Long}:
          The number of iterations to process. The default is 20.
      repel_factor {Double}:
          Adds distance between diagram junctions that are close together. The
          larger the repel factor, the greater the distance that will be added
          between nearly overlapping diagram junctions. The default is 1.
      degree_freedom {String}:
          Specifies the area used to move the diagram junctions during each
          algorithm iteration.

          * LOW-The area used to move the diagram junctions will be very
          limited. This is the default.

          * HIGH-The area used to move the diagram junctions will be very large.

          * MEDIUM-The area used to move the diagram junctions will be moderate.
      breakpoint_position {Double}:
          The relative position of the two inflexion points that will be
          inserted along the diagram edges to compute the curved edges geometry
          when Edge Display Type is set to Curved edges
          (edges_display_type="CURVED_EDGES" in Python). It is a percentage
          between 15 and 40; the default is 30. For example, with a Break Point
          Relative Position (%) parameter value of N between 15 and 40, the
          following is true:

          * X being the x-coordinate of the edge's from junction and Y being the
          y-coordinate of the edge's to junction for a horizontal tree:

          * The first inflexion point will be positioned at N% of the length of
          the [XY] segment

          * The second inflexion point will be positioned at (100 - N)% of the
          length of the [XY] segment

          * Y being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree:

          * The first inflexion point will be positioned at N% of the length of
          the [YX] segment

          * The second inflexion point will be positioned at (100 - N)% of the
          length of the [XY] segment

          The concept of the from and to junctions above is relative to the tree
          direction; it is not related to the topology of the network feature
          edge.This parameter is ignored when the Edge Display Type parameter is
          set
          to Regular edges (edges_display_type="REGULAR_EDGES" in Python).
      edge_display_type {String}:
          Specifies the type of display for the diagram edges.

          * REGULAR_EDGES-All diagram edges display as straight lines. This is
          the default.

          * CURVED_EDGES-All diagram edges are curved."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddForceDirectedLayout_nd(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, iterations_number, repel_factor, degree_freedom, breakpoint_position, edge_display_type), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddGridLayout_nd', None)
def AddGridLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, cell_width_absolute=None, cell_height_absolute=None):
    """AddGridLayout_nd(in_utility_network, template_name, is_active, {are_containers_preserved}, {cell_width_absolute}, {cell_height_absolute})

        Adds the Grid Layout algorithm to the list of the layouts to be
        automatically chained at the end of the building of diagrams based on
        a given template. This tool also presets the Grid Layout algorithm
        parameters for any diagram based on that template.This algorithm
        positions diagram junctions relative to a magnetic grid
        that has cell sizes fixed by the Cell Width and Cell Height parameter
        values.This tool is a configuration and administration tool.When
        working with a utility network in an enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the layout algorithm will automatically execute
          when generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagram that is based on the template_name
          parameter. This is the default.The parameter values specified for the
          layout algorithm are used to run the layout during diagram generation.
          They are also loaded by default when the algorithm is to be run on any
          diagram based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be loaded by default when the algorithm is to be
          run on any diagram based on the input template.
      are_containers_preserved {Boolean}:
          Specifies how the algorithm will process containers.

          * PRESERVE_CONTAINERS-The layout algorithm will execute on the top
          graph of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm will execute on both content
          and noncontent features in the diagram. This is the default.
      cell_width_absolute {Linear Unit}:
          The width of each grid cell. The default is 2 in the units of the
          diagram's coordinate system.
      cell_height_absolute {Linear Unit}:
          The height of each grid cell. The default is 2 in the units of the
          diagram's coordinate system."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddGridLayout_nd(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, cell_width_absolute, cell_height_absolute), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddLinearDispatchLayout_nd', None)
def AddLinearDispatchLayout(in_utility_network=None, template_name=None, is_active=None, junction_placement_type=None, is_unit_absolute=None, maximum_shift_absolute=None, maximum_shift_proportional=None, minimum_shift_absolute=None, minimum_shift_proportional=None, iterations_number=None, is_path_preserved=None, are_leaves_moved=None, are_leaves_expanded=None, expand_shift_absolute=None, expand_shift_proportional=None):
    """AddLinearDispatchLayout_nd(in_utility_network, template_name, is_active, {junction_placement_type}, {is_unit_absolute}, {maximum_shift_absolute}, {maximum_shift_proportional}, {minimum_shift_absolute}, {minimum_shift_proportional}, {iterations_number}, {is_path_preserved}, {are_leaves_moved}, {are_leaves_expanded}, {expand_shift_absolute}, {expand_shift_proportional})

        Adds the Linear Dispatch Layout algorithm to the list of the layouts
        to be automatically chained at the end of the building of diagrams
        based on a given template. This tool also presets the Linear Dispatch
        Layout algorithm parameters for any diagram based on that
        template.This layout algorithm adds space between diagram junctions
        that are
        visually too close, overlapping, or coincident. It moves junctions
        along their connected edges. The movement along the edges depends on
        the current and relative position of junctions and on the layout
        parameters.This tool is a configuration and administration tool.When
        working with a utility network in an enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the layout algorithm will automatically execute
          when generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagram that is based on the template_name
          parameter. This is the default.The parameter values specified for the
          layout algorithm are used to run the layout during diagram generation.
          They are also loaded by default when the algorithm is to be run on any
          diagram based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be loaded by default when the algorithm is to be
          run on any diagram based on the input template.
      junction_placement_type {String}:
          Specifies how the junctions will be moved.

          *  EQUAL_DISTANCE-All junctions with two connected edges will be moved
          so the distances between them and their two connected junctions are
          equal. This is the default.

          *  USER_DEFINE_DISTANCE-All junctions with two connected edges will be
          moved so there is a minimum distance (minimum_shift_ parameter value)
          between them and the other end of the edges to which they connect.
          This occurs at the end of the layout execution.

          * ITERATIVE_DISTANCE-All junctions with two connected edges will be
          moved slightly  according to the iterations_number and maximum_shift_
          parameter values.
      is_unit_absolute {Boolean}:
          Specifies how parameters representing distances will be interpreted.

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the current diagram extent. This is the default.
      maximum_shift_absolute {Linear Unit}:
          The maximum distance the junctions with two connections will be
          spaced from the junctions to which they connect. The default is 2 in
          the units of the diagram's coordinate system. At the time this
          distance is reached, junctions will not be moved during following
          iterations. This parameter can only be used with the
          ITERATIVE_DISTANCE  junction placement type and absolute units.
      maximum_shift_proportional {Double}:
          The maximum distance the junctions with two connections will be
          spaced from the junctions to which they connect. The default is 2. At
          the time this distance is reached, junctions will not be moved during
          following iterations. This parameter can only be used with the
          ITERATIVE_DISTANCE  junction placement type and proportional units.
      minimum_shift_absolute {Linear Unit}:
          The minimum distance that will separate each junction with two
          connected edges from its two edge extremities after the layout
          execution. The default is 2 in the units of the diagram's coordinate
          system. When this parameter value is too large, the junctions with two
          connections are moved so the distances between each moved junction and
          its edge extremities are equal along the path defined by its two
          connected edges. This parameter can only be used with the
          USER_DEFINE_DISTANCE  junction placement type and absolute units.
      minimum_shift_proportional {Double}:
          The minimum distance that will separate each junction with two
          connected edges from its two edge extremities after the layout
          execution. The default is 2. When this parameter value is too large,
          the junctions with two connections are moved so the distances between
          each moved junction and its edge extremities are equal along the path
          defined by its two connected edges. This parameter is used with the
          USER_DEFINE_DISTANCE junction placement type and proportional units.
      iterations_number {Long}:
          The number of iterations to process. The default is 5. This parameter
          can only be used with the ITERATIVE_DISTANCE  junction placement type.
      is_path_preserved {Boolean}:
          Specifies how vertices along edges will be processed.

          *  PRESERVE_PATH-All vertices along the connected edges will be
          preserved, and new vertices will be added at the moved junctions'
          original locations. This is the default.

          *  IGNORE_PATH-Vertices along edges will not be preserved.
      are_leaves_moved {Boolean}:
          Specifies whether leaf junctions-junctions with one connection-will
          be moved during the algorithm execution.

          *  MOVE_LEAVES-Leaf junctions will be moved.

          *  DO_NOT_MOVE_LEAVES-Leaf junctions will not be moved. This is the
          default unless the specified input network diagram is based on a
          template for which the Linear Dispatch Layout algorithm has been
          configured with another parameter value.
      are_leaves_expanded {Boolean}:
          Specifies whether leaf junctions will be expanded:

          *  EXPAND_LEAVES-Leaf junctions will be expanded. The
          expand_shift_absolute parameter value specifies the maximum distance
          the leaf junctions can be expanded from the junctions to which they
          connect.

          *  DO_NOT_EXPAND_LEAVES-Leaf junctions will not be expanded. This is
          the default unless the specified input network diagram is based on a
          template for which the Linear Dispatch Layout algorithm has been
          configured with another parameter value.
      expand_shift_absolute {Linear Unit}:
          The maximum distance leaf junctions must be expanded from the
          junctions to which they connect. The default is 2 in the units of the
          diagram's coordinate system unless the specified input network diagram
          is based on a template for which the Linear Dispatch Layout algorithm
          has been configured with another parameter value. At the time this
          distance is reached, leaf junctions will not be moved during following
          iterations. This parameter can only be used with the Expand leaves
          parameter and absolute units.
      expand_shift_proportional {Double}:
          The maximum distance the leaf junctions will be expanded from the
          junctions to which they connect. The default is 2 unless the specified
          input network diagram is based on a template for which the Linear
          Dispatch Layout algorithm has been configured with another parameter
          value. At the time this distance is reached, leaf junctions will not
          be moved during following iterations. This parameter can only be used
          with the Expand leaves parameter and proportional units."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddLinearDispatchLayout_nd(*gp_fixargs((in_utility_network, template_name, is_active, junction_placement_type, is_unit_absolute, maximum_shift_absolute, maximum_shift_proportional, minimum_shift_absolute, minimum_shift_proportional, iterations_number, is_path_preserved, are_leaves_moved, are_leaves_expanded, expand_shift_absolute, expand_shift_proportional), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddMainRingLayout_nd', None)
def AddMainRingLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, ring_type=None, is_unit_absolute=None, ring_width_absolute=None, ring_width_proportional=None, ring_height_absolute=None, ring_height_proportional=None, tree_type=None, perpendicular_absolute=None, perpendicular_proportional=None, along_absolute=None, along_proportional=None, breakpoint_position=None, edge_display_type=None):
    """AddMainRingLayout_nd(in_utility_network, template_name, is_active, {are_containers_preserved}, {ring_type}, {is_unit_absolute}, {ring_width_absolute}, {ring_width_proportional}, {ring_height_absolute}, {ring_height_proportional}, {tree_type}, {perpendicular_absolute}, {perpendicular_proportional}, {along_absolute}, {along_proportional}, {breakpoint_position}, {edge_display_type})

        Adds the Main Ring Layout algorithm to the list of the layouts to be
        automatically chained at the end of the building of diagrams based on
        a given template. This tool also presets the Main Ring Layout
        algorithm parameters for any diagram based on that template.This
        layout algorithm arranges the diagram features around the main
        ring and hierarchically lays out the subset of diagram features that
        connect to each diagram junction placed along the main ring.This tool
        is a configuration and administration tool.When working with a utility
        network in an enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the layout algorithm will automatically execute
          when generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagram that is based on the template_name
          parameter. This is the default.The parameter values specified for the
          layout algorithm are used to run the layout during diagram generation.
          They are also loaded by default when the algorithm is to be run on any
          diagram based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be loaded by default when the algorithm is to be
          run on any diagram based on the input template.
      are_containers_preserved {Boolean}:
          Specifies how the algorithm will process containers.

          * PRESERVE_CONTAINERS-The layout algorithm will execute on the top
          graph of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm will execute on both content
          and noncontent features in the diagram. This is the default.
      ring_type {String}:
          Specifies the type of ring.

          * ELLIPSE-The diagram features of the detected main ring will display
          along an ellipse. This is the default.

          * RECTANGLE-The diagram features of the detected main ring will
          display along a rectangle.
      is_unit_absolute {Boolean}:
          Specifies how parameters representing distances will be interpreted.

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the current diagram extent. This is the default.
      ring_width_absolute {Linear Unit}:
          The width of the ring. The default is in the units of the diagram's
          coordinate system. This parameter can only be used with absolute
          units.
      ring_width_proportional {Double}:
          The width of the ring. The default is 50. This parameter can only be
          used with proportional units.
      ring_height_absolute {Linear Unit}:
          The height of the ring. The default is in the units of the diagram's
          coordinate system. This parameter can only be used with absolute
          units.
      ring_height_proportional {Double}:
          The height of the ring. The default is 20. This parameter can only be
          used with proportional units.
      tree_type {String}:
          Specifies how the trees coming out of the main ring's junctions will
          be positioned.

          * BOTH_SIDES-Each tree will be displayed along a main line, and its
          related branches will be arranged on both the left and right sides of
          this main line.

          * LEFT_SIDE-Each tree will be displayed hierarchically along a main
          line, and its related branches will be arranged on the left side of
          this main line.

          * RIGHT_SIDE-Each tree will be displayed hierarchically along a main
          line, and its related branches will be arranged on the right side of
          this main line.

          * SMART_TREE-Each tree will be displayed hierarchically as a smart
          tree. This is the default.
      perpendicular_absolute {Linear Unit}:
          The spacing between diagram junctions that are displayed perpendicular
          to the tree direction and belong to the same subtree level. The
          default is 2 in the units of the diagram's coordinate system. This
          parameter can only be used with absolute units.
      perpendicular_proportional {Double}:
          The spacing between diagram junctions that are displayed perpendicular
          to the tree direction and belong to the same subtree level. The
          default is 2. This parameter can only be used with proportional units.
      along_absolute {Linear Unit}:
          The spacing between diagram junctions that are displayed along the
          tree direction. The default is 2 in the units of the diagram's
          coordinate system. This parameter can only be used with absolute
          units.
      along_proportional {Double}:
          The spacing between diagram junctions that are displayed along the
          tree direction. The default is 2. This parameter can only be used with
          proportional units.
      breakpoint_position {Double}:
          The relative position of the break point that will be inserted along
          the diagram edges when Edge Display Type is Regular edges
          (edge_display_type = REGULAR_EDGES in Python) or Edge Display Type is
          Orthogonal edges (edge_display_type = ORTHOGONAL_EDGES in Python). It
          is a percentage between 0 and 100.

          * With a Break Point Relative Position (%) value of 0, the break point
          is positioned at the x-coordinate of the edge's from junction and at
          the y-coordinate of the edge's to junction for a horizontal tree. It
          is positioned at the y-coordinate of the edge's from junction and at
          the x-coordinate of the edge's to junction for a vertical tree.

          * With a Break Point Relative Position (%) value of 100, there is no
          break point inserted on the diagram edges; each diagram edge directly
          connects its from and to junctions.

          * With a Break Point Relative Position (%) value of N between 0 and
          100, the break point is positioned at N% of the length of the [XY]
          segment, X being the x-coordinate of the edge's from junction and Y
          being the y-coordinate of the edge's to junction for a horizontal
          tree. It is positioned at N% of the length of the [YX] segment, Y
          being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree.
          The relative position of the two inflection points that will be
          inserted along the diagram edges to compute the curved edges geometry
          when Edge Display Type is Curved edges (edge_display_type =
          CURVED_EDGES in Python). It is a percentage between 15 and 40. With a
          Break Point Relative Position (%) value of N between 15 and 40:

          * X being the x-coordinate of the edge's from junction and Y being the
          y-coordinate of the edge's to junction for a horizontal tree:

          * The first inflection point will be positioned at N% of the length of
          the [XY] segment.

          * The second inflection point will be positioned at (100 - N)% of the
          length of the [XY] segment.

          * Y being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree:

          * The first inflection point will be positioned at N% of the length of
          the [YX] segment.

          * The second inflection point will be positioned at (100 - N)% of the
          length of the [XY] segment.

          The concept of the from and to junctions above is relative to the tree
          direction; it has nothing to do with the real topology of the network
          feature edge.
      edge_display_type {String}:
          Specifies the type of display for the diagram edges related to the
          tree branches.

          * REGULAR_EDGES-All diagram edges related to the tree branches will
          not display with right angles. This is the default.

          * ORTHOGONAL_EDGES-All diagram edges related to the tree branches will
          display with right angles.

          * CURVED_EDGES-All diagram edges related to the tree branches will be
          curved."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddMainRingLayout_nd(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, ring_type, is_unit_absolute, ring_width_absolute, ring_width_proportional, ring_height_absolute, ring_height_proportional, tree_type, perpendicular_absolute, perpendicular_proportional, along_absolute, along_proportional, breakpoint_position, edge_display_type), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddMainlineTreeLayout_nd', None)
def AddMainlineTreeLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, tree_direction=None, branches_placement=None, is_unit_absolute=None, perpendicular_absolute=None, perpendicular_proportional=None, along_absolute=None, along_proportional=None, disjoined_graph_absolute=None, disjoined_graph_proportional=None, are_edges_orthogonal=None, breakpoint_position=None, edge_display_type=None):
    """AddMainlineTreeLayout_nd(in_utility_network, template_name, is_active, {are_containers_preserved}, {tree_direction}, {branches_placement}, {is_unit_absolute}, {perpendicular_absolute}, {perpendicular_proportional}, {along_absolute}, {along_proportional}, {disjoined_graph_absolute}, {disjoined_graph_proportional}, {are_edges_orthogonal}, {breakpoint_position}, {edge_display_type})

        Adds the Mainline Tree Layout algorithm to the list of the layouts to
        be automatically chained at the end of the building of diagrams based
        on a given template. This tool also presets the Mainline Tree Layout
        algorithm parameters for any diagram based on that template.This
        layout algorithm arranges the junctions and edges in the input
        network diagram hierarchically along a main line and places its
        related branches on the left side, the right side, or both sides of
        the main line.This tool is a configuration and administration
        tool.When working with a utility network in an enterprise geodatabase,
        it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the layout algorithm will automatically execute
          when generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagram that is based on the template_name
          parameter. This is the default.The parameter values specified for the
          layout algorithm are used to run the layout during diagram generation.
          They are also loaded by default when the algorithm is to be run on any
          diagram based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be loaded by default when the algorithm is to be
          run on any diagram based on the input template.
      are_containers_preserved {Boolean}:
          Specifies how the algorithm will process containers.

          * PRESERVE_CONTAINERS-The layout algorithm will execute on the top
          graph of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm will execute on both content
          and noncontent features in the diagram. This is the default.
      tree_direction {String}:
          Specifies the direction of the main line.

          * FROM_LEFT_TO_RIGHT-The main line will be drawn as a horizontal line
          starting from the left and ending on the right. This is the default.

          * FROM_RIGHT_TO_LEFT-The main line will be drawn as a horizontal line
          starting from the right and ending on the left.

          * FROM_BOTTOM_TO_TOP-The main line will be drawn as a vertical line
          starting from the bottom and ending at the top.

          * FROM_TOP_TO_BOTTOM-The main line will be drawn as a vertical line
          starting from the top and ending at the bottom.
      branches_placement {String}:
          Specifies how branches from the main line will be relatively placed
          with regard to its direction.

          * BOTH_SIDES-Branches will be placed on both the left and right sides
          of the main line. This is the default.

          * LEFT_SIDE-Branches will only be placed on the left side of the main
          line.

          * RIGHT_SIDE-Branches will only be placed on the right side of the
          main line.
      is_unit_absolute {Boolean}:
          Specifies how parameters representing distances will be interpreted.

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the current diagram extent. This is the default.
      perpendicular_absolute {Linear Unit}:
          The spacing between diagram junctions that are displayed along the
          axis perpendicular to the main line. The default is 2 in the diagram's
          coordinate system. This parameter can only be used with absolute
          units.
      perpendicular_proportional {Double}:
          The spacing between diagram junctions that are displayed along the
          axis perpendicular to the main line. The default is 2. This parameter
          can only be used with proportional units.
      along_absolute {Linear Unit}:
          The spacing between diagram junctions that are displayed along the
          main line, as well as the spacing between diagram junctions that are
          displayed along the axis parallel to the main line. This parameter can
          only be used with absolute units. The default is 2 in the units of the
          diagram's coordinate system.
      along_proportional {Double}:
          The spacing between diagram junctions that are displayed along the
          main line, as well as the spacing between diagram junctions that are
          displayed along the axis parallel to the main line. This parameter is
          used with proportional units. The default is 2.
      disjoined_graph_absolute {Linear Unit}:
          The minimum spacing that will separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is used with absolute units. The default is 4 in the units of the
          diagram's coordinate system.
      disjoined_graph_proportional {Double}:
          The minimum spacing that will separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is used with proportional units. The default is 4.
      are_edges_orthogonal {Boolean}:
          Specifies how diagram edges that are related to the tree branches will
          display.This parameter is deprecated at ArcGIS Pro 2.5. It is
          systematically
          ignored regardless of its value when the edge_display_type parameter
          is specified. However, to maintain compatibility with ArcGIS Pro 2.1,
          it remains enabled when the edge_display_type parameter is not
          specified.

          *  ORTHOGONAL_EDGES-All diagram edges related to the tree branches
          will display with right angles.

          *  SLANTED_EDGES-All diagram edges related to the tree branches will
          not display with right angles. This is the default.
      breakpoint_position {Double}:
          The relative position of the break point that will be inserted along
          the diagram edges when Edge Display Type is Regular edges
          (edge_display_type = REGULAR_EDGES in Python) or Edge Display Type is
          Orthogonal edges (edge_display_type = ORTHOGONAL_EDGES in Python). It
          is a percentage between 0 and 100.

          * With a Break Point Relative Position (%) value of 0, the break point
          is positioned at the x-coordinate of the edge's from junction and at
          the y-coordinate of the edge's to junction for a horizontal tree. It
          is positioned at the y-coordinate of the edge's from junction and at
          the x-coordinate of the edge's to junction for a vertical tree.

          * With a Break Point Relative Position (%) value of 100, there is no
          break point inserted on the diagram edges; each diagram edge directly
          connects its from and to junctions.

          * With a Break Point Relative Position (%) value of N between 0 and
          100, the break point is positioned at N% of the length of the [XY]
          segment, X being the x-coordinate of the edge's from junction and Y
          being the y-coordinate of the edge's to junction for a horizontal
          tree. It is positioned at N% of the length of the [YX] segment, Y
          being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree.
          The relative position of the two inflection points that will be
          inserted along the diagram edges to compute the curved edges geometry
          when Edge Display Type is Curved edges (edge_display_type =
          CURVED_EDGES in Python). It is a percentage between 15 and 40. With a
          Break Point Relative Position (%) value of N between 15 and 40:

          * X being the x-coordinate of the edge's from junction and Y being the
          y-coordinate of the edge's to junction for a horizontal tree:

          * The first inflection point will be positioned at N% of the length of
          the [XY] segment.

          * The second inflection point will be positioned at (100 - N)% of the
          length of the [XY] segment.

          * Y being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree:

          * The first inflection point will be positioned at N% of the length of
          the [YX] segment.

          * The second inflection point will be positioned at (100 - N)% of the
          length of the [XY] segment.

          The concept of the from and to junctions above is relative to the tree
          direction; it has nothing to do with the real topology of the network
          feature edge.
      edge_display_type {String}:
          Specifies the type of display for the diagram edges related to the
          tree branches.

          * REGULAR_EDGES-All diagram edges related to the tree branches will
          not display with right angles. This is the default.

          * ORTHOGONAL_EDGES-All diagram edges related to the tree branches will
          display with right angles.

          * CURVED_EDGES-All diagram edges related to the tree branches will be
          curved."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddMainlineTreeLayout_nd(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, tree_direction, branches_placement, is_unit_absolute, perpendicular_absolute, perpendicular_proportional, along_absolute, along_proportional, disjoined_graph_absolute, disjoined_graph_proportional, are_edges_orthogonal, breakpoint_position, edge_display_type), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddPartialOverlappingEdgesLayout_nd', None)
def AddPartialOverlappingEdgesLayout(in_utility_network=None, template_name=None, is_active=None, buffer_width_absolute=None, offset_absolute=None, optimize_edges=None):
    """AddPartialOverlappingEdgesLayout_nd(in_utility_network, template_name, is_active, buffer_width_absolute, offset_absolute, {optimize_edges})

        Adds the Partial Overlapping Edges Layout algorithm to the list of the
        layouts to be automatically chained at the end of the building of
        diagrams based on a given template. This tool also presets the Partial
        Overlapping Edges Layout algorithm parameters for any diagram based on
        that template.This layout algorithm detects sets of collinear edges or
        collinear
        portions of edges (edge segments) that can be considered as being
        inside a buffer zone of a given size.This tool is a configuration and
        administration tool.When working with a utility network in an
        enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the layout algorithm will automatically execute
          when generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagram that is based on the template_name
          parameter. This is the default.The parameter values specified for the
          layout algorithm are used to run the layout during diagram generation.
          They are also loaded by default when the algorithm is to be run on any
          diagram based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be loaded by default when the algorithm is to be
          run on any diagram based on the input template.
      buffer_width_absolute (Linear Unit):
          The width of the buffer zone in which to search for collinear edge
          segments.
      offset_absolute (Linear Unit):
          The distance that will separate the detected edge segments.
      optimize_edges {Boolean}:
          Specifies how segments are placed along edges:

          *  OPTIMIZE_EDGES-The placement of segments will be optimized in each
          set of collinear segments. This is done by focusing on their
          connections instead of their positions. Segments that cross each other
          can be repositioned so they do not cross.

          *  DO_NOT_OPTIMIZE_EDGES-The initial position of each segment will be
          maintained in the collinear segment set and crossings will be
          preserved. This is the default option."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddPartialOverlappingEdgesLayout_nd(*gp_fixargs((in_utility_network, template_name, is_active, buffer_width_absolute, offset_absolute, optimize_edges), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddRadialTreeLayout_nd', None)
def AddRadialTreeLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, is_unit_absolute=None, initial_radius_absolute=None, initial_radius_proportional=None, disjoined_graph_absolute=None, disjoined_graph_proportional=None, radius_factor=None):
    """AddRadialTreeLayout_nd(in_utility_network, template_name, is_active, {are_containers_preserved}, {is_unit_absolute}, {initial_radius_absolute}, {initial_radius_proportional}, {disjoined_graph_absolute}, {disjoined_graph_proportional}, {radius_factor})

        Adds the Radial Tree Layout algorithm to the list of the layouts to
        be automatically chained at the end of the building of diagrams based
        on a given template. This tool also presets the Radial Tree Layout
        algorithm parameters for any diagram based on that template.This
        layout algorithm arranges the diagram features hierarchically and
        places them in a radial tree according to the specified radius
        parameters. It works from a root junction that it uses as the circle
        center to arrange the subtrees starting from this root in concentric
        circles, each circle corresponding to one hierarchical level.This tool
        is a configuration and administration tool.When working with a utility
        network in an enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the layout algorithm will automatically execute
          when generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagram that is based on the template_name
          parameter. This is the default.The parameter values specified for the
          layout algorithm are used to run the layout during diagram generation.
          They are also loaded by default when the algorithm is to be run on any
          diagram based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be loaded by default when the algorithm is to be
          run on any diagram based on the input template.
      are_containers_preserved {Boolean}:
          Specifies how the algorithm will process containers.

          * PRESERVE_CONTAINERS-The layout algorithm will execute on the top
          graph of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm will execute on both content
          and noncontent features in the diagram. This is the default.
      is_unit_absolute {Boolean}:
          Specifies how parameters representing distances will be interpreted.

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the current diagram extent. This is the default.
      initial_radius_absolute {Linear Unit}:
          The radius of the first concentric circle whose center is the radial
          tree root junction; that is, the radius of the circle around which the
          diagram junctions belonging to the first hierarchical level are
          placed. The default is 5 in the units of the diagram's coordinate
          system. This parameter can only be used with absolute units.
      initial_radius_proportional {Double}:
          The radius of the first concentric circle whose center is the radial
          tree root junction; that is, the radius of the circle around which the
          diagram junctions belonging to the first hierarchical level are
          placed. The default is 5. This parameter can only be used with
          proportional units.
      disjoined_graph_absolute {Linear Unit}:
          The minimum spacing that will separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is used with absolute units. The default is 4 in the units of the
          diagram's coordinate system.
      disjoined_graph_proportional {Double}:
          The minimum spacing that will separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is used with proportional units. The default is 4.
      radius_factor {Double}:
          The multiplicative factor used to increase or decrease the radius of
          each concentric circle. It is also the distance that separates each
          concentric circle related to a hierarchical level. When using a radius
          factor less than 1, the distance that separates the diagram junctions
          belonging to the (n) hierarchical level and the (n+1) hierarchical
          level progressively decreases. With a factor greater than 1, the
          distance between the hierarchical levels increases progressively. The
          default is 1."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddRadialTreeLayout_nd(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, is_unit_absolute, initial_radius_absolute, initial_radius_proportional, disjoined_graph_absolute, disjoined_graph_proportional, radius_factor), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddReduceEdgeByAttributeRule_nd', None)
def AddReduceEdgeByAttributeRule(in_utility_network=None, template_name=None, is_active=None, network_source=None, where_clause=None, description=None, reconnected_edges_option=None):
    """AddReduceEdgeByAttributeRule_nd(in_utility_network, template_name, is_active, network_source, {where_clause}, {description}, {reconnected_edges_option})

        Adds a diagram rule to automatically reduce diagram edges during the
        building of diagrams based on an existing template. This rule can be
        set up to reduce diagram edges by attributes.This tool is a
        configuration and administration tool.When working with a utility
        network in an enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule will be enabled when generating and
          updating diagrams based on the specified template.

          * ACTIVE-The added rule will become enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule will not become enabled during the
          generation or update of any diagrams based on the input template.
      network_source (Table / Feature Class):
          The network edge source class to process during the reduction rule.
          All diagram edges related to network lines that belong to this source
          class are candidates for the reduction.
      where_clause {SQL Expression}:
          An SQL expression used to select the subset of network edges among
          the edges that are candidates for the reduction that will be reduced
          in the diagrams based on the input template. For more information on
          SQL syntax, see the SQL reference for query expressions used in ArcGIS
          help topic.
      description {String}:
          The description of the rule.
      reconnected_edges_option {Boolean}:
          Specifies whether the rule must aggregate the edges that are
          reconnected to the reduction junctions or not.

          * DONT_AGGREGATE_RECONNECTED_EDGES-Any edge connecting a point along
          the edge that is reduced is kept and simply reconnected to the
          reduction junction.

          * AGGREGATE_RECONNECTED_EDGES-Any edge connecting a point along the
          edge that is reduced is replaced by a reduction edge. This reduction
          edge is reconnected to the reduction junction. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddReduceEdgeByAttributeRule_nd(*gp_fixargs((in_utility_network, template_name, is_active, network_source, where_clause, description, reconnected_edges_option), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddReduceJunctionByAttributeRule_nd', None)
def AddReduceJunctionByAttributeRule(in_utility_network=None, template_name=None, is_active=None, junction_source=None, where_clause=None, connectivity_options=None, unconnected_junctions=None, one_connected_junction=None, two_connected_junctions=None, edges_attributes=None, description=None):
    """AddReduceJunctionByAttributeRule_nd(in_utility_network, template_name, is_active, junction_source, {where_clause}, {connectivity_options}, {unconnected_junctions}, {one_connected_junction}, {two_connected_junctions}, {edges_attributes;edges_attributes...}, {description})

        Adds a diagram rule to automatically reduce diagram junctions during
        the building of diagrams based on an existing template. The junctions
        to reduce are queried from a given network junction source class by
        attributes according to the number of other junctions they are
        connected to.This tool is a configuration and administration tool.When
        working with a utility network in an enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule will be enabled when generating and
          updating diagrams based on the specified template.

          * ACTIVE-The added rule will become enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule will not become enabled during the
          generation or update of any diagrams based on the input template.
      junction_source (Table / Feature Class):
          The network junction source class to process during the reduction
          rule. All diagram junctions related to network junctions that belong
          to this source class are candidates for the reduction.
      where_clause {SQL Expression}:
          An SQL expression used to select the subset of network junctions
          among the junctions that are candidates for the reduction that will be
          reduced in the diagrams based on the input template. For more
          information on SQL syntax, see the SQL reference for query expressions
          used in ArcGIS help topic.
      connectivity_options {String}:
          This parameter allows specifying which kind of reduction the rule
          will process.

          * MAX_2_CONNECTED_JUNCTIONS-The rule will process junctions that have
          two connections or fewer. In this case, the rule executes a specific
          process according to the number of junctions that the junction to
          reduce connects. This is the default.

          * MIN_3_CONNECTED_JUNCTIONS-The rule will process junctions that have
          three connections or more. In this case, the rule will execute
          upstream traces to determine whether or not the junctions that are
          candidates for the reduction can be reduced.
      unconnected_junctions {Boolean}:
          This option is available when the rule is configured to run with the
          Maximum two connected junctions connectivity option. It determines
          whether each network diagram unconnected junction that is a candidate
          for the reduction is reduced or kept.

          *  REDUCE_UNCONNECTED_JCT-The rule will reduce the diagram junctions
          that are candidates for the reduction that are unconnected. Each of
          those junctions will be removed.

          *  KEEP_UNCONNECTED_JCT-The rule will keep the unconnected diagram
          junctions. This is the default.
      one_connected_junction {Boolean}:
          This option is available when the rule is configured to run with the
          Maximum two connected junctions connectivity option. It determines
          whether each network diagram junction that is a candidate for the
          reduction and connected to a single other junction is reduced or kept.

          *  REDUCE_JCT_TO_1JCT-The rule will reduce the diagram junctions that
          are candidates for the reduction and connected to a single junction.
          Each of those junctions and its incident edge will be reduced onto its
          single connected junction.

          *  KEEP_JCT_TO_1JCT-The rule will keep the diagram junctions that are
          candidates for the reduction and connected to a single junction. This
          is the default.
      two_connected_junctions {Boolean}:
          This option is available when the rule is configured to run with the
          Maximum two connected junctions connectivity option. It determines
          whether each network diagram junction connected to two different other
          junctions that is a candidate for the reduction is reduced or kept:

          *  REDUCE_JCT_TO_2JCTS-The rule will reduce the diagram junctions that
          are candidates for the reduction and connect two other junctions. Each
          of those junctions and its incident edges will be reduced onto a super
          span edge, the reduction edge. This is the default.

          *  KEEP_JCT_TO_2JCTS-The rule will keep the diagram junctions that are
          candidates for the reduction and connect two other junctions.
      edges_attributes {String}:
          The alias of the attributes brought by the edges adjacent to the
          junction that is a candidate for the reduction.The junction will be
          reduced only when all its adjacent edges have
          brought the same values for each of the specified attribute aliases.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddReduceJunctionByAttributeRule_nd(*gp_fixargs((in_utility_network, template_name, is_active, junction_source, where_clause, connectivity_options, unconnected_junctions, one_connected_junction, two_connected_junctions, edges_attributes, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddReduceJunctionRule_nd', None)
def AddReduceJunctionRule(in_utility_network=None, template_name=None, is_active=None, inverse_source_selection=None, junction_source=None, connectivity_options=None, unconnected_junctions=None, one_connected_junction=None, two_connected_junctions=None, edges_attributes=None, description=None):
    """AddReduceJunctionRule_nd(in_utility_network, template_name, is_active, inverse_source_selection, {junction_source;junction_source...}, {connectivity_options}, {unconnected_junctions}, {one_connected_junction}, {two_connected_junctions}, {edges_attributes;edges_attributes...}, {description})

        Adds a diagram rule to automatically reduce diagram junctions during
        the building of diagrams based on an existing template. This rule
        reduces junctions based on several network junction source classes
        according to the number of other junctions to which they are
        connected.This tool is a configuration and administration tool.When
        working with
        a utility network in an enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule will be enabled when generating and
          updating diagrams based on the specified template.

          * ACTIVE-The added rule will become enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule will not become enabled during the
          generation or update of any diagrams based on the input template.
      inverse_source_selection (String):
          How the rule processes the specified junction source classes.

          * EXCLUDE_SOURCE_CLASSES-The junctions based on the specified source
          classes will not be processed by the Reduce Junction rule, while all
          the other junctions will be.

          * INCLUDE_SOURCE_CLASSES-The junctions based on only the specified
          source classes will be processed by the Reduce Junction rule. This is
          the default.
      junction_source {Table / Feature Class}:
          The junction source class (or classes) that must be excluded or
          included during the Reduce Junction rule execution depending on the
          chosen rule process. With the Include source classes rule process set
          by default, the
          Reduce Junction rule expects one or more network junction source
          classes to process during the rule execution. All diagram junctions
          related to network junctions that belong to those source classes are
          candidates for the reductions. The Reduce Junction rule will process
          the junction source classes in
          the order specified in this list, from the junction class with the
          highest priority-the first class in the list-to the junction class
          with the lowest priority-the last class in the list.With the Exclude
          source classes rule process, the rule can be
          configured without specifying any particular junction source class; in
          that case, it will reduce all junctions in the generated diagrams,
          whatever their source class.
      connectivity_options {String}:
          This parameter allows specifying which kind of reduction the rule
          will process.

          * MAX_2_CONNECTED_JUNCTIONS-The rule will process junctions that have
          two connections or fewer. In this case, the rule executes a specific
          process according to the number of junctions that the junction to
          reduce connects. This is the default.

          * MIN_3_CONNECTED_JUNCTIONS-The rule will process junctions that have
          three connections or more. In this case, the rule will execute
          upstream traces to determine whether or not the junctions that are
          candidates for the reduction can be reduced.
      unconnected_junctions {Boolean}:
          This option is available when the rule is configured to run with the
          Maximum two connected junctions connectivity option. It determines
          whether each network diagram unconnected junction that is a candidate
          for the reduction is reduced or kept.

          *  REDUCE_UNCONNECTED_JCT-The rule will reduce the diagram junctions
          that are candidates for the reduction that are unconnected. Each of
          those junctions will be removed.

          *  KEEP_UNCONNECTED_JCT-The rule will keep the unconnected diagram
          junctions. This is the default.
      one_connected_junction {Boolean}:
          This option is available when the rule is configured to run with the
          Maximum two connected junctions connectivity option. It determines
          whether each network diagram junction that is a candidate for the
          reduction and connected to a single other junction is reduced or kept.

          *  REDUCE_JCT_TO_1JCT-The rule will reduce the diagram junctions that
          are candidates for the reduction and connected to a single junction.
          Each of those junctions and its incident edge will be reduced onto its
          single connected junction.

          *  KEEP_JCT_TO_1JCT-The rule will keep the diagram junctions that are
          candidates for the reduction and connected to a single junction. This
          is the default.
      two_connected_junctions {Boolean}:
          This option is available when the rule is configured to run with the
          Maximum two connected junctions connectivity option. It determines
          whether each network diagram junction connected to two different other
          junctions that is a candidate for the reduction is reduced or kept:

          *  REDUCE_JCT_TO_2JCTS-The rule will reduce the diagram junctions that
          are candidates for the reduction and connect two other junctions. Each
          of those junctions and its incident edges will be reduced onto a super
          span edge, the reduction edge. This is the default.

          *  KEEP_JCT_TO_2JCTS-The rule will keep the diagram junctions that are
          candidates for the reduction and connect two other junctions.
      edges_attributes {String}:
          The alias of the attributes brought by the edges adjacent to the
          junction that is a candidate for the reduction.The junction will be
          reduced only when all its adjacent edges have
          brought the same values for each of the specified attribute aliases.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddReduceJunctionRule_nd(*gp_fixargs((in_utility_network, template_name, is_active, inverse_source_selection, junction_source, connectivity_options, unconnected_junctions, one_connected_junction, two_connected_junctions, edges_attributes, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddRelativeMainlineLayout_nd', None)
def AddRelativeMainlineLayout(in_utility_network=None, template_name=None, is_active=None, line_attribute=None, mainline_direction=None, offset_between_branches=None, breakpoint_angle=None, type_attribute=None, mainline_values=None, branch_values=None, excluded_values=None, is_compressing=None, compression_ratio=None, minimal_distance=None, alignment_attribute=None, initial_distances=None, length_attribute=None):
    """AddRelativeMainlineLayout_nd(in_utility_network, template_name, is_active, line_attribute, {mainline_direction}, {offset_between_branches}, {breakpoint_angle}, {type_attribute}, {mainline_values;mainline_values...}, {branch_values;branch_values...}, {excluded_values;excluded_values...}, {is_compressing}, {compression_ratio}, {minimal_distance}, {alignment_attribute}, {initial_distances}, {length_attribute})

        Adds the Relative Mainline Layout algorithm to the list of layouts to
        be automatically chained at the end of the building of diagrams based
        on a given template. This tool also presets the Relative Mainline
        Layout algorithm parameters for any diagram based on that
        template.This layout arranges the network diagram features in the
        active
        diagram along parallel straight lines, with all the connected edges
        having the same attribute value. It also places the branches from
        those lines, preserving their directions regarding the straight lines
        and the distances proportional to the initial distance and relative to
        each other.This tool is a configuration and administration tool.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the layout algorithm will automatically execute
          when generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagram that is based on the template_name
          parameter. This is the default.The parameter values specified for the
          layout algorithm are used to run the layout during diagram generation.
          They are also loaded by default when the algorithm is to be run on any
          diagram based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be loaded by default when the algorithm is to be
          run on any diagram based on the input template.
      line_attribute (String):
          The name of the network attribute that will be used to identify the
          lines that comprise the straight lines. This network attribute must
          exist in the network line classes. Its values should be the same for
          all the edges that comprise a straight line, for example, Line 1, Line
          2, and so on
      mainline_direction {String}:
          Specifies the direction of the main line.

          * FROM_LEFT_TO_RIGHT-The main line will be drawn as a horizontal line
          starting from the left and ending on the right. This is the default.

          * FROM_TOP_TO_BOTTOM-The main line will be drawn as a vertical line
          starting from the top and ending at the bottom.
      offset_between_branches {Linear Unit}:
          The spacing between two adjacent branches along the axis
          perpendicular to the direction of the lines.
      breakpoint_angle {Double}:
          The angle that will be used to position the break point on the
          branches. It is a value between 30 and 90 degrees that is combined
          with the offset_between_branches parameter value to compute this
          position. When the break point angle value is 90 degrees, each branch
          displays orthogonally.
      type_attribute {String}:
          The name of the network attribute that will be used to qualify the
          lines. This network attribute may exist in the network line
          classes.The type_attribute and line_attribute network attributes can
          be the
          same.
      mainline_values {Value Table}:
          The type_attribute values that identify the main lines. When such
          values exist, they must be the same for any edge that comprises the
          main lines, regardless of their related network feature classes.
      branch_values {Value Table}:
          The type_attribute values that identify the branches.
      excluded_values {Value Table}:
          The type_attribute values that identify the edges that must be
          excluded from the straight lines (crossovers or ladders).
      is_compressing {Boolean}:
          Specifies whether the graph will be compressed.

          * USE_COMPRESSION-An additional step is executed at the end of the
          process to reduce the distances between adjacent groups of neighbor
          junctions along the direction while maintaining relative positioning
          between these groups. Neighbor junctions are junctions that are
          geographically close to each other without being directly connected.

          * DO_NOT_USE_COMPRESSION-Compression will not be used. This is the
          default.
      compression_ratio {Double}:
          A value between 0 and 100 that is applied to the length of any edge
          after subtracting the minimal distance of its length. When
          compression_ratio is 100, the distance between each detected junction
          group is equal to the minimal distance.
      minimal_distance {Linear Unit}:
          The minimal distance between two adjacent groups of neighbor
          junctions. This minimal distance is also used to group neighbor
          junctions regarding their projection along the direction axis. Two
          junctions projected on this axis will belong to the same group when
          the distance between the two projected points is less than this
          distance.
      alignment_attribute {String}:
          The name of the network attribute that will be used to align lines
          that are split. The algorithm aligns the line with the same attribute
          value.
      initial_distances {String}:
          Specifies how the length of the diagram edges will be assessed. This
          length determines the positions of the junctions along the direction.
          The distances between the connected junctions along the direction are
          not equidistant; they are relative to each other and depend on the
          current edge length and the length of the shortest edge.

          * FROM_CURRENT_EDGE_GEOMETRY-The distances will be computed from the
          current edge geometry. This is the default.

          * FROM_ATTRIBUTE_EDGE-The distances will be computed from a given
          attribute that exists on an edge.
      length_attribute {String}:
          The network attribute from which the distances will be computed when
          initial_distances is FROM_ATTRIBUTE_EDGE."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddRelativeMainlineLayout_nd(*gp_fixargs((in_utility_network, template_name, is_active, line_attribute, mainline_direction, offset_between_branches, breakpoint_angle, type_attribute, mainline_values, branch_values, excluded_values, is_compressing, compression_ratio, minimal_distance, alignment_attribute, initial_distances, length_attribute), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddRemoveFeatureByAttributeRule_nd', None)
def AddRemoveFeatureByAttributeRule(in_utility_network=None, template_name=None, is_active=None, network_source=None, where_clause=None, description=None):
    """AddRemoveFeatureByAttributeRule_nd(in_utility_network, template_name, is_active, network_source, {where_clause}, {description})

        Adds a diagram rule to automatically remove diagram features during
        the building of diagrams based on an existing template. The features
        to remove are queried from a given network source class.This tool is a
        configuration and administration tool.When working with a utility
        network in an enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule will be enabled when generating and
          updating diagrams based on the specified template.

          * ACTIVE-The added rule will become enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule will not become enabled during the
          generation or update of any diagrams based on the input template.
      network_source (Table / Feature Class):
          The network source class to process during the Remove Feature rule.
          All diagram features related to network features that belong to this
          source class are candidates for removal.
      where_clause {SQL Expression}:
          An SQL expression used to select the subset of features among the
          features that are candidates for removal from the diagrams based on
          the input template. For more information on SQL syntax, see the SQL
          reference for query expressions used in ArcGIS help topic.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddRemoveFeatureByAttributeRule_nd(*gp_fixargs((in_utility_network, template_name, is_active, network_source, where_clause, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddRemoveFeatureRule_nd', None)
def AddRemoveFeatureRule(in_utility_network=None, template_name=None, is_active=None, source_type=None, inverse_source_selection=None, network_source=None, description=None):
    """AddRemoveFeatureRule_nd(in_utility_network, template_name, is_active, source_type, inverse_source_selection, network_source;network_source..., {description})

        Adds a diagram rule to automatically remove diagram features during
        the building of diagrams based on an existing template. This rule
        removes features based on different network source classes.This tool
        is a configuration and administration tool.When working with a utility
        network in an enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule will be enabled when generating and
          updating diagrams based on the specified template.

          * ACTIVE-The added rule will become enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule will not become enabled during the
          generation or update of any diagrams based on the input template.
      source_type (String):
          The geometry type of the source class feature the rule must process.

          * JUNCTIONS-Only junction source classes will be processed; that is,
          the network polygon or point source classes.

          * EDGES-Only edge source classes will be processed; that is, the
          network linear source classes.

          * BOTH-Both junction and edge types will be processed. This is the
          default.
      inverse_source_selection (String):
          Specifies how the rule will process the specified network source
          classes.

          * EXCLUDE_SOURCE_CLASSES-Features based on the specified network
          source classes will not be processed by the Remove Feature rule. while
          other features will be processed.

          * INCLUDE_SOURCE_CLASSES-Features based on the specified network
          source classes will be processed by the Remove Feature rule. This is
          the default.
      network_source (Table / Feature Class):
          The network source class or classes that must be excluded or included
          during the Remove Feature rule execution depending on the chosen rule
          process.By default, with the include source classes rule process, the
          Remove
          Feature rule expects one or more network source classes to process
          during the rule execution. All diagram features related to network
          features that belong to those classes are removed.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddRemoveFeatureRule_nd(*gp_fixargs((in_utility_network, template_name, is_active, source_type, inverse_source_selection, network_source, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddReshapeDiagramEdgesLayout_nd', None)
def AddReshapeDiagramEdgesLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, reshape_type=None, is_path_preserved=None, offset_between_segment_absolute=None, breakpoint_absolute=None, shift_between_edge_absolute=None, angle_threshold=None, circular_arc_radius=None, circular_arc_position=None):
    """AddReshapeDiagramEdgesLayout_nd(in_utility_network, template_name, is_active, {are_containers_preserved}, {reshape_type}, {is_path_preserved}, {offset_between_segment_absolute}, {breakpoint_absolute}, {shift_between_edge_absolute}, {angle_threshold}, {circular_arc_radius}, {circular_arc_position})

        Adds the Reshape Diagram Edges Layout algorithm to the list of the
        layouts to be automatically chained at the end of the building of
        diagrams based on a given template. This tool also presets the Reshape
        Diagram Edges Layout algorithm parameters for any diagram based on
        that template.This layout is used to process simple operations on
        vertices along
        edges in network diagrams. It allows you to do the following:

        * Remove all vertices along diagram edges.

        * Reduce some vertices along diagram edges.

        * Square diagram edges with the addition of vertices on edges.

        * Separate diagram edges that overlap.

        * Detect diagram edges that cross each other at right angles and
        reshape their geometries to display a circular arc at the crossing
        locations.
        This tool is a configuration and administration tool.When working with
        a utility network in an enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the layout algorithm will automatically execute
          when generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagram that is based on the template_name
          parameter. This is the default.The parameter values specified for the
          layout algorithm are used to run the layout during diagram generation.
          They are also loaded by default when the algorithm is to be run on any
          diagram based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be loaded by default when the algorithm is to be
          run on any diagram based on the input template.
      are_containers_preserved {Boolean}:
          Specifies how the algorithm will process containers.

          * PRESERVE_CONTAINERS-The layout algorithm will execute on the top
          graph of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm will execute on both content
          and noncontent features in the diagram. This is the default.
      reshape_type {String}:
          Specifies how edges will be reshaped.

          * REMOVE_VERTICES-Vertices along any edges in the diagram will be
          removed.

          * SQUARE_EDGES-Vertices will be placed along diagram edges, and the
          edges will be displayed with right angles. This is the default.

          * SEPARATE_OVERLAPPING_EDGES-Edges that connect the same origin and
          extremity junctions will be separated when they are overlapping.

          * REDUCE_VERTICES_BY_ANGLE-Some or all vertices displayed along
          diagram edges will be reduced according to the angle that separates
          the segments incident to those vertices.

          * MARK_CROSSING_EDGES-The horizontal and vertical diagram edges that
          cross each other at a right angle in the diagram will be marked, and
          the geometry of one of the crossing edges will be reshaped to display
          a circular arc at this location.
      is_path_preserved {Boolean}:
          Specifies whether vertices along the edges that are going to be
          squared will be preserved. This parameter can only be used when
          reshape_type is SQUARE_EDGES.

          *  PRESERVE_PATH-The direction of any edge will be considered, and
          vertices along that edge will be preserved from the first vertex to
          the last. This is the default.

          * IGNORE_PATH-Vertices along the diagram edges will not be considered,
          and the vertices will be removed during execution.
      offset_between_segment_absolute {Linear Unit}:
          The spacing that will separate parallel segments of squared edges
          incident to the same junction. The default is 5 in the units of the
          diagram's coordinate system. This parameter can only be used when
          reshape_type is SQUARE_EDGES.
      breakpoint_absolute {Linear Unit}:
          The maximum distance between each junction to the first or last break
          point along edges incident to that junction when those edges are
          squared. The default is 8.66 in the units of the diagram's coordinate
          system. This parameter can only be used when reshape_type is
          SQUARE_EDGES.
      shift_between_edge_absolute {Linear Unit}:
          The absolute spacing that will separate two edges. The default is 0.5
          in the units of the diagram's coordinate system. This parameter can
          only be used when reshape_type is SEPARATE_OVERLAPPING_EDGES.
      angle_threshold {Double}:
          The angle formed by the incident segments over which the vertex
          related to these segments is reduced. The wider the angle, the fewer
          number of vertices are reduced. The default is 160 degrees. This
          parameter can only be used when reshape_type is
          REDUCE_VERTICES_BY_ANGLE.
      circular_arc_radius {Linear Unit}:
          The radius of the circular arc that will be added to the crossing
          edge locations. The default is 5.
      circular_arc_position {String}:
          Specifies the segment on which a circular arc will be placed.

          * LEFT_OF_VERTICAL_SEGMENT-A circular arc will be placed to the left
          of the vertical segment.

          * RIGHT_OF_VERTICAL_SEGMENT-A circular arc will be placed to the right
          of the vertical segment.

          * ABOVE_HORIZONTAL_SEGMENT-A circular arc will be placed above the
          horizontal segment.

          * BELOW_HORIZONTAL_SEGMENT-A circular arc will be placed below the
          horizontal segment."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddReshapeDiagramEdgesLayout_nd(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, reshape_type, is_path_preserved, offset_between_segment_absolute, breakpoint_absolute, shift_between_edge_absolute, angle_threshold, circular_arc_radius, circular_arc_position), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddSetRootJunctionByAttributeRule_nd', None)
def AddSetRootJunctionByAttributeRule(in_utility_network=None, template_name=None, is_active=None, junction_source=None, where_clause=None, description=None):
    """AddSetRootJunctionByAttributeRule_nd(in_utility_network, template_name, is_active, junction_source, {where_clause}, {description})

        Adds a diagram rule to automatically flag diagram junctions as root
        junctions during the building of diagrams based on an existing
        template. This rule specifies root junctions based on a particular
        source class and eventually filters using their attributes.This tool
        is a configuration and administration tool.When working with a utility
        network in an enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule will be enabled when generating and
          updating diagrams based on the specified template.

          * ACTIVE-The added rule will become enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule will not become enabled during the
          generation or update of any diagrams based on the input template.
      junction_source (Table / Feature Class):
          The network junction source class to process during the Set Root
          Junction By Attribute rule. All diagram junctions related to network
          features that belong to this source class are candidates for root
          junctions.
      where_clause {SQL Expression}:
          An optional SQL expression used to filter out the expected root
          junctions among all the junction candidates for root junctions for the
          diagrams based on the input template. For more information on SQL
          syntax, see SQL reference for query expressions used in ArcGIS.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddSetRootJunctionByAttributeRule_nd(*gp_fixargs((in_utility_network, template_name, is_active, junction_source, where_clause, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddSetStartingPointByAttributeRule_nd', None)
def AddSetStartingPointByAttributeRule(in_utility_network=None, template_name=None, is_active=None, network_source=None, where_clause=None, junction_terminals=None, description=None):
    """AddSetStartingPointByAttributeRule_nd(in_utility_network, template_name, is_active, network_source, {where_clause}, {junction_terminals;junction_terminals...}, {description})

        Adds a diagram rule to a diagram template to set diagram features
        currently represented in the diagrams as starting points for tracing
        rules. The diagram features are queried from a given network source
        class and can be filtered by their attributes.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule will be enabled when generating and
          updating diagrams based on the specified template.

          * ACTIVE-The added rule will become enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule will not become enabled during the
          generation or update of any diagrams based on the input template.
      network_source (Table / Feature Class):
          The network source class that references the features that will be
          set as starting points.
      where_clause {SQL Expression}:
          An SQL expression to select the subset of features in the source
          class that will be set as starting points. For more information on SQL
          syntax, see SQL reference for query expressions used in ArcGIS.
      junction_terminals {Long}:
          The terminal IDs that will be considered to start tracing if the
          network source class references junctions with terminals.The terminal
          IDs are all listed in the Terminal Configurations section
          on the Network Properties tab.When both the where_clause and
          junction_terminals parameters are
          configured, the specified terminals must correspond to queried
          features; otherwise, no starting points will be set.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddSetStartingPointByAttributeRule_nd(*gp_fixargs((in_utility_network, template_name, is_active, network_source, where_clause, junction_terminals, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddSmartTreeLayout_nd', None)
def AddSmartTreeLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, tree_direction=None, is_unit_absolute=None, subtree_absolute=None, subtree_proportional=None, perpendicular_absolute=None, perpendicular_proportional=None, along_absolute=None, along_proportional=None, disjoined_graph_absolute=None, disjoined_graph_proportional=None, are_edges_orthogonal=None, breakpoint_position=None, edge_display_type=None):
    """AddSmartTreeLayout_nd(in_utility_network, template_name, is_active, {are_containers_preserved}, {tree_direction}, {is_unit_absolute}, {subtree_absolute}, {subtree_proportional}, {perpendicular_absolute}, {perpendicular_proportional}, {along_absolute}, {along_proportional}, {disjoined_graph_absolute}, {disjoined_graph_proportional}, {are_edges_orthogonal}, {breakpoint_position}, {edge_display_type})

        Adds the Smart Tree Layout algorithm to the list of the layouts to be
        automatically chained at the end of the building of diagrams based on
        a given template. This tool also presets the Smart Tree Layout
        algorithm parameters for any diagram based on that template.This
        layout algorithm arranges the diagram features hierarchically and
        places them in a smart tree according to the direction and spacing
        distances specified.This tool is a configuration and administration
        tool.When working with a utility network in an enterprise geodatabase,
        it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the layout algorithm will automatically execute
          when generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagram that is based on the template_name
          parameter. This is the default.The parameter values specified for the
          layout algorithm are used to run the layout during diagram generation.
          They are also loaded by default when the algorithm is to be run on any
          diagram based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be loaded by default when the algorithm is to be
          run on any diagram based on the input template.
      are_containers_preserved {Boolean}:
          Specifies how the algorithm will process containers.

          * PRESERVE_CONTAINERS-The layout algorithm will execute on the top
          graph of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm will execute on both content
          and noncontent features in the diagram. This is the default.
      tree_direction {String}:
          Specifies the direction of the tree.

          * FROM_LEFT_TO_RIGHT-The tree will be drawn from left to right. This
          is the default.

          * FROM_RIGHT_TO_LEFT-The tree will be drawn from right to left.

          * FROM_BOTTOM_TO_TOP-The tree will be drawn from bottom to top.

          * FROM_TOP_TO_BOTTOM-The tree will be drawn from top to bottom.
      is_unit_absolute {Boolean}:
          Specifies how parameters representing distances will be interpreted.

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the current diagram extent. This is the default.
      subtree_absolute {Linear Unit}:
          The spacing between two neighboring subtrees; that is, the spacing
          between diagram junctions that are displayed perpendicular to the
          smart tree direction and belong to a different subtree. The default is
          in the units of the diagram's coordinate system. This parameter can
          only be used with absolute units.
      subtree_proportional {Double}:
          The spacing between two neighboring subtrees; that is, the spacing
          between diagram junctions that are displayed perpendicular to the
          smart tree direction and belong to a different subtree. The default is
          2. This parameter can only be used with proportional units.
      perpendicular_absolute {Linear Unit}:
          The spacing between diagram junctions that are displayed perpendicular
          to the smart tree direction and belong to the same subtree level. The
          default is 2 in the units of the diagram's coordinate system. This
          parameter can only be used with absolute units.
      perpendicular_proportional {Double}:
          The spacing between diagram junctions that are displayed
          perpendicular to the smart tree direction and belong to the same
          subtree level. The default is 2. This parameter can only be used with
          proportional units.
      along_absolute {Linear Unit}:
          The spacing between diagram junctions that are displayed along the
          smart tree direction. The default is 2 in the units of the diagram's
          coordinate system. This parameter can only be used with absolute
          units.
      along_proportional {Double}:
          The spacing between diagram junctions that are displayed along the
          smart tree direction. The default is 2. This parameter can only be
          used with proportional units.
      disjoined_graph_absolute {Linear Unit}:
          The minimum spacing that will separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is used with absolute units. The default is 4 in the units of the
          diagram's coordinate system.
      disjoined_graph_proportional {Double}:
          The minimum spacing that will separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is used with proportional units. The default is 4.
      are_edges_orthogonal {Boolean}:
          Specifies how diagram edges that are related to the tree branches will
          display.This parameter is deprecated at ArcGIS Pro 2.5. It is
          systematically
          ignored regardless of its value when the edge_display_type parameter
          is specified. However, to maintain compatibility with ArcGIS Pro 2.1,
          it remains enabled when the edge_display_type parameter is not
          specified.

          *  ORTHOGONAL_EDGES-All diagram edges related to the tree branches
          will display with right angles.

          *  SLANTED_EDGES-All diagram edges related to the tree branches will
          not display with right angles. This is the default.
      breakpoint_position {Double}:
          The relative position of the break point that will be inserted along
          the diagram edges when Edge Display Type is Regular edges
          (edge_display_type = REGULAR_EDGES in Python) or Edge Display Type is
          Orthogonal edges (edge_display_type = ORTHOGONAL_EDGES in Python). It
          is a percentage between 0 and 100.

          * With a Break Point Relative Position (%) value of 0, the break point
          is positioned at the x-coordinate of the edge's from junction and at
          the y-coordinate of the edge's to junction for a horizontal tree. It
          is positioned at the y-coordinate of the edge's from junction and at
          the x-coordinate of the edge's to junction for a vertical tree.

          * With a Break Point Relative Position (%) value of 100, there is no
          break point inserted on the diagram edges; each diagram edge directly
          connects its from and to junctions.

          * With a Break Point Relative Position (%) value of N between 0 and
          100, the break point is positioned at N% of the length of the [XY]
          segment, X being the x-coordinate of the edge's from junction and Y
          being the y-coordinate of the edge's to junction for a horizontal
          tree. It is positioned at N% of the length of the [YX] segment, Y
          being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree.
          The relative position of the two inflection points that will be
          inserted along the diagram edges to compute the curved edges geometry
          when Edge Display Type is Curved edges (edge_display_type =
          CURVED_EDGES in Python). It is a percentage between 15 and 40. With a
          Break Point Relative Position (%) value of N between 15 and 40:

          * X being the x-coordinate of the edge's from junction and Y being the
          y-coordinate of the edge's to junction for a horizontal tree:

          * The first inflection point will be positioned at N% of the length of
          the [XY] segment.

          * The second inflection point will be positioned at (100 - N)% of the
          length of the [XY] segment.

          * Y being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree:

          * The first inflection point will be positioned at N% of the length of
          the [YX] segment.

          * The second inflection point will be positioned at (100 - N)% of the
          length of the [XY] segment.

          The concept of the from and to junctions above is relative to the tree
          direction; it has nothing to do with the real topology of the network
          feature edge.
      edge_display_type {String}:
          Specifies the type of display for the diagram edges related to the
          tree branches.

          * REGULAR_EDGES-All diagram edges related to the tree branches will
          not display with right angles. This is the default.

          * ORTHOGONAL_EDGES-All diagram edges related to the tree branches will
          display with right angles.

          * CURVED_EDGES-All diagram edges related to the tree branches will be
          curved."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddSmartTreeLayout_nd(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, tree_direction, is_unit_absolute, subtree_absolute, subtree_proportional, perpendicular_absolute, perpendicular_proportional, along_absolute, along_proportional, disjoined_graph_absolute, disjoined_graph_proportional, are_edges_orthogonal, breakpoint_position, edge_display_type), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddSpatialDispatchLayout_nd', None)
def AddSpatialDispatchLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, iterations_number=None, maximum_shift_factor=None):
    """AddSpatialDispatchLayout_nd(in_utility_network, template_name, is_active, {are_containers_preserved}, {iterations_number}, {maximum_shift_factor})

        Adds the Spatial Dispatch Layout algorithm to the list of the layouts
        to be automatically chained at the end of the building of diagrams
        based on a given template. This tool also presets the Spatial Dispatch
        Layout algorithm parameters for any diagram based on that
        template.This layout algorithm progressively separates diagram
        junctions that
        are visibly close to overlapping according to their current positions
        and to the shift factor specified.This tool is a configuration and
        administration tool.When working with a utility network in an
        enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the layout algorithm will automatically execute
          when generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagram that is based on the template_name
          parameter. This is the default.The parameter values specified for the
          layout algorithm are used to run the layout during diagram generation.
          They are also loaded by default when the algorithm is to be run on any
          diagram based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be loaded by default when the algorithm is to be
          run on any diagram based on the input template.
      are_containers_preserved {Boolean}:
          Specifies how the algorithm will process containers.

          * PRESERVE_CONTAINERS-The layout algorithm will execute on the top
          graph of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm will execute on both content
          and noncontent features in the diagram. This is the default.
      iterations_number {Long}:
          The number of iterations to process. The default is 5.
      maximum_shift_factor {Double}:
          The maximum value used to increase the diagram junctions' displacement
          for junctions that are very close together. The greater the shift
          factor, the larger the separation between the diagram junctions that
          almost overlap. The default is 2."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddSpatialDispatchLayout_nd(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, iterations_number, maximum_shift_factor), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddSpatialQueryRule_nd', None)
def AddSpatialQueryRule(in_utility_network=None, template_name=None, is_active=None, added_features=None, overlap_type=None, existing_features=None, search_distance=None, added_where_clause=None, existing_where_clause=None, description=None):
    """AddSpatialQueryRule_nd(in_utility_network, template_name, is_active, added_features, overlap_type, existing_features, {search_distance}, {added_where_clause}, {existing_where_clause}, {description})

        Adds a diagram rule that automatically appends new network features to
        the diagrams based on their location relative to the network features
        currently represented in the diagram.This tool is a configuration and
        administration tool.When working with
        a utility network in an enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule will be enabled when generating and
          updating diagrams based on the specified template.

          * ACTIVE-The added rule will become enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule will not become enabled during the
          generation or update of any diagrams based on the input template.
      added_features (Feature Class):
          The source feature class to which you want to add features
      overlap_type (String):
          The spatial relationship to be evaluated.

          *  INTERSECT-The features in the added_features source feature class
          will be appended to the diagram if they intersect one of the
          existing_features. This is the default.

          *  WITHIN_A_DISTANCE-The features in the added_features source
          feature class will be appended to the diagram if they are within the
          specified distance (using Euclidean distance) of one of the
          existing_features. Use the search_distance parameter to specify the
          distance.

          *  CONTAINS-The features in the added_features source feature class
          will be appended to the diagram if they contain or are contained of
          the existing_features.

          *  WITHIN-The features in the added_features source feature class
          will be appended to the diagram if they are within existing_features.

          *  BOUNDARY_TOUCHES-The features in the added_features source feature
          class will be appended to the diagram if they have a boundary that
          touches one of the existing_features. When the existing_features are
          lines or polygons, the boundary of the added_features can only touch
          the boundary of one of the existing_features, and no part of the input
          feature can cross the boundary of one of the existing_features.

          *  SHARE_A_LINE_SEGMENT_WITH-The features in the added_features
          source feature class will be appended to the diagram if they share a
          line segment with one of the existing_features. The added and existing
          features must be line or polygon.

          *  CROSSED_BY_THE_OUTLINE_OF-The features in the added_features
          source feature class will be appended to the diagram if they are
          crossed by the outline of one of the existing_features. The added and
          existing features must be lines or polygons. If polygons are used for
          the existing_features, the polygon's boundary (line) will be used.
          Lines that cross at a point will be appended; lines that share a line
          segment will not.
      existing_features (Feature Class):
          The source feature class of the features existing in the diagram from
          which the spatial query will execute.
      search_distance {Linear Unit}:
          This parameter is only valid if the overlap_type parameter is set to
          INTERSECT, WITHIN_A_DISTANCE, CONTAINS, or WITHIN
      added_where_clause {SQL Expression}:
          The SQL query that will be used to filter the features to be added to
          the diagram. Without an SQL query, the features based on the specified
          source class that are spatially related to the specified existing
          features will be appended to the diagram.
      existing_where_clause {SQL Expression}:
          The SQL query that will be used to filter the features existing in
          the diagram. Without an SQL query, the features based on the specified
          source class that exist in the diagram will be considered.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddSpatialQueryRule_nd(*gp_fixargs((in_utility_network, template_name, is_active, added_features, overlap_type, existing_features, search_distance, added_where_clause, existing_where_clause, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddStartIterationRule_nd', None)
def AddStartIterationRule(in_utility_network=None, template_name=None, is_active=None, description=None):
    """AddStartIterationRule_nd(in_utility_network, template_name, is_active, {description})

        Adds a diagram rule to specify the beginning of a rule sequence
        during the building of diagrams based on an existing template.This
        tool is a configuration and administration tool.When working with a
        utility network in an enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule will be enabled when generating and
          updating diagrams based on the specified template.

          * ACTIVE-The added rule will become enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule will not become enabled during the
          generation or update of any diagrams based on the input template.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddStartIterationRule_nd(*gp_fixargs((in_utility_network, template_name, is_active, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddStopIterationRule_nd', None)
def AddStopIterationRule(in_utility_network=None, template_name=None, is_active=None, description=None):
    """AddStopIterationRule_nd(in_utility_network, template_name, is_active, {description})

        Adds a diagram rule to specify the end of a rule sequence during the
        building of diagrams based on an existing template.This tool is a
        configuration and administration tool.When working with a utility
        network in an enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule will be enabled when generating and
          updating diagrams based on the specified template.

          * ACTIVE-The added rule will become enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule will not become enabled during the
          generation or update of any diagrams based on the input template.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddStopIterationRule_nd(*gp_fixargs((in_utility_network, template_name, is_active, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddStructuralAttachmentsRule_nd', None)
def AddStructuralAttachmentsRule(in_utility_network=None, template_name=None, is_active=None, description=None):
    """AddStructuralAttachmentsRule_nd(in_utility_network, template_name, is_active, {description})

        Adds a diagram rule to automatically represent structural attachments
        during the building of diagrams based on an existing template. This
        rule processes structural attachment associations for which both the
        attached feature and structure feature are currently represented in
        the diagrams.This tool is a configuration and administration tool.When
        working with a utility network in an enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule will be enabled when generating and
          updating diagrams based on the specified template.

          * ACTIVE-The added rule will become enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule will not become enabled during the
          generation or update of any diagrams based on the input template.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddStructuralAttachmentsRule_nd(*gp_fixargs((in_utility_network, template_name, is_active, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddTraceRule_nd', None)
def AddTraceRule(in_utility_network=None, template_name=None, is_active=None, trace_type=None, domain_network=None, tier=None, target_tier=None, include_structures=None, include_barriers=None, condition_barriers=None, function_barriers=None, traversability_scope=None, filter_barriers=None, filter_function_barriers=None, filter_scope=None, filter_bitset_network_attribute_name=None, filter_nearest=None, nearest_count=None, nearest_cost_network_attribute=None, nearest_categories=None, nearest_assets=None, propagators=None, description=None, allow_indeterminate_flow=None, path_direction=None, path_network_weight_name=None):
    """AddTraceRule_nd(in_utility_network, template_name, is_active, trace_type, {domain_network}, {tier}, {target_tier}, {include_structures}, {include_barriers}, {condition_barriers;condition_barriers...}, {function_barriers;function_barriers...}, {traversability_scope}, {filter_barriers;filter_barriers...}, {filter_function_barriers;filter_function_barriers...}, {filter_scope}, {filter_bitset_network_attribute_name}, {filter_nearest}, {nearest_count}, {nearest_cost_network_attribute}, {nearest_categories;nearest_categories...}, {nearest_assets;nearest_assets...}, {propagators;propagators...}, {description}, {allow_indeterminate_flow}, {path_direction}, {path_network_weight_name})

        Adds a diagram rule to automatically execute a trace on the network
        during the building of diagrams based on an existing template. The
        resulting traced network features are used to build the diagram
        content.This tool is a configuration and administration tool.When
        working with a utility network in an enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule will be enabled when generating and
          updating diagrams based on the specified template.

          * ACTIVE-The added rule will become enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule will not become enabled during the
          generation or update of any diagrams based on the input template.
      trace_type (String):
          The type of trace the rule must perform to build the diagram content.

          * CONNECTED-A connected trace is executed from the utility network
          features currently represented in the diagram when the rule starts and
          spans outward along connected features. This is the default.

          * SUBNETWORK-A subnetwork trace is executed from the utility network
          features currently represented in the diagram when the rule starts and
          spans outward along connected features to find sources or sinks from
          which it spans outward along the related subnetwork.

          * UPSTREAM-An upstream trace is executed from the utility network
          features currently represented in the diagram when the rule starts to
          discover features upstream.

          * DOWNSTREAM-A downstream trace is executed from the utility network
          features currently represented in the diagram when the rule starts to
          discover features downstream.

          * SHORTEST_PATH-A shortest path trace is executed from the trace
          network features currently specified as starting points in the diagram
          when the rule starts to discover the features along the shortest path
          between those starting points. The cost of traversing the path is
          determined based on the network weight set for the
          path_network_weight_name value regardless of flow direction.
      domain_network {String}:
          The name of the domain network where the trace is run for a utility
          network. This parameter is needed when running the subnetwork,
          upstream, and downstream trace types.
      tier {String}:
          The name of the tier where the trace starts for a utility network.
          This parameter is optional when running the connected trace type; it
          is required when running the subnetwork, upstream, and downstream
          trace types.
      target_tier {String}:
          The name of the target tier to which the input tier flows for a
          utility network.  If this parameter is missing for upstream and
          downstream traces, those traces will stop when they reach the boundary
          of the starting subnetwork. This parameter can be used to allow these
          traces to continue either farther up or farther down the hierarchy.
      include_structures {Boolean}:
          Specifies whether structure features will be included in the trace
          results.

          * INCLUDE_STRUCTURES-Structure features will be included in the trace
          results.

          * EXCLUDE_STRUCTURES-Structure features will not be included in the
          trace results. This is the default.
      include_barriers {Boolean}:
          Specifies whether the traversability barrier features will be included
          in the trace results. Traversability barriers are optional even if
          they have been preset in the subnetwork definition. This parameter
          does not apply to device features with terminals.

          * INCLUDE_BARRIERS-Traversability barrier features will be included in
          the trace results. This is the default.

          * EXCLUDE_BARRIERS-Traversability barrier features will not be
          included in the trace results.
      condition_barriers {Value Table}:
          Sets a traversability barrier condition on features based on a
          comparison to a network attribute or check for a category string. A
          condition barrier uses a network attribute, an operator and a type,
          and an attribute value. For example, stop a trace when a feature has
          the attribute Device Status equal to the specific value of Open. When
          a feature meets this condition, the trace stops. If you're using more
          than one attribute, you can use the Combine using parameter to define
          an And or an Or condition.Condition barrier components are as follows:

          * Name-Filter by any network attribute defined in the system.

          * Operator-Choose from a number of different operators.

          * Type-Choose a specific value or network attribute from the value
          that is specified in the name parameter.

          * Value-Provide a specific value for the input attribute type that
          would cause termination based on the operator value.

          * Combine Using-Set this value if you have multiple attributes to add.
          You can combine them using an And or an Or condition.
          The condition barriers operator value options are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES_NOT_INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INCLUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
          The condition barriers Type value options are as follows:

          * SPECIFIC_VALUE-Filter by a specific value.

          * NETWORK_ATTRIBUTE-Filter by a network attribute.
          The condition barriers Combine Using value options are as follows:

          * AND-Combine the condition barriers.

          * OR-Use if either condition barrier is met.
      function_barriers {Value Table}:
          Sets a traversability barrier on features based on a function.
          Function barriers can be used to do such things as restrict how far
          the trace travels from the starting point, or set a maximum value to
          stop a trace. For example, the length of each line traveled is added
          to the total distance traveled so far. When the total length traveled
          reaches the value specified, the trace stops.Function barrier
          components are as follows:

          * Function-Choose from a number of different calculation functions.

          * Attribute-Filter by any network attribute defined in the system.

          * Operator-Choose from a number of different operators.

          * Value-Provide a specific value for the input attribute type that, if
          discovered, will cause the termination.

          * Use Local Values-Calculate values in each direction as opposed to an
          overall global value. For example, a function barrier that is
          calculating the sum of Shape length where the trace terminates if the
          value is greater than or equal to 4. In the global case, after you
          have traversed two edges with a value of 2, you will have already
          reached a shape length sum of 4, so the trace stops. If local values
          are used, the local values along each path change, and the trace
          continues.
          The function barrier function value options are as follows:

          * AVERAGE-The average of the input values.

          * COUNT-The number of features.

          * MAX-The maximum of the input values.

          * MIN-The minimum of the input values.

          * ADD-The sum of the values.

          * SUBTRACT-The difference between the values. Subnetwork controllers
          and loops trace types do not support the subtract function.
          The function barrier operator value options are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES_NOT_INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INCLUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
          The function barrier Use Local Values options are as follows:

          * TRUE-Use local values.

          * FALSE-Use global values. This is the default.
      traversability_scope {String}:
          The type of traversability to enforce. Traversability scope dictates
          whether traversability is enforced at junctions, edges, or both. For
          example, if a condition barrier is defined to stop the trace if Device
          Status is equal to Open and traversability scope is set to edges only,
          then even if the trace encounters an open device, the trace would not
          stop because Device Status is only applicable to junctions. In other
          words, this parameter indicates to the trace whether to ignore
          junctions, edges, or both.

          * BOTH_JUNCTIONS_AND_EDGES-Apply traversability to both junctions and
          edges. This is the default.

          * JUNCTIONS_ONLY-Apply traversability to only junctions.

          * EDGES_ONLY-Apply traversability to only edges.
      filter_barriers {Value Table}:
          Specifies when a trace should stop for a specific category or network
          attribute. For example, stop a trace at features that have a life
          cycle status attribute that is equal to a certain value. This
          parameter is used to set a terminator based on a value of a network
          attribute that is defined in the system. If using more than one
          attribute, you can use the Combine Using option to define an And or an
          Or condition.Filter barrier components are as follows:

          * Name-Choose to filter by category or any network attribute defined
          in the system.

          * Operator-Choose from a number of different operators.

          * Type-Choose a specific value or network attribute from the value
          that is specified in the name parameter.

          * Value-Provide a specific value of the input attribute type that
          would cause termination based on the operator value.

          * Combine Using-Set this value if you have multiple attributes to add.
          You can choose to combine them using an And or an Or condition.
          The filter barriers operator value options are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES NOT INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INLCUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
          The filter barriers Type value options are as follows:

          * SPECIFIC_VALUE-Filter by a specific value.

          * NETWORK_ATTRIBUTE-Filter by a network attribute.
          The filter barriers Combine Using value options are as follows:

          * AND-Combine the condition barriers.

          * OR-Use if either condition barrier is met.
      filter_function_barriers {Value Table}:
          Filters the results of the trace for a specific category.Filter
          function barriers components are as follows:

          * Function-Choose from a number of different calculation functions.

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Value-Provide a specific value for the input attribute type that, if
          discovered, will cause the termination.

          * Use Local Values-Calculates values in each direction as opposed to
          an overall global value. For example, a function barrier that is
          calculating the sum of Shape length where the trace terminates if the
          value is greater than or equal to 4. In the global case, after you
          have traversed two edges with a value of 2, you will have already
          reached a shape length sum of 4, so the trace stops. If local values
          are used, the local values along each path change, or the trace
          continues.
          The filter function barriers function value options are as follows:

          * AVERAGE-The average of the input values.

          * COUNT-The number of features.

          * MAX-The maximum of the input values.

          * MIN-The minimum of the input values.

          * ADD-The sum of the values.

          * SUBTRACT-The difference between the values. Subnetwork controllers
          and loops trace types do not support the subtract function.
          The filter function barriers operator value options are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES_NOT_INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INCLUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
          The filter function barriers Use Local Values options are as follows:

          * TRUE-Use local values.

          * FALSE-Use global values. This is the default.
      filter_scope {String}:
          Specifies whether the filter for a specific category will be enforced
          at junctions, edges, or both. For example, if a filter barrier is
          defined to stop the trace if Device Status is equal to Open and
          traversability scope is set to edges only, then even if the trace
          encounters an open device, the trace will not stop because Device
          Status is only applicable to junctions. In other words, this parameter
          indicates to the trace whether to ignore junctions, edges, or both.

          * BOTH_JUNCTIONS_AND_EDGES-The filter will be applied to both
          junctions and edges. This is the default.

          * JUNCTIONS_ONLY-The filter will be applied to junctions only.

          * EDGES_ONLY-The filter will be applied to edges only.
      filter_bitset_network_attribute_name {String}:
          The name of the network attribute that can be used to filter by
          bitset. This parameter is only applicable to upstream, downstream, and
          loops trace types. This parameter can be used to add special logic
          during a trace so the trace is more reflective of real world
          scenarios. For example, for a loops trace, the Phases current network
          attribute can determine if the loop is a true electrical loop (the
          same phase is energized all around the loop, that is, A) and return
          only real electrical loops for the trace results. An example for an
          upstream trace is when tracing an electric distribution network,
          specify a Phases current network attribute, and the trace results will
          only include valid paths that are the specified in the network
          attribute, not all paths.
      filter_nearest {Boolean}:
          Specifies whether the k-nearest neighbors algorithm will be used to
          return a number of features of a certain type within a given distance.
          When this parameter is used, you can specify a count and a cost as
          well as a collection of categories, an asset type, or both.

          * FILTER_BY_NEAREST-The k-nearest neighbors algorithm will be used to
          return a number of features as specified in the nearest_count,
          nearest_cost_network_attribute, nearest_categories, or nearest_assets
          parameter.

          * DO_NOT_FILTER-The k-nearest neighbors algorithm will not be used to
          filter results. This is the default.
      nearest_count {Long}:
          The number of features to be returned when filter_nearest is True.
      nearest_cost_network_attribute {String}:
          The numeric network attribute that will be used to calculate nearness,
          cost, or distance when filter_nearest is True-for example,  Shape
          length.
      nearest_categories {String}:
          The categories that will be returned when filter_nearest is True-for
          example, Protective.
      nearest_assets {String}:
          The asset groups and asset types that will be returned when
          filter_nearest is True-for example,
          ElectricDistributionDevice/Transformer/Step Down.
      propagators {Value Table}:
          Specifies the network attributes to propagate as well as how that
          propagation should occur during a trace. Propagated class attributes
          denote the key values on subnetwork controllers that are disseminated
          to the rest of the features in the subnetwork. For example, in an
          electric distribution model, you can propagate the phase
          value.Propagators components are as follows:

          * Attribute-Filter by any network attribute defined in the system.

          * Substitution Attribute-Use a substituted value instead of bitset
          network attribute values. Substitutions are encoded based on the
          number of bits in the network attribute being propagated. A
          substitution is a mapping of each bit in phase to another bit. For
          example, for Phase AC, one substitution could map bit A to B, and bit
          C to null. In this example, the substitution for 1010 (Phase AC) is
          0000-0010-0000-0000 (512). The substitution captures the mapping so
          you know that Phase A was mapped to B, and Phase C was mapped to null
          and not the other way around (that is, Phase A was not mapped to null
          and Phase C was not mapped to B).

          * Function-Choose from a number of calculation functions.

          * Operator-Choose from a number of operators.

          * Value-Provide a specific value for the input attribute type that
          would cause termination based on the operator value.
          The propagators function value options are as follows:

          * PROPAGATED_BITWISE_AND-Compare the values from one feature to the
          next.

          * PROPAGATED_MIN-Get the minimum value.

          * PROPAGATED_MAX-Get the maximum value.
          The propagators operator value options are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES_NOT_INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INCLUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
          This parameter is only available via Python.
      description {String}:
          The description of the rule.
      allow_indeterminate_flow {Boolean}:
          Specifies whether trace network features that have indeterminate or
          uninitialized flow should be traced. This parameter is only honored
          when running an upstream or downstream trace type.

          * TRACE_INDETERMINATE_FLOW-Include trace network features that have
          indeterminate or uninitialized flow direction in the trace.

          * IGNORE_INDETERMINATE_FLOW-Do not trace trace network features that
          have indeterminate or uninitialized flow direction. This is the
          default.
      path_direction {String}:
          The direction of the path for a trace network. The cost of traversing
          the path is determined based on the value set for the
          path_network_weight_name. This parameter is only honored when running
          a PATH trace type.

          * NO_DIRECTION-Find the path between the two starting points
          regardless of the direction of flow. This is the default.

          * PATH_UPSTREAM-Find the downstream path between the two starting
          points.

          * PATH_DOWNSTREAM-Find the upstream path between the two starting
          points.
      path_network_weight_name {String}:
          The network weight used to calculate the path for a trace network.
          When running a path  type, the shortest path is calculated using a
          numeric network weight such as shape length. Cost and distance-based
          paths can both be achieved. The default value is a path with the least
          number of features, which is equivalent to the geometric network. This
          parameter is required when running a path trace."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddTraceRule_nd(*gp_fixargs((in_utility_network, template_name, is_active, trace_type, domain_network, tier, target_tier, include_structures, include_barriers, condition_barriers, function_barriers, traversability_scope, filter_barriers, filter_function_barriers, filter_scope, filter_bitset_network_attribute_name, filter_nearest, nearest_count, nearest_cost_network_attribute, nearest_categories, nearest_assets, propagators, description, allow_indeterminate_flow, path_direction, path_network_weight_name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AlterDiagramTemplate_nd', None)
def AlterDiagramTemplate(in_utility_network=None, template_name=None, out_name=None, is_default_template=None, are_rules_and_layouts_removed=None, are_vertices_kept=None, container_margin=None, is_diagram_storage_enabled=None, is_diagram_extension_enabled=None, description=None, are_layer_definitions_removed=None):
    """AlterDiagramTemplate_nd(in_utility_network, template_name, {out_name}, {is_default_template}, {are_rules_and_layouts_removed}, {are_vertices_kept}, {container_margin}, {is_diagram_storage_enabled}, {is_diagram_extension_enabled}, {description}, {are_layer_definitions_removed})

        Alters the properties of a diagram template, for example, its name,
        how it handles vertices along input network edges, whether the related
        diagrams can be stored or extended, the margin between containers and
        their contents in these diagrams, and the removal of its rule and
        layout or layer definitions.This tool is a configuration and
        administration tool.When working with a utility network in an
        enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network of the diagram template to alter.
      template_name (String):
          The name of the diagram template to alter.
      out_name {String}:
          The new name of the template.
      is_default_template {Boolean}:
          Specifies the default status of the template.

          *  DEFAULT_TEMPLATE-The input diagram template will be the default
          template.

          *  NOT_DEFAULT_TEMPLATE-The input diagram template will not be the
          default template. This is the default.
          The default template is the one used when generating a diagram if a
          template is not specified.
      are_rules_and_layouts_removed {Boolean}:
          Specifies whether the template rule and layout definitions will be
          removed.

          *  REMOVE_RULES_AND_LAYOUTS-The rule and layout definitions related to
          the input diagram template will be removed.

          *  DO_NOT_REMOVE_RULES_AND_LAYOUTS-The rule and layout definitions
          related to the input diagram template will not be removed. This is the
          default.
      are_vertices_kept {Boolean}:
          Specifies how vertices along the GIS edges will be managed in the
          diagrams based on this template.

          *  KEEP_VERTICES-All vertices that display along GIS edges will be
          preserved on the associated edges in each network diagram based on
          this template.

          *  DO_NOT_KEEP_VERTICES-Diagram edges will be drawn as straight lines
          between their connected junctions. This is the default.
      container_margin {Linear Unit}:
          The minimum distance between the center of any junctions inside the
          container and the container border.
      is_diagram_storage_enabled {Boolean}:
          Specifies whether the diagrams based on this template can be stored.

          *  ENABLE_DIAGRAM_STORAGE-The diagrams based on this template can be
          stored. This is the default.

          *  DISABLE_DIAGRAM_STORAGE-The diagrams based on this template cannot
          be stored.
      is_diagram_extension_enabled {Boolean}:
          Specifies whether the diagrams based on this template can be extended.

          *  ENABLE_DIAGRAM_EXTENSION-The diagrams based on this template can be
          extended by connectivity, traversability, containment, or attachment.

          *  DISABLE_DIAGRAM_EXTENSION-The diagrams based on this template
          cannot be extended. This is the default.
      description {String}:
          The description of the template.
      are_layer_definitions_removed {Boolean}:
          Specifies whether the template layer definitions will be removed.

          *  REMOVE_LAYER_DEFINITIONS-The layer definitions related to the input
          diagram template will be removed.

          *  DO_NOT_REMOVE_LAYER_DEFINITIONS-The layer definitions related to
          the input diagram template will not be removed. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AlterDiagramTemplate_nd(*gp_fixargs((in_utility_network, template_name, out_name, is_default_template, are_rules_and_layouts_removed, are_vertices_kept, container_margin, is_diagram_storage_enabled, is_diagram_extension_enabled, description, are_layer_definitions_removed), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CreateDiagramLayerDefinition_nd', None)
def CreateDiagramLayerDefinition(in_utility_network=None, template_name=None, system_junctions=None, connectivity_associations=None, structural_attachments=None, reduction_edges=None, point_subLayers=None, polygon_subLayers=None):
    """CreateDiagramLayerDefinition_nd(in_utility_network, template_name, {system_junctions}, {connectivity_associations}, {structural_attachments}, {reduction_edges}, {point_subLayers;point_subLayers...}, {polygon_subLayers;polygon_subLayers...})

        Creates a diagram layer definition for the input diagram template,
        taking into consideration the settings of the network feature layers
        present in the active map.This tool allows you to do the following:

        * Import the appearance and labeling settings configured on each
        feature layer present in the active map when those layers are related
        to the network layer specified in the input.

        * Control the set of extra layers that are created by default to
        represent pure schematic features-for example, reduction edges,
        connectivity associations, and structural attachments-when those
        layers are not relevant to your template.
        This tool is a configuration and administration tool.When working with
        a utility network in an enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network Layer / Trace Network Layer):
          The utility network layer in the active map.
      template_name (String):
          The name of the diagram template to modify.
      system_junctions {Boolean}:
          Specifies whether system junctions will be represented in the
          diagrams based on the specified template.

          *  SHOW-The diagram layer will include a System Junctions layer to
          represent the system junctions in the diagrams. This is the default.

          *  HIDE-No layer will exist under the diagram layer to represent the
          system junctions in the diagrams.
      connectivity_associations {Boolean}:
          Specifies whether connectivity associations will be represented in
          the diagrams based on the specified template.

          *  SHOW-The diagram layer will include a Connectivity Associations
          layer to represent the connectivity associations in the diagrams. This
          is the default.

          *  HIDE-No layer will exist under the diagram layer to represent the
          connectivity associations in the diagrams.
      structural_attachments {Boolean}:
          Specifies whether structural attachment associations will be
          represented in the diagrams based on the specified template.

          *  SHOW-The diagram layer will include a Structural Attachments layer
          to represent the  structural attachment associations in the diagrams.
          This is the default.

          *  HIDE-No layer will exist under the diagram layer to represent the
          structural attachment associations in the diagrams.
      reduction_edges {Boolean}:
          Specifies whether reduction edges will be represented in the diagrams
          based on the specified template.

          *  SHOW-The diagram layer will include a Reduction Edges layer to
          represent the reduction edges in the diagrams. This is the default.

          *  HIDE-No layer will exist under the diagram layer to represent the
          reduction edges in the diagrams.
      point_subLayers {Value Table}:
          Specifies whether layers will be added to represent container polygon
          or line network features as point features in the diagrams.The Subtype
          Layer column is used as follows:

          * True-The layer will be created with subtype group layers.

          * False-The layer will be created as a simple layer. This is the
          default.
      polygon_subLayers {Value Table}:
          Specifies whether layers will be added to represent container point
          network features as polygon features in the diagrams.The Subtype Layer
          column is used as follows:

          * True-The layer will be created with subtype group layers.

          * False-The layer will be created as a simple layer. This is the
          default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateDiagramLayerDefinition_nd(*gp_fixargs((in_utility_network, template_name, system_junctions, connectivity_associations, structural_attachments, reduction_edges, point_subLayers, polygon_subLayers), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DeleteDiagramTemplate_nd', None)
def DeleteDiagramTemplate(in_utility_network=None, template_name=None):
    """DeleteDiagramTemplate_nd(in_utility_network, template_name)

        Deletes a diagram template and all diagrams  based on that
        template.This tool is a configuration and administration tool.When
        working with a utility network in an enterprise geodatabase, it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network related to the diagram template to delete.
      template_name (String):
          The name of the diagram template to delete."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DeleteDiagramTemplate_nd(*gp_fixargs((in_utility_network, template_name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ExportDiagramLayerDefinition_nd', None)
def ExportDiagramLayerDefinition(in_network_diagram_layer=None, out_ndld_file=None):
    """ExportDiagramLayerDefinition_nd(in_network_diagram_layer, out_ndld_file)

        Exports the diagram layer definition currently set up for the input
        diagram layer into a diagram layer definition file (.ndld).

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram layer which layer definition will be exported.

     OUTPUTS:
      out_ndld_file (File):
          The network diagram layer definition file (.ndld) to be created."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportDiagramLayerDefinition_nd(*gp_fixargs((in_network_diagram_layer, out_ndld_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ExportDiagramTemplateDefinitions_nd', None)
def ExportDiagramTemplateDefinitions(in_utility_network=None, template_name=None, out_ndbd_file=None, out_ndld_file=None):
    """ExportDiagramTemplateDefinitions_nd(in_utility_network, template_name, {out_ndbd_file}, {out_ndld_file})

        Exports the network diagram rule and layout definitions and the
        network diagram layer definitions to .ndbd and .ndld files,
        respectively.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template definitions to
          export.
      template_name (String):
          The name of the diagram template with definitions to be exported.

     OUTPUTS:
      out_ndbd_file {File}:
          The network diagram rule and layout definitions file (.ndbd) to be
          created.
      out_ndld_file {File}:
          The network diagram layer definitions file (.ndld) to be created."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportDiagramTemplateDefinitions_nd(*gp_fixargs((in_utility_network, template_name, out_ndbd_file, out_ndld_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GetDiagramTemplateNames_nd', None)
def GetDiagramTemplateNames(in_utility_network=None):
    """GetDiagramTemplateNames_nd(in_utility_network)

        Returns the names of all diagram templates related to a network.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network to which the diagram template names are related."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GetDiagramTemplateNames_nd(*gp_fixargs((in_utility_network,), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ImportDiagramTemplateDefinitions_nd', None)
def ImportDiagramTemplateDefinitions(in_utility_network=None, template_name=None, ndbd_file=None, ndld_file=None):
    """ImportDiagramTemplateDefinitions_nd(in_utility_network, template_name, {ndbd_file}, {ndld_file})

        Imports a network diagram rule and layout definitions file (.ndbd), a
        network diagram layer definitions file (.ndld), or both into an
        existing template.This tool is a configuration and administration
        tool.When working with a utility network in an enterprise geodatabase,
        it
        must be run by the database utility network owner through a database
        connection to the default version. The default version must be public,
        that is, not protected. In addition, to perform this operation, the
        connected ArcGIS Enterprise portal account must be the portal utility
        network owner. This essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network / Trace Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template onto which the definitions will be
          imported.
      ndbd_file {File}:
          The network diagram rule and layout definitions file (.ndbd) to
          import.This file is the result of the execution of the Export Diagram
          Template Definitions tool on an existing template.At least one of the
          two definitions file input parameters must be
          completed; that is, either the network diagram rule and layout
          definitions file (.ndbd) or the network diagram layer definitions file
          (.ndld) must be completed.
      ndld_file {File}:
          The network diagram layer definitions file (.ndld) to import.This
          file is the result of the execution of the Export Diagram
          Template Definitions or Export Diagram Layer Definition geoprocessing
          tool on an existing template.At least one of the two definitions file
          input parameters must be
          completed; that is, either the network diagram rule and layout
          definitions file (.ndbd) or the network diagram layer definitions file
          (.ndld) must be completed."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ImportDiagramTemplateDefinitions_nd(*gp_fixargs((in_utility_network, template_name, ndbd_file, ndld_file), True)))
        return retval
    except Exception as e:
        raise e


# Layout toolset
@gptooldoc('ApplyAngleDirectedLayout_nd', None)
def ApplyAngleDirectedLayout(in_network_diagram_layer=None, are_containers_preserved=None, iterations_number=None, number_of_directions=None, run_async=None):
    """ApplyAngleDirectedLayout_nd(in_network_diagram_layer, {are_containers_preserved}, {iterations_number}, {number_of_directions}, {run_async})

        Moves a diagram's edges in specified alignment directions.If you have
        an open edit session, you must save your edits prior to
        running this tool. This ensures that the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which the layout will be applied.
      are_containers_preserved {Boolean}:
          Specifies how the algorithm will process containers.

          * PRESERVE_CONTAINERS-The layout algorithm will execute on the top
          graph of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm will execute on both content
          and noncontent features in the diagram. This is the default.
      iterations_number {Long}:
          The number of iterations to process. The default is 1.
      number_of_directions {String}:
          The number of directions that will be used to align the diagram edges
          and their connected junctions.

          * TWELVE_DIRECTIONS-The edges will move so they progressively approach
          one of the 12 axes, starting with the edge's origin junction and
          inclined at 30, 60, 90, 120, 150, 180, 210, 240, 270, 300, 330, or 360
          degrees.

          * EIGHT_DIRECTIONS-The edges will move so they progressively approach
          one of the 8 axes, starting with the edge's origin junction and
          inclined at 45, 90, 135, 180, 225, 270, 315, or 360 degrees. This is
          the default.

          * FOUR_DIRECTIONS-The edges will move so they progressively approach
          one of the 4 axes, starting with the edge's origin junction and
          inclined at 90, 180, 270, or 360 degrees.
      run_async {Boolean}:
          Specifies whether the layout algorithm will run asynchronously or
          synchronously on the server.

          *  RUN_ASYNCHRONOUSLY-The layout algorithm will run asynchronously on
          the server. This option dedicates server resources to run the layout
          algorithm with a longer time-out. Running asynchronously can be
          interesting when executing layouts that are time consuming and may
          exceed the server time-out-for example, Partial Overlapping Edges-and
          applying to large diagrams-more than 25,000 features.

          *  RUN_SYNCHRONOUSLY-The layout algorithm will run synchronously on
          the server. It can fail without completion if its execution exceeds
          the service time-out: 600 seconds by default. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyAngleDirectedLayout_nd(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, iterations_number, number_of_directions, run_async), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyCompressionLayout_nd', None)
def ApplyCompressionLayout(in_network_diagram_layer=None, are_containers_preserved=None, grouping_distance_absolute=None, vertices_removal_rule=None, run_async=None):
    """ApplyCompressionLayout_nd(in_network_diagram_layer, {are_containers_preserved}, {grouping_distance_absolute}, {vertices_removal_rule}, {run_async})

        Compresses the diagram features toward the middle of the diagram.If
        you have an open edit session, you must save your edits prior to
        running this tool. This ensures that the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which the layout will be applied.
      are_containers_preserved {Boolean}:
          Specifies how containers will be processed by the Compression layout
          algorithm.

          * PRESERVE_CONTAINERS-The Compression layout algorithm will execute
          on the top graph of the diagram so containers are preserved. This is
          the default.

          * IGNORE_CONTAINERS-The Compression layout algorithm will execute on
          both content and noncontent features in the diagram.
      grouping_distance_absolute {Linear Unit}:
          The grouping distance is used to determine whether two connected
          junctions are close enough to be considered part of the same junctions
          group. A junctions group represents many junctions that are moved as a
          group during execution. The group may contain both junctions and
          containers. To group two junctions together, they must also be
          connected in the diagram by an edge. The default is 20 units in the
          diagram's coordinate system.
      vertices_removal_rule {String}:
          Specifies which vertices along edges in the diagram will be removed.

          * ALL-All vertices on all edges will be removed from the diagram.

          * OUTER-Any edge vertices that are within the detected junctions'
          groups will be maintained, while edge vertices that are outside will
          be removed.When there are containers in the diagram that have edges
          that intersect the container polygons, a vertex is added at the
          intersection of the edge and container polygon. This is the default.

          * OUTER_EXCEPT_FIRST-Any edge vertices that are within the detected
          junctions' groups will be maintained, while edge vertices that are
          outside will be removed.When there are containers in the diagram that
          have edges that intersect the container polygons, the first (or last)
          outside vertex is preserved on edges that intersect a container
          polygon. A vertex is automatically inserted at the intersection of the
          edges and container polygons.
      run_async {Boolean}:
          Specifies whether the layout algorithm will run asynchronously or
          synchronously on the server.

          *  RUN_ASYNCHRONOUSLY-The layout algorithm will run asynchronously on
          the server. This option dedicates server resources to run the layout
          algorithm with a longer time-out. Running asynchronously can be
          interesting when executing layouts that are time consuming and may
          exceed the server time-out-for example, Partial Overlapping Edges-and
          applying to large diagrams-more than 25,000 features.

          *  RUN_SYNCHRONOUSLY-The layout algorithm will run synchronously on
          the server. It can fail without completion if its execution exceeds
          the service time-out: 600 seconds by default. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyCompressionLayout_nd(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, grouping_distance_absolute, vertices_removal_rule, run_async), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyForceDirectedLayout_nd', None)
def ApplyForceDirectedLayout(in_network_diagram_layer=None, are_containers_preserved=None, iterations_number=None, repel_factor=None, degree_freedom=None, breakpoint_position=None, edge_display_type=None, run_async=None):
    """ApplyForceDirectedLayout_nd(in_network_diagram_layer, {are_containers_preserved}, {iterations_number}, {repel_factor}, {degree_freedom}, {breakpoint_position}, {edge_display_type}, {run_async})

        Emphasizes loops contained in a network diagram.If you have an open
        edit session, you must save your edits prior to
        running this tool. This ensures that the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which the layout will be applied.
      are_containers_preserved {Boolean}:
          Specifies how the algorithm will process containers.

          * PRESERVE_CONTAINERS-The layout algorithm will execute on the top
          graph of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm will execute on both content
          and noncontent features in the diagram. This is the default.
      iterations_number {Long}:
          The number of iterations to process. The default is 20.
      repel_factor {Double}:
          Adds distance between diagram junctions that are close together. The
          larger the repel factor, the greater the distance that will be added
          between nearly overlapping diagram junctions. The default is 1.
      degree_freedom {String}:
          Specifies the area used to move the diagram junctions during each
          algorithm iteration.

          * LOW-The area used to move the diagram junctions will be very
          limited. This is the default.

          * HIGH-The area used to move the diagram junctions will be very large.

          * MEDIUM-The area used to move the diagram junctions will be moderate.
      breakpoint_position {Double}:
          The relative position of the two inflexion points that will be
          inserted along the diagram edges to compute the curved edges geometry
          when Edge Display Type is set to Curved edges
          (edges_display_type="CURVED_EDGES" in Python). It is a percentage
          between 15 and 40; the default is 30. For example, with a Break Point
          Relative Position (%) parameter value of N between 15 and 40, the
          following is true:

          * X being the x-coordinate of the edge's from junction and Y being the
          y-coordinate of the edge's to junction for a horizontal tree:

          * The first inflexion point will be positioned at N% of the length of
          the [XY] segment

          * The second inflexion point will be positioned at (100 - N)% of the
          length of the [XY] segment

          * Y being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree:

          * The first inflexion point will be positioned at N% of the length of
          the [YX] segment

          * The second inflexion point will be positioned at (100 - N)% of the
          length of the [XY] segment

          The concept of the from and to junctions above is relative to the tree
          direction; it is not related to the topology of the network feature
          edge.This parameter is ignored when the Edge Display Type parameter is
          set
          to Regular edges (edges_display_type="REGULAR_EDGES" in Python).
      edge_display_type {String}:
          Specifies the type of display for the diagram edges.

          * REGULAR_EDGES-All diagram edges display as straight lines. This is
          the default.

          * CURVED_EDGES-All diagram edges are curved.
      run_async {Boolean}:
          Specifies whether the layout algorithm will run asynchronously or
          synchronously on the server.

          *  RUN_ASYNCHRONOUSLY-The layout algorithm will run asynchronously on
          the server. This option dedicates server resources to run the layout
          algorithm with a longer time-out. Running asynchronously can be
          interesting when executing layouts that are time consuming and may
          exceed the server time-out-for example, Partial Overlapping Edges-and
          applying to large diagrams-more than 25,000 features.

          *  RUN_SYNCHRONOUSLY-The layout algorithm will run synchronously on
          the server. It can fail without completion if its execution exceeds
          the service time-out: 600 seconds by default. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyForceDirectedLayout_nd(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, iterations_number, repel_factor, degree_freedom, breakpoint_position, edge_display_type, run_async), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyGeoPositionsLayout_nd', None)
def ApplyGeoPositionsLayout(in_network_diagram_layer=None, restore_edges_geo_positions=None, run_async=None):
    """ApplyGeoPositionsLayout_nd(in_network_diagram_layer, {restore_edges_geo_positions}, {run_async})

        Moves each diagram junction and edge feature so they match the
        geographical positions of the associated network features.If you have
        an open edit session, you must save your edits prior to
        running this tool. This ensures that the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which the layout will be applied.
      restore_edges_geo_positions {Boolean}:
          Indicates whether or not diagram edges will be restored to the
          geographic position of their vertices:

          *  RESTORE_EDGES_GEO_POSITIONS-Vertices along diagram edges will be
          restored when possible, moving them to match the geographic positions
          of the network features. This is the default.

          *  DO_NOT_RESTORE_EDGES_GEO_POSITIONS-Vertices along diagram edges
          will not be restored. They will appear as straight lines between their
          connecting junctions.
      run_async {Boolean}:
          Specifies whether the layout algorithm will run asynchronously or
          synchronously on the server.

          *  RUN_ASYNCHRONOUSLY-The layout algorithm will run asynchronously on
          the server. This option dedicates server resources to run the layout
          algorithm with a longer time-out. Running asynchronously can be
          interesting when executing layouts that are time consuming and may
          exceed the server time-out-for example, Partial Overlapping Edges-and
          applying to large diagrams-more than 25,000 features.

          *  RUN_SYNCHRONOUSLY-The layout algorithm will run synchronously on
          the server. It can fail without completion if its execution exceeds
          the service time-out: 600 seconds by default. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyGeoPositionsLayout_nd(*gp_fixargs((in_network_diagram_layer, restore_edges_geo_positions, run_async), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyGridLayout_nd', None)
def ApplyGridLayout(in_network_diagram_layer=None, are_containers_preserved=None, cell_width_absolute=None, cell_height_absolute=None, run_async=None):
    """ApplyGridLayout_nd(in_network_diagram_layer, {are_containers_preserved}, {cell_width_absolute}, {cell_height_absolute}, {run_async})

        Positions diagram junctions relative to a predefined magnetic grid.If
        you have an open edit session, you must save your edits prior to
        running this tool. This ensures that the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which the layout will be applied.
      are_containers_preserved {Boolean}:
          Specifies how the algorithm will process containers.

          * PRESERVE_CONTAINERS-The layout algorithm will execute on the top
          graph of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm will execute on both content
          and noncontent features in the diagram. This is the default.
      cell_width_absolute {Linear Unit}:
          The width of each grid cell. The default is 2 in the units of the
          diagram's coordinate system.
      cell_height_absolute {Linear Unit}:
          The height of each grid cell. The default is 2 in the units of the
          diagram's coordinate system.
      run_async {Boolean}:
          Specifies whether the layout algorithm will run asynchronously or
          synchronously on the server.

          *  RUN_ASYNCHRONOUSLY-The layout algorithm will run asynchronously on
          the server. This option dedicates server resources to run the layout
          algorithm with a longer time-out. Running asynchronously can be
          interesting when executing layouts that are time consuming and may
          exceed the server time-out-for example, Partial Overlapping Edges-and
          applying to large diagrams-more than 25,000 features.

          *  RUN_SYNCHRONOUSLY-The layout algorithm will run synchronously on
          the server. It can fail without completion if its execution exceeds
          the service time-out: 600 seconds by default. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyGridLayout_nd(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, cell_width_absolute, cell_height_absolute, run_async), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyLinearDispatchLayout_nd', None)
def ApplyLinearDispatchLayout(in_network_diagram_layer=None, junction_placement_type=None, is_unit_absolute=None, maximum_shift_absolute=None, maximum_shift_proportional=None, minimum_shift_absolute=None, minimum_shift_proportional=None, iterations_number=None, is_path_preserved=None, are_leaves_moved=None, are_leaves_expanded=None, expand_shift_absolute=None, expand_shift_proportional=None, run_async=None):
    """ApplyLinearDispatchLayout_nd(in_network_diagram_layer, {junction_placement_type}, {is_unit_absolute}, {maximum_shift_absolute}, {maximum_shift_proportional}, {minimum_shift_absolute}, {minimum_shift_proportional}, {iterations_number}, {is_path_preserved}, {are_leaves_moved}, {are_leaves_expanded}, {expand_shift_absolute}, {expand_shift_proportional}, {run_async})

        Adds space between diagram junctions that are visually too close,
        overlapping, or coincident.If you have an open edit session, you must
        save your edits prior to
        running this tool. This ensures that the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which the layout will be applied.
      junction_placement_type {String}:
          Specifies how the junctions will be moved.

          *  EQUAL_DISTANCE-All junctions with two connected edges will be moved
          so the distances between them and their two connected junctions are
          equal. This is the default.

          *  USER_DEFINE_DISTANCE-All junctions with two connected edges will be
          moved so there is a minimum distance (minimum_shift_ parameter value)
          between them and the other end of the edges to which they connect.
          This occurs at the end of the layout execution.

          * ITERATIVE_DISTANCE-All junctions with two connected edges will be
          moved slightly  according to the iterations_number and maximum_shift_
          parameter values.
      is_unit_absolute {Boolean}:
          Specifies how parameters representing distances will be interpreted.

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the current diagram extent. This is the default.
      maximum_shift_absolute {Linear Unit}:
          The maximum distance the junctions with two connections will be
          spaced from the junctions to which they connect. The default is 2 in
          the units of the diagram's coordinate system. At the time this
          distance is reached, junctions will not be moved during following
          iterations. This parameter can only be used with the
          ITERATIVE_DISTANCE  junction placement type and absolute units.
      maximum_shift_proportional {Double}:
          The maximum distance the junctions with two connections will be
          spaced from the junctions to which they connect. The default is 2. At
          the time this distance is reached, junctions will not be moved during
          following iterations. This parameter can only be used with the
          ITERATIVE_DISTANCE  junction placement type and proportional units.
      minimum_shift_absolute {Linear Unit}:
          The minimum distance that will separate each junction with two
          connected edges from its two edge extremities after the layout
          execution. The default is 2 in the units of the diagram's coordinate
          system. When this parameter value is too large, the junctions with two
          connections are moved so the distances between each moved junction and
          its edge extremities are equal along the path defined by its two
          connected edges. This parameter can only be used with the
          USER_DEFINE_DISTANCE  junction placement type and absolute units.
      minimum_shift_proportional {Double}:
          The minimum distance that will separate each junction with two
          connected edges from its two edge extremities after the layout
          execution. The default is 2. When this parameter value is too large,
          the junctions with two connections are moved so the distances between
          each moved junction and its edge extremities are equal along the path
          defined by its two connected edges. This parameter is used with the
          USER_DEFINE_DISTANCE junction placement type and proportional units.
      iterations_number {Long}:
          The number of iterations to process. The default is 5. This parameter
          can only be used with the ITERATIVE_DISTANCE  junction placement type.
      is_path_preserved {Boolean}:
          Specifies how vertices along edges will be processed.

          *  PRESERVE_PATH-All vertices along the connected edges will be
          preserved, and new vertices will be added at the moved junctions'
          original locations. This is the default.

          *  IGNORE_PATH-Vertices along edges will not be preserved.
      are_leaves_moved {Boolean}:
          Specifies whether leaf junctions-junctions with one connection-will
          be moved during the algorithm execution.

          *  MOVE_LEAVES-Leaf junctions will be moved.

          *  DO_NOT_MOVE_LEAVES-Leaf junctions will not be moved. This is the
          default unless the specified input network diagram is based on a
          template for which the Linear Dispatch Layout algorithm has been
          configured with another parameter value.
      are_leaves_expanded {Boolean}:
          Specifies whether leaf junctions will be expanded:

          *  EXPAND_LEAVES-Leaf junctions will be expanded. The
          expand_shift_absolute parameter value specifies the maximum distance
          the leaf junctions can be expanded from the junctions to which they
          connect.

          *  DO_NOT_EXPAND_LEAVES-Leaf junctions will not be expanded. This is
          the default unless the specified input network diagram is based on a
          template for which the Linear Dispatch Layout algorithm has been
          configured with another parameter value.
      expand_shift_absolute {Linear Unit}:
          The maximum distance leaf junctions must be expanded from the
          junctions to which they connect. The default is 2 in the units of the
          diagram's coordinate system unless the specified input network diagram
          is based on a template for which the Linear Dispatch Layout algorithm
          has been configured with another parameter value. At the time this
          distance is reached, leaf junctions will not be moved during following
          iterations. This parameter can only be used with the Expand leaves
          parameter and absolute units.
      expand_shift_proportional {Double}:
          The maximum distance the leaf junctions will be expanded from the
          junctions to which they connect. The default is 2 unless the specified
          input network diagram is based on a template for which the Linear
          Dispatch Layout algorithm has been configured with another parameter
          value. At the time this distance is reached, leaf junctions will not
          be moved during following iterations. This parameter can only be used
          with the Expand leaves parameter and proportional units.
      run_async {Boolean}:
          Specifies whether the layout algorithm will run asynchronously or
          synchronously on the server.

          *  RUN_ASYNCHRONOUSLY-The layout algorithm will run asynchronously on
          the server. This option dedicates server resources to run the layout
          algorithm with a longer time-out. Running asynchronously can be
          interesting when executing layouts that are time consuming and may
          exceed the server time-out-for example, Partial Overlapping Edges-and
          applying to large diagrams-more than 25,000 features.

          *  RUN_SYNCHRONOUSLY-The layout algorithm will run synchronously on
          the server. It can fail without completion if its execution exceeds
          the service time-out: 600 seconds by default. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyLinearDispatchLayout_nd(*gp_fixargs((in_network_diagram_layer, junction_placement_type, is_unit_absolute, maximum_shift_absolute, maximum_shift_proportional, minimum_shift_absolute, minimum_shift_proportional, iterations_number, is_path_preserved, are_leaves_moved, are_leaves_expanded, expand_shift_absolute, expand_shift_proportional, run_async), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyMainRingLayout_nd', None)
def ApplyMainRingLayout(in_network_diagram_layer=None, are_containers_preserved=None, ring_type=None, is_unit_absolute=None, ring_width_absolute=None, ring_width_proportional=None, ring_height_absolute=None, ring_height_proportional=None, tree_type=None, perpendicular_absolute=None, perpendicular_proportional=None, along_absolute=None, along_proportional=None, breakpoint_position=None, edge_display_type=None, run_async=None):
    """ApplyMainRingLayout_nd(in_network_diagram_layer, {are_containers_preserved}, {ring_type}, {is_unit_absolute}, {ring_width_absolute}, {ring_width_proportional}, {ring_height_absolute}, {ring_height_proportional}, {tree_type}, {perpendicular_absolute}, {perpendicular_proportional}, {along_absolute}, {along_proportional}, {breakpoint_position}, {edge_display_type}, {run_async})

        Arranges the diagram features in a network diagram around a main
        ring.If you have an open edit session, you must save your edits prior
        to
        running this tool. This ensures that the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which the layout will be applied.
      are_containers_preserved {Boolean}:
          Specifies how the algorithm will process containers.

          * PRESERVE_CONTAINERS-The layout algorithm will execute on the top
          graph of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm will execute on both content
          and noncontent features in the diagram. This is the default.
      ring_type {String}:
          Specifies the type of ring.

          * ELLIPSE-The diagram features of the detected main ring will display
          along an ellipse. This is the default.

          * RECTANGLE-The diagram features of the detected main ring will
          display along a rectangle.
      is_unit_absolute {Boolean}:
          Specifies how parameters representing distances will be interpreted.

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the current diagram extent. This is the default.
      ring_width_absolute {Linear Unit}:
          The width of the ring. The default is in the units of the diagram's
          coordinate system. This parameter can only be used with absolute
          units.
      ring_width_proportional {Double}:
          The width of the ring. The default is 50. This parameter can only be
          used with proportional units.
      ring_height_absolute {Linear Unit}:
          The height of the ring. The default is in the units of the diagram's
          coordinate system. This parameter can only be used with absolute
          units.
      ring_height_proportional {Double}:
          The height of the ring. The default is 20. This parameter can only be
          used with proportional units.
      tree_type {String}:
          Specifies how the trees coming out of the main ring's junctions will
          be positioned.

          * BOTH_SIDES-Each tree will be displayed along a main line, and its
          related branches will be arranged on both the left and right sides of
          this main line.

          * LEFT_SIDE-Each tree will be displayed hierarchically along a main
          line, and its related branches will be arranged on the left side of
          this main line.

          * RIGHT_SIDE-Each tree will be displayed hierarchically along a main
          line, and its related branches will be arranged on the right side of
          this main line.

          * SMART_TREE-Each tree will be displayed hierarchically as a smart
          tree. This is the default.
      perpendicular_absolute {Linear Unit}:
          The spacing between diagram junctions that are displayed perpendicular
          to the tree direction and belong to the same subtree level. The
          default is 2 in the units of the diagram's coordinate system. This
          parameter can only be used with absolute units.
      perpendicular_proportional {Double}:
          The spacing between diagram junctions that are displayed perpendicular
          to the tree direction and belong to the same subtree level. The
          default is 2. This parameter can only be used with proportional units.
      along_absolute {Linear Unit}:
          The spacing between diagram junctions that are displayed along the
          tree direction. The default is 2 in the units of the diagram's
          coordinate system. This parameter can only be used with absolute
          units.
      along_proportional {Double}:
          The spacing between diagram junctions that are displayed along the
          tree direction. The default is 2. This parameter can only be used with
          proportional units.
      breakpoint_position {Double}:
          The relative position of the break point that will be inserted along
          the diagram edges when Edge Display Type is Regular edges
          (edge_display_type = REGULAR_EDGES in Python) or Edge Display Type is
          Orthogonal edges (edge_display_type = ORTHOGONAL_EDGES in Python). It
          is a percentage between 0 and 100.

          * With a Break Point Relative Position (%) value of 0, the break point
          is positioned at the x-coordinate of the edge's from junction and at
          the y-coordinate of the edge's to junction for a horizontal tree. It
          is positioned at the y-coordinate of the edge's from junction and at
          the x-coordinate of the edge's to junction for a vertical tree.

          * With a Break Point Relative Position (%) value of 100, there is no
          break point inserted on the diagram edges; each diagram edge directly
          connects its from and to junctions.

          * With a Break Point Relative Position (%) value of N between 0 and
          100, the break point is positioned at N% of the length of the [XY]
          segment, X being the x-coordinate of the edge's from junction and Y
          being the y-coordinate of the edge's to junction for a horizontal
          tree. It is positioned at N% of the length of the [YX] segment, Y
          being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree.
          The relative position of the two inflection points that will be
          inserted along the diagram edges to compute the curved edges geometry
          when Edge Display Type is Curved edges (edge_display_type =
          CURVED_EDGES in Python). It is a percentage between 15 and 40. With a
          Break Point Relative Position (%) value of N between 15 and 40:

          * X being the x-coordinate of the edge's from junction and Y being the
          y-coordinate of the edge's to junction for a horizontal tree:

          * The first inflection point will be positioned at N% of the length of
          the [XY] segment.

          * The second inflection point will be positioned at (100 - N)% of the
          length of the [XY] segment.

          * Y being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree:

          * The first inflection point will be positioned at N% of the length of
          the [YX] segment.

          * The second inflection point will be positioned at (100 - N)% of the
          length of the [XY] segment.

          The concept of the from and to junctions above is relative to the tree
          direction; it has nothing to do with the real topology of the network
          feature edge.
      edge_display_type {String}:
          Specifies the type of display for the diagram edges related to the
          tree branches.

          * REGULAR_EDGES-All diagram edges related to the tree branches will
          not display with right angles. This is the default.

          * ORTHOGONAL_EDGES-All diagram edges related to the tree branches will
          display with right angles.

          * CURVED_EDGES-All diagram edges related to the tree branches will be
          curved.
      run_async {Boolean}:
          Specifies whether the layout algorithm will run asynchronously or
          synchronously on the server.

          *  RUN_ASYNCHRONOUSLY-The layout algorithm will run asynchronously on
          the server. This option dedicates server resources to run the layout
          algorithm with a longer time-out. Running asynchronously can be
          interesting when executing layouts that are time consuming and may
          exceed the server time-out-for example, Partial Overlapping Edges-and
          applying to large diagrams-more than 25,000 features.

          *  RUN_SYNCHRONOUSLY-The layout algorithm will run synchronously on
          the server. It can fail without completion if its execution exceeds
          the service time-out: 600 seconds by default. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyMainRingLayout_nd(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, ring_type, is_unit_absolute, ring_width_absolute, ring_width_proportional, ring_height_absolute, ring_height_proportional, tree_type, perpendicular_absolute, perpendicular_proportional, along_absolute, along_proportional, breakpoint_position, edge_display_type, run_async), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyMainlineTreeLayout_nd', None)
def ApplyMainlineTreeLayout(in_network_diagram_layer=None, are_containers_preserved=None, tree_direction=None, branches_placement=None, is_unit_absolute=None, perpendicular_absolute=None, perpendicular_proportional=None, along_absolute=None, along_proportional=None, disjoined_graph_absolute=None, disjoined_graph_proportional=None, are_edges_orthogonal=None, breakpoint_position=None, edge_display_type=None, run_async=None):
    """ApplyMainlineTreeLayout_nd(in_network_diagram_layer, {are_containers_preserved}, {tree_direction}, {branches_placement}, {is_unit_absolute}, {perpendicular_absolute}, {perpendicular_proportional}, {along_absolute}, {along_proportional}, {disjoined_graph_absolute}, {disjoined_graph_proportional}, {are_edges_orthogonal}, {breakpoint_position}, {edge_display_type}, {run_async})

        Arranges diagram junctions and edges hierarchically along a main
        line.If you have an open edit session, you must save your edits prior
        to
        running this tool. This ensures that the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which the layout will be applied.
      are_containers_preserved {Boolean}:
          Specifies how the algorithm will process containers.

          * PRESERVE_CONTAINERS-The layout algorithm will execute on the top
          graph of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm will execute on both content
          and noncontent features in the diagram. This is the default.
      tree_direction {String}:
          Specifies the direction of the main line.

          * FROM_LEFT_TO_RIGHT-The main line will be drawn as a horizontal line
          starting from the left and ending on the right. This is the default.

          * FROM_RIGHT_TO_LEFT-The main line will be drawn as a horizontal line
          starting from the right and ending on the left.

          * FROM_BOTTOM_TO_TOP-The main line will be drawn as a vertical line
          starting from the bottom and ending at the top.

          * FROM_TOP_TO_BOTTOM-The main line will be drawn as a vertical line
          starting from the top and ending at the bottom.
      branches_placement {String}:
          Specifies how branches from the main line will be relatively placed
          with regard to its direction.

          * BOTH_SIDES-Branches will be placed on both the left and right sides
          of the main line. This is the default.

          * LEFT_SIDE-Branches will only be placed on the left side of the main
          line.

          * RIGHT_SIDE-Branches will only be placed on the right side of the
          main line.
      is_unit_absolute {Boolean}:
          Specifies how parameters representing distances will be interpreted.

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the current diagram extent. This is the default.
      perpendicular_absolute {Linear Unit}:
          The spacing between diagram junctions that are displayed along the
          axis perpendicular to the main line. The default is 2 in the diagram's
          coordinate system. This parameter can only be used with absolute
          units.
      perpendicular_proportional {Double}:
          The spacing between diagram junctions that are displayed along the
          axis perpendicular to the main line. The default is 2. This parameter
          can only be used with proportional units.
      along_absolute {Linear Unit}:
          The spacing between diagram junctions that are displayed along the
          main line, as well as the spacing between diagram junctions that are
          displayed along the axis parallel to the main line. This parameter can
          only be used with absolute units. The default is 2 in the units of the
          diagram's coordinate system.
      along_proportional {Double}:
          The spacing between diagram junctions that are displayed along the
          main line, as well as the spacing between diagram junctions that are
          displayed along the axis parallel to the main line. This parameter is
          used with proportional units. The default is 2.
      disjoined_graph_absolute {Linear Unit}:
          The minimum spacing that will separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is used with absolute units. The default is 4 in the units of the
          diagram's coordinate system.
      disjoined_graph_proportional {Double}:
          The minimum spacing that will separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is used with proportional units. The default is 4.
      are_edges_orthogonal {Boolean}:
          Specifies how diagram edges that are related to the tree branches will
          display.This parameter is deprecated at ArcGIS Pro 2.5. It is
          systematically
          ignored regardless of its value when the edge_display_type parameter
          is specified. However, to maintain compatibility with ArcGIS Pro 2.1,
          it remains enabled when the edge_display_type parameter is not
          specified.

          *  ORTHOGONAL_EDGES-All diagram edges related to the tree branches
          will display with right angles.

          *  SLANTED_EDGES-All diagram edges related to the tree branches will
          not display with right angles. This is the default.
      breakpoint_position {Double}:
          The relative position of the break point that will be inserted along
          the diagram edges when Edge Display Type is Regular edges
          (edge_display_type = REGULAR_EDGES in Python) or Edge Display Type is
          Orthogonal edges (edge_display_type = ORTHOGONAL_EDGES in Python). It
          is a percentage between 0 and 100.

          * With a Break Point Relative Position (%) value of 0, the break point
          is positioned at the x-coordinate of the edge's from junction and at
          the y-coordinate of the edge's to junction for a horizontal tree. It
          is positioned at the y-coordinate of the edge's from junction and at
          the x-coordinate of the edge's to junction for a vertical tree.

          * With a Break Point Relative Position (%) value of 100, there is no
          break point inserted on the diagram edges; each diagram edge directly
          connects its from and to junctions.

          * With a Break Point Relative Position (%) value of N between 0 and
          100, the break point is positioned at N% of the length of the [XY]
          segment, X being the x-coordinate of the edge's from junction and Y
          being the y-coordinate of the edge's to junction for a horizontal
          tree. It is positioned at N% of the length of the [YX] segment, Y
          being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree.
          The relative position of the two inflection points that will be
          inserted along the diagram edges to compute the curved edges geometry
          when Edge Display Type is Curved edges (edge_display_type =
          CURVED_EDGES in Python). It is a percentage between 15 and 40. With a
          Break Point Relative Position (%) value of N between 15 and 40:

          * X being the x-coordinate of the edge's from junction and Y being the
          y-coordinate of the edge's to junction for a horizontal tree:

          * The first inflection point will be positioned at N% of the length of
          the [XY] segment.

          * The second inflection point will be positioned at (100 - N)% of the
          length of the [XY] segment.

          * Y being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree:

          * The first inflection point will be positioned at N% of the length of
          the [YX] segment.

          * The second inflection point will be positioned at (100 - N)% of the
          length of the [XY] segment.

          The concept of the from and to junctions above is relative to the tree
          direction; it has nothing to do with the real topology of the network
          feature edge.
      edge_display_type {String}:
          Specifies the type of display for the diagram edges related to the
          tree branches.

          * REGULAR_EDGES-All diagram edges related to the tree branches will
          not display with right angles. This is the default.

          * ORTHOGONAL_EDGES-All diagram edges related to the tree branches will
          display with right angles.

          * CURVED_EDGES-All diagram edges related to the tree branches will be
          curved.
      run_async {Boolean}:
          Specifies whether the layout algorithm will run asynchronously or
          synchronously on the server.

          *  RUN_ASYNCHRONOUSLY-The layout algorithm will run asynchronously on
          the server. This option dedicates server resources to run the layout
          algorithm with a longer time-out. Running asynchronously can be
          interesting when executing layouts that are time consuming and may
          exceed the server time-out-for example, Partial Overlapping Edges-and
          applying to large diagrams-more than 25,000 features.

          *  RUN_SYNCHRONOUSLY-The layout algorithm will run synchronously on
          the server. It can fail without completion if its execution exceeds
          the service time-out: 600 seconds by default. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyMainlineTreeLayout_nd(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, tree_direction, branches_placement, is_unit_absolute, perpendicular_absolute, perpendicular_proportional, along_absolute, along_proportional, disjoined_graph_absolute, disjoined_graph_proportional, are_edges_orthogonal, breakpoint_position, edge_display_type, run_async), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyPartialOverlappingEdgesLayout_nd', None)
def ApplyPartialOverlappingEdgesLayout(in_network_diagram_layer=None, buffer_width_absolute=None, offset_absolute=None, optimize_edges=None, run_async=None):
    """ApplyPartialOverlappingEdgesLayout_nd(in_network_diagram_layer, buffer_width_absolute, offset_absolute, {optimize_edges}, {run_async})

        Spaces out collinear edges or collinear portions of edges (edge
        segments) inside a given buffer zone.If you have an open edit session,
        you must save your edits prior to
        running this tool. This ensures that the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which the layout will be applied.
      buffer_width_absolute (Linear Unit):
          The width of the buffer zone in which to search for collinear edge
          segments.
      offset_absolute (Linear Unit):
          The distance that will separate the detected edge segments.
      optimize_edges {Boolean}:
          Specifies how segments are placed along edges:

          *  OPTIMIZE_EDGES-The placement of segments will be optimized in each
          set of collinear segments. This is done by focusing on their
          connections instead of their positions. Segments that cross each other
          can be repositioned so they do not cross.

          *  DO_NOT_OPTIMIZE_EDGES-The initial position of each segment will be
          maintained in the collinear segment set and crossings will be
          preserved. This is the default option.
      run_async {Boolean}:
          Specifies whether the layout algorithm will run asynchronously or
          synchronously on the server.

          *  RUN_ASYNCHRONOUSLY-The layout algorithm will run asynchronously on
          the server. This option dedicates server resources to run the layout
          algorithm with a longer time-out. Running asynchronously can be
          interesting when executing layouts that are time consuming and may
          exceed the server time-out-for example, Partial Overlapping Edges-and
          applying to large diagrams-more than 25,000 features.

          *  RUN_SYNCHRONOUSLY-The layout algorithm will run synchronously on
          the server. It can fail without completion if its execution exceeds
          the service time-out: 600 seconds by default. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyPartialOverlappingEdgesLayout_nd(*gp_fixargs((in_network_diagram_layer, buffer_width_absolute, offset_absolute, optimize_edges, run_async), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyRadialTreeLayout_nd', None)
def ApplyRadialTreeLayout(in_network_diagram_layer=None, are_containers_preserved=None, is_unit_absolute=None, initial_radius_absolute=None, initial_radius_proportional=None, disjoined_graph_absolute=None, disjoined_graph_proportional=None, radius_factor=None, run_async=None):
    """ApplyRadialTreeLayout_nd(in_network_diagram_layer, {are_containers_preserved}, {is_unit_absolute}, {initial_radius_absolute}, {initial_radius_proportional}, {disjoined_graph_absolute}, {disjoined_graph_proportional}, {radius_factor}, {run_async})

        Arranges diagram features hierarchically and places them in a radial
        tree.If you have an open edit session, you must save your edits prior
        to
        running this tool. This ensures that the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which the layout will be applied.
      are_containers_preserved {Boolean}:
          Specifies how the algorithm will process containers.

          * PRESERVE_CONTAINERS-The layout algorithm will execute on the top
          graph of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm will execute on both content
          and noncontent features in the diagram. This is the default.
      is_unit_absolute {Boolean}:
          Specifies how parameters representing distances will be interpreted.

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the current diagram extent. This is the default.
      initial_radius_absolute {Linear Unit}:
          The radius of the first concentric circle whose center is the radial
          tree root junction; that is, the radius of the circle around which the
          diagram junctions belonging to the first hierarchical level are
          placed. The default is 5 in the units of the diagram's coordinate
          system. This parameter can only be used with absolute units.
      initial_radius_proportional {Double}:
          The radius of the first concentric circle whose center is the radial
          tree root junction; that is, the radius of the circle around which the
          diagram junctions belonging to the first hierarchical level are
          placed. The default is 5. This parameter can only be used with
          proportional units.
      disjoined_graph_absolute {Linear Unit}:
          The minimum spacing that will separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is used with absolute units. The default is 4 in the units of the
          diagram's coordinate system.
      disjoined_graph_proportional {Double}:
          The minimum spacing that will separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is used with proportional units. The default is 4.
      radius_factor {Double}:
          The multiplicative factor used to increase or decrease the radius of
          each concentric circle. It is also the distance that separates each
          concentric circle related to a hierarchical level. When using a radius
          factor less than 1, the distance that separates the diagram junctions
          belonging to the (n) hierarchical level and the (n+1) hierarchical
          level progressively decreases. With a factor greater than 1, the
          distance between the hierarchical levels increases progressively. The
          default is 1.
      run_async {Boolean}:
          Specifies whether the layout algorithm will run asynchronously or
          synchronously on the server.

          *  RUN_ASYNCHRONOUSLY-The layout algorithm will run asynchronously on
          the server. This option dedicates server resources to run the layout
          algorithm with a longer time-out. Running asynchronously can be
          interesting when executing layouts that are time consuming and may
          exceed the server time-out-for example, Partial Overlapping Edges-and
          applying to large diagrams-more than 25,000 features.

          *  RUN_SYNCHRONOUSLY-The layout algorithm will run synchronously on
          the server. It can fail without completion if its execution exceeds
          the service time-out: 600 seconds by default. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyRadialTreeLayout_nd(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, is_unit_absolute, initial_radius_absolute, initial_radius_proportional, disjoined_graph_absolute, disjoined_graph_proportional, radius_factor, run_async), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyRelativeMainlineLayout_nd', None)
def ApplyRelativeMainlineLayout(in_network_diagram_layer=None, line_attribute=None, mainline_direction=None, offset_between_branches=None, breakpoint_angle=None, type_attribute=None, mainline_values=None, branch_values=None, excluded_values=None, is_compressing=None, compression_ratio=None, minimal_distance=None, alignment_attribute=None, initial_distances=None, length_attribute=None, run_async=None):
    """ApplyRelativeMainlineLayout_nd(in_network_diagram_layer, line_attribute, {mainline_direction}, {offset_between_branches}, {breakpoint_angle}, {type_attribute}, {mainline_values;mainline_values...}, {branch_values;branch_values...}, {excluded_values;excluded_values...}, {is_compressing}, {compression_ratio}, {minimal_distance}, {alignment_attribute}, {initial_distances}, {length_attribute}, {run_async})

        Arranges the network diagram features in the active diagram along
        parallel straight lines.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which the layout will be applied.
      line_attribute (String):
          The name of the network attribute that will be used to identify the
          lines that comprise the straight lines. This network attribute must
          exist in the network line classes. Its values should be the same for
          all the edges that comprise a straight line, for example, Line 1, Line
          2, and so on
      mainline_direction {String}:
          Specifies the direction of the main line.

          * FROM_LEFT_TO_RIGHT-The main line will be drawn as a horizontal line
          starting from the left and ending on the right. This is the default.

          * FROM_TOP_TO_BOTTOM-The main line will be drawn as a vertical line
          starting from the top and ending at the bottom.
      offset_between_branches {Linear Unit}:
          The spacing between two adjacent branches along the axis
          perpendicular to the direction of the lines.
      breakpoint_angle {Double}:
          The angle that will be used to position the break point on the
          branches. It is a value between 30 and 90 degrees that is combined
          with the offset_between_branches parameter value to compute this
          position. When the break point angle value is 90 degrees, each branch
          displays orthogonally.
      type_attribute {String}:
          The name of the network attribute that will be used to qualify the
          lines. This network attribute may exist in the network line
          classes.The type_attribute and line_attribute network attributes can
          be the
          same.
      mainline_values {Value Table}:
          The type_attribute values that identify the main lines. When such
          values exist, they must be the same for any edge that comprises the
          main lines, regardless of their related network feature classes.
      branch_values {Value Table}:
          The type_attribute values that identify the branches.
      excluded_values {Value Table}:
          The type_attribute values that identify the edges that must be
          excluded from the straight lines (crossovers or ladders).
      is_compressing {Boolean}:
          Specifies whether the graph will be compressed.

          * USE_COMPRESSION-An additional step is executed at the end of the
          process to reduce the distances between adjacent groups of neighbor
          junctions along the direction while maintaining relative positioning
          between these groups. Neighbor junctions are junctions that are
          geographically close to each other without being directly connected.

          * DO_NOT_USE_COMPRESSION-Compression will not be used. This is the
          default.
      compression_ratio {Double}:
          A value between 0 and 100 that is applied to the length of any edge
          after subtracting the minimal distance of its length. When
          compression_ratio is 100, the distance between each detected junction
          group is equal to the minimal distance.
      minimal_distance {Linear Unit}:
          The minimal distance between two adjacent groups of neighbor
          junctions. This minimal distance is also used to group neighbor
          junctions regarding their projection along the direction axis. Two
          junctions projected on this axis will belong to the same group when
          the distance between the two projected points is less than this
          distance.
      alignment_attribute {String}:
          The name of the network attribute that will be used to align lines
          that are split. The algorithm aligns the line with the same attribute
          value.
      initial_distances {String}:
          Specifies how the length of the diagram edges will be assessed. This
          length determines the positions of the junctions along the direction.
          The distances between the connected junctions along the direction are
          not equidistant; they are relative to each other and depend on the
          current edge length and the length of the shortest edge.

          * FROM_CURRENT_EDGE_GEOMETRY-The distances will be computed from the
          current edge geometry. This is the default.

          * FROM_ATTRIBUTE_EDGE-The distances will be computed from a given
          attribute that exists on an edge.
      length_attribute {String}:
          The network attribute from which the distances will be computed when
          initial_distances is FROM_ATTRIBUTE_EDGE.
      run_async {Boolean}:
          Specifies whether the layout algorithm will run asynchronously or
          synchronously on the server.

          *  RUN_ASYNCHRONOUSLY-The layout algorithm will run asynchronously on
          the server. This option dedicates server resources to run the layout
          algorithm with a longer time-out. Running asynchronously can be
          interesting when executing layouts that are time consuming and may
          exceed the server time-out-for example, Partial Overlapping Edges-and
          applying to large diagrams-more than 25,000 features.

          *  RUN_SYNCHRONOUSLY-The layout algorithm will run synchronously on
          the server. It can fail without completion if its execution exceeds
          the service time-out: 600 seconds by default. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyRelativeMainlineLayout_nd(*gp_fixargs((in_network_diagram_layer, line_attribute, mainline_direction, offset_between_branches, breakpoint_angle, type_attribute, mainline_values, branch_values, excluded_values, is_compressing, compression_ratio, minimal_distance, alignment_attribute, initial_distances, length_attribute, run_async), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyRotateTreeLayout_nd', None)
def ApplyRotateTreeLayout(in_network_diagram_layer=None, are_containers_preserved=None, rotation_angle=None, run_async=None):
    """ApplyRotateTreeLayout_nd(in_network_diagram_layer, {are_containers_preserved}, {rotation_angle}, {run_async})

        Rotates the tree or trees related to pivot junctions currently set up
        in a diagram to the specified angle.If you have an open edit session,
        you must save your edits prior to
        running this tool. This ensures that the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which the layout will be applied.
      are_containers_preserved {Boolean}:
          Specifies how the algorithm will process containers.

          * PRESERVE_CONTAINERS-The layout algorithm will execute on the top
          graph of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm will execute on both content
          and noncontent features in the diagram. This is the default.
      rotation_angle {Double}:
          The angle in degrees that will be used to rotate the tree. The default
          is 45 degrees.
      run_async {Boolean}:
          Specifies whether the layout algorithm will run asynchronously or
          synchronously on the server.

          *  RUN_ASYNCHRONOUSLY-The layout algorithm will run asynchronously on
          the server. This option dedicates server resources to run the layout
          algorithm with a longer time-out. Running asynchronously can be
          interesting when executing layouts that are time consuming and may
          exceed the server time-out-for example, Partial Overlapping Edges-and
          applying to large diagrams-more than 25,000 features.

          *  RUN_SYNCHRONOUSLY-The layout algorithm will run synchronously on
          the server. It can fail without completion if its execution exceeds
          the service time-out: 600 seconds by default. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyRotateTreeLayout_nd(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, rotation_angle, run_async), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplySmartTreeLayout_nd', None)
def ApplySmartTreeLayout(in_network_diagram_layer=None, are_containers_preserved=None, tree_direction=None, is_unit_absolute=None, subtree_absolute=None, subtree_proportional=None, perpendicular_absolute=None, perpendicular_proportional=None, along_absolute=None, along_proportional=None, disjoined_graph_absolute=None, disjoined_graph_proportional=None, are_edges_orthogonal=None, breakpoint_position=None, edge_display_type=None, run_async=None):
    """ApplySmartTreeLayout_nd(in_network_diagram_layer, {are_containers_preserved}, {tree_direction}, {is_unit_absolute}, {subtree_absolute}, {subtree_proportional}, {perpendicular_absolute}, {perpendicular_proportional}, {along_absolute}, {along_proportional}, {disjoined_graph_absolute}, {disjoined_graph_proportional}, {are_edges_orthogonal}, {breakpoint_position}, {edge_display_type}, {run_async})

        Arranges diagram features hierarchically and places them in a smart
        tree.If you have an open edit session, you must save your edits prior
        to
        running this tool. This ensures that the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which the layout will be applied.
      are_containers_preserved {Boolean}:
          Specifies how the algorithm will process containers.

          * PRESERVE_CONTAINERS-The layout algorithm will execute on the top
          graph of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm will execute on both content
          and noncontent features in the diagram. This is the default.
      tree_direction {String}:
          Specifies the direction of the tree.

          * FROM_LEFT_TO_RIGHT-The tree will be drawn from left to right. This
          is the default.

          * FROM_RIGHT_TO_LEFT-The tree will be drawn from right to left.

          * FROM_BOTTOM_TO_TOP-The tree will be drawn from bottom to top.

          * FROM_TOP_TO_BOTTOM-The tree will be drawn from top to bottom.
      is_unit_absolute {Boolean}:
          Specifies how parameters representing distances will be interpreted.

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the current diagram extent. This is the default.
      subtree_absolute {Linear Unit}:
          The spacing between two neighboring subtrees; that is, the spacing
          between diagram junctions that are displayed perpendicular to the
          smart tree direction and belong to a different subtree. The default is
          in the units of the diagram's coordinate system. This parameter can
          only be used with absolute units.
      subtree_proportional {Double}:
          The spacing between two neighboring subtrees; that is, the spacing
          between diagram junctions that are displayed perpendicular to the
          smart tree direction and belong to a different subtree. The default is
          2. This parameter can only be used with proportional units.
      perpendicular_absolute {Linear Unit}:
          The spacing between diagram junctions that are displayed perpendicular
          to the smart tree direction and belong to the same subtree level. The
          default is 2 in the units of the diagram's coordinate system. This
          parameter can only be used with absolute units.
      perpendicular_proportional {Double}:
          The spacing between diagram junctions that are displayed
          perpendicular to the smart tree direction and belong to the same
          subtree level. The default is 2. This parameter can only be used with
          proportional units.
      along_absolute {Linear Unit}:
          The spacing between diagram junctions that are displayed along the
          smart tree direction. The default is 2 in the units of the diagram's
          coordinate system. This parameter can only be used with absolute
          units.
      along_proportional {Double}:
          The spacing between diagram junctions that are displayed along the
          smart tree direction. The default is 2. This parameter can only be
          used with proportional units.
      disjoined_graph_absolute {Linear Unit}:
          The minimum spacing that will separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is used with absolute units. The default is 4 in the units of the
          diagram's coordinate system.
      disjoined_graph_proportional {Double}:
          The minimum spacing that will separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is used with proportional units. The default is 4.
      are_edges_orthogonal {Boolean}:
          Specifies how diagram edges that are related to the tree branches will
          display.This parameter is deprecated at ArcGIS Pro 2.5. It is
          systematically
          ignored regardless of its value when the edge_display_type parameter
          is specified. However, to maintain compatibility with ArcGIS Pro 2.1,
          it remains enabled when the edge_display_type parameter is not
          specified.

          *  ORTHOGONAL_EDGES-All diagram edges related to the tree branches
          will display with right angles.

          *  SLANTED_EDGES-All diagram edges related to the tree branches will
          not display with right angles. This is the default.
      breakpoint_position {Double}:
          The relative position of the break point that will be inserted along
          the diagram edges when Edge Display Type is Regular edges
          (edge_display_type = REGULAR_EDGES in Python) or Edge Display Type is
          Orthogonal edges (edge_display_type = ORTHOGONAL_EDGES in Python). It
          is a percentage between 0 and 100.

          * With a Break Point Relative Position (%) value of 0, the break point
          is positioned at the x-coordinate of the edge's from junction and at
          the y-coordinate of the edge's to junction for a horizontal tree. It
          is positioned at the y-coordinate of the edge's from junction and at
          the x-coordinate of the edge's to junction for a vertical tree.

          * With a Break Point Relative Position (%) value of 100, there is no
          break point inserted on the diagram edges; each diagram edge directly
          connects its from and to junctions.

          * With a Break Point Relative Position (%) value of N between 0 and
          100, the break point is positioned at N% of the length of the [XY]
          segment, X being the x-coordinate of the edge's from junction and Y
          being the y-coordinate of the edge's to junction for a horizontal
          tree. It is positioned at N% of the length of the [YX] segment, Y
          being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree.
          The relative position of the two inflection points that will be
          inserted along the diagram edges to compute the curved edges geometry
          when Edge Display Type is Curved edges (edge_display_type =
          CURVED_EDGES in Python). It is a percentage between 15 and 40. With a
          Break Point Relative Position (%) value of N between 15 and 40:

          * X being the x-coordinate of the edge's from junction and Y being the
          y-coordinate of the edge's to junction for a horizontal tree:

          * The first inflection point will be positioned at N% of the length of
          the [XY] segment.

          * The second inflection point will be positioned at (100 - N)% of the
          length of the [XY] segment.

          * Y being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree:

          * The first inflection point will be positioned at N% of the length of
          the [YX] segment.

          * The second inflection point will be positioned at (100 - N)% of the
          length of the [XY] segment.

          The concept of the from and to junctions above is relative to the tree
          direction; it has nothing to do with the real topology of the network
          feature edge.
      edge_display_type {String}:
          Specifies the type of display for the diagram edges related to the
          tree branches.

          * REGULAR_EDGES-All diagram edges related to the tree branches will
          not display with right angles. This is the default.

          * ORTHOGONAL_EDGES-All diagram edges related to the tree branches will
          display with right angles.

          * CURVED_EDGES-All diagram edges related to the tree branches will be
          curved.
      run_async {Boolean}:
          Specifies whether the layout algorithm will run asynchronously or
          synchronously on the server.

          *  RUN_ASYNCHRONOUSLY-The layout algorithm will run asynchronously on
          the server. This option dedicates server resources to run the layout
          algorithm with a longer time-out. Running asynchronously can be
          interesting when executing layouts that are time consuming and may
          exceed the server time-out-for example, Partial Overlapping Edges-and
          applying to large diagrams-more than 25,000 features.

          *  RUN_SYNCHRONOUSLY-The layout algorithm will run synchronously on
          the server. It can fail without completion if its execution exceeds
          the service time-out: 600 seconds by default. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplySmartTreeLayout_nd(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, tree_direction, is_unit_absolute, subtree_absolute, subtree_proportional, perpendicular_absolute, perpendicular_proportional, along_absolute, along_proportional, disjoined_graph_absolute, disjoined_graph_proportional, are_edges_orthogonal, breakpoint_position, edge_display_type, run_async), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplySpatialDispatchLayout_nd', None)
def ApplySpatialDispatchLayout(in_network_diagram_layer=None, are_containers_preserved=None, iterations_number=None, maximum_shift_factor=None, run_async=None):
    """ApplySpatialDispatchLayout_nd(in_network_diagram_layer, {are_containers_preserved}, {iterations_number}, {maximum_shift_factor}, {run_async})

        Separates diagram junctions that are visibly close to overlapping.If
        you have an open edit session, you must save your edits prior to
        running this tool. This ensures that the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which the layout will be applied.
      are_containers_preserved {Boolean}:
          Specifies how the algorithm will process containers.

          * PRESERVE_CONTAINERS-The layout algorithm will execute on the top
          graph of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm will execute on both content
          and noncontent features in the diagram. This is the default.
      iterations_number {Long}:
          The number of iterations to process. The default is 5.
      maximum_shift_factor {Double}:
          The maximum value used to increase the diagram junctions' displacement
          for junctions that are very close together. The greater the shift
          factor, the larger the separation between the diagram junctions that
          almost overlap. The default is 2.
      run_async {Boolean}:
          Specifies whether the layout algorithm will run asynchronously or
          synchronously on the server.

          *  RUN_ASYNCHRONOUSLY-The layout algorithm will run asynchronously on
          the server. This option dedicates server resources to run the layout
          algorithm with a longer time-out. Running asynchronously can be
          interesting when executing layouts that are time consuming and may
          exceed the server time-out-for example, Partial Overlapping Edges-and
          applying to large diagrams-more than 25,000 features.

          *  RUN_SYNCHRONOUSLY-The layout algorithm will run synchronously on
          the server. It can fail without completion if its execution exceeds
          the service time-out: 600 seconds by default. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplySpatialDispatchLayout_nd(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, iterations_number, maximum_shift_factor, run_async), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyTemplateLayouts_nd', None)
def ApplyTemplateLayouts(in_network_diagram_layer=None):
    """ApplyTemplateLayouts_nd(in_network_diagram_layer)

        Applies the list of layout algorithms currently configured for the
        diagram template to the input network diagram layer.If you have an
        open edit session, you must save your edits prior to
        running this tool. This ensures that the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which the layout will be applied."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyTemplateLayouts_nd(*gp_fixargs((in_network_diagram_layer,), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ReshapeDiagramEdgesLayout_nd', None)
def ReshapeDiagramEdgesLayout(in_network_diagram_layer=None, are_containers_preserved=None, reshape_type=None, is_path_preserved=None, offset_between_segment_absolute=None, breakpoint_absolute=None, shift_between_edge_absolute=None, angle_threshold=None, circular_arc_radius=None, circular_arc_position=None, run_async=None):
    """ReshapeDiagramEdgesLayout_nd(in_network_diagram_layer, {are_containers_preserved}, {reshape_type}, {is_path_preserved}, {offset_between_segment_absolute}, {breakpoint_absolute}, {shift_between_edge_absolute}, {angle_threshold}, {circular_arc_radius}, {circular_arc_position}, {run_async})

        Processes simple operations on vertices along edges.If you have an
        open edit session, you must save your edits prior to
        running this tool. This ensures that the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to which the layout will be applied.
      are_containers_preserved {Boolean}:
          Specifies how the algorithm will process containers.

          * PRESERVE_CONTAINERS-The layout algorithm will execute on the top
          graph of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm will execute on both content
          and noncontent features in the diagram. This is the default.
      reshape_type {String}:
          Specifies how edges will be reshaped.

          * REMOVE_VERTICES-Vertices along any edges in the diagram will be
          removed.

          * SQUARE_EDGES-Vertices will be placed along diagram edges, and the
          edges will be displayed with right angles. This is the default.

          * SEPARATE_OVERLAPPING_EDGES-Edges that connect the same origin and
          extremity junctions will be separated when they are overlapping.

          * REDUCE_VERTICES_BY_ANGLE-Some or all vertices displayed along
          diagram edges will be reduced according to the angle that separates
          the segments incident to those vertices.

          * MARK_CROSSING_EDGES-The horizontal and vertical diagram edges that
          cross each other at a right angle in the diagram will be marked, and
          the geometry of one of the crossing edges will be reshaped to display
          a circular arc at this location.
      is_path_preserved {Boolean}:
          Specifies whether vertices along the edges that are going to be
          squared will be preserved. This parameter can only be used when
          reshape_type is SQUARE_EDGES.

          *  PRESERVE_PATH-The direction of any edge will be considered, and
          vertices along that edge will be preserved from the first vertex to
          the last. This is the default.

          * IGNORE_PATH-Vertices along the diagram edges will not be considered,
          and the vertices will be removed during execution.
      offset_between_segment_absolute {Linear Unit}:
          The spacing that will separate parallel segments of squared edges
          incident to the same junction. The default is 5 in the units of the
          diagram's coordinate system. This parameter can only be used when
          reshape_type is SQUARE_EDGES.
      breakpoint_absolute {Linear Unit}:
          The maximum distance between each junction to the first or last break
          point along edges incident to that junction when those edges are
          squared. The default is 8.66 in the units of the diagram's coordinate
          system. This parameter can only be used when reshape_type is
          SQUARE_EDGES.
      shift_between_edge_absolute {Linear Unit}:
          The absolute spacing that will separate two edges. The default is 0.5
          in the units of the diagram's coordinate system. This parameter can
          only be used when reshape_type is SEPARATE_OVERLAPPING_EDGES.
      angle_threshold {Double}:
          The angle formed by the incident segments over which the vertex
          related to these segments is reduced. The wider the angle, the fewer
          number of vertices are reduced. The default is 160 degrees. This
          parameter can only be used when reshape_type is
          REDUCE_VERTICES_BY_ANGLE.
      circular_arc_radius {Linear Unit}:
          The radius of the circular arc that will be added to the crossing
          edge locations. The default is 5.
      circular_arc_position {String}:
          Specifies the segment on which a circular arc will be placed.

          * LEFT_OF_VERTICAL_SEGMENT-A circular arc will be placed to the left
          of the vertical segment.

          * RIGHT_OF_VERTICAL_SEGMENT-A circular arc will be placed to the right
          of the vertical segment.

          * ABOVE_HORIZONTAL_SEGMENT-A circular arc will be placed above the
          horizontal segment.

          * BELOW_HORIZONTAL_SEGMENT-A circular arc will be placed below the
          horizontal segment.
      run_async {Boolean}:
          Specifies whether the layout algorithm will run asynchronously or
          synchronously on the server.

          *  RUN_ASYNCHRONOUSLY-The layout algorithm will run asynchronously on
          the server. This option dedicates server resources to run the layout
          algorithm with a longer time-out. Running asynchronously can be
          interesting when executing layouts that are time consuming and may
          exceed the server time-out-for example, Partial Overlapping Edges-and
          applying to large diagrams-more than 25,000 features.

          *  RUN_SYNCHRONOUSLY-The layout algorithm will run synchronously on
          the server. It can fail without completion if its execution exceeds
          the service time-out: 600 seconds by default. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ReshapeDiagramEdgesLayout_nd(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, reshape_type, is_path_preserved, offset_between_segment_absolute, breakpoint_absolute, shift_between_edge_absolute, angle_threshold, circular_arc_radius, circular_arc_position, run_async), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject